@@ -35,10 +35,9 @@ public class VisualVMJUnitPluginDelegate extends JUnitLaunchConfigurationDelegat
 			throws CoreException {
 		try {
 			VisualVMHelper.openInVisualVM(usedId);
-			return super.getVMRunner(configuration, mode);
 		} catch (IOException e) {
-			e.printStackTrace();
-			return null;
+			VisualVMHelper.logException(e);
 		}
+		return super.getVMRunner(configuration, mode);
 	}
 }
