@@ -50,8 +50,6 @@ import org.netbeans.lib.profiler.client.ClientUtils;
 import org.netbeans.lib.profiler.client.ClientUtils.SourceCodeSelection;
 import org.netbeans.lib.profiler.common.event.ProfilingStateEvent;
 import org.netbeans.lib.profiler.common.event.ProfilingStateListener;
-import org.netbeans.lib.profiler.common.filters.DefinedFilterSets;
-import org.netbeans.lib.profiler.common.filters.GlobalFilters;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.instrumentation.BadLocationException;
 import org.netbeans.lib.profiler.instrumentation.InstrumentationException;
@@ -147,12 +145,6 @@ public abstract class Profiler {
 
     public abstract SessionSettings getCurrentSessionSettings();
 
-    public abstract DefinedFilterSets getDefinedFilterSets();
-
-    public abstract GlobalFilters getGlobalFilters();
-    
-    public abstract void saveFilters();
-
     public abstract GlobalProfilingSettings getGlobalProfilingSettings();
 
     public abstract ProfilingSettings getLastProfilingSettings();
@@ -262,6 +254,7 @@ public abstract class Profiler {
                 break;
             case ProfilingSettings.PROFILE_CPU_ENTIRE:
             case ProfilingSettings.PROFILE_CPU_PART:
+            case ProfilingSettings.PROFILE_CPU_JDBC:
                 instrumentSelectedRoots(profilingSettings.getInstrumentationMethods());
 
                 break;
