@@ -45,18 +45,16 @@ package org.netbeans.lib.profiler.common;
 
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.client.ClientUtils;
-import org.netbeans.lib.profiler.common.filters.FilterSet;
-import org.netbeans.lib.profiler.common.filters.FilterUtils;
-import org.netbeans.lib.profiler.common.filters.GlobalFilters;
-import org.netbeans.lib.profiler.common.filters.SimpleFilter;
 import org.netbeans.lib.profiler.global.CommonConstants;
-import org.netbeans.lib.profiler.global.InstrumentationFilter;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.ResourceBundle;
 import java.util.Set;
+import org.netbeans.lib.profiler.filters.GenericFilter;
+import org.netbeans.lib.profiler.filters.JavaTypeFilter;
 
 
 /**
@@ -85,6 +83,7 @@ public class ProfilingSettings {
     public static final int PROFILE_CPU_STOPWATCH = 32; // cpu: code fragment
     public static final int PROFILE_CPU_SAMPLING = 64; // cpu: sampled profiling
     public static final int PROFILE_MEMORY_SAMPLING = 128; // memory: sampling 
+    public static final int PROFILE_CPU_JDBC = 256; // special type of cpu profiling (uses marker methods) 
     public static final boolean QUICK_FILTER_INCLUSIVE = true;
     public static final boolean QUICK_FILTER_EXCLUSIVE = false;
     public static final String LINES_PREFIX = "[lines]"; //NOI18N
@@ -107,6 +106,7 @@ public class ProfilingSettings {
     public static final String PROP_INSTRUMENT_METHOD_INVOKE = "profiler.settings.instrument.method.invoke"; //NOI18N
     public static final String PROP_INSTRUMENT_SPAWNED_THREADS = "profiler.settings.instrument.spawned.threads"; //NOI18N
     public static final String PROP_N_PROFILED_THREADS_LIMIT = "profiler.settings.n.profiled.threads.limit"; //NOI18N
+    public static final String PROP_STACK_DEPTH_LIMIT = "profiler.settings.stack.depth.limit"; //NOI18N
     public static final String PROP_SORT_RESULTS_BY_THREAD_CPU_TIME = "profiler.settings.sort.results.by.thread.cpu.time"; //NOI18N
     public static final String PROP_SAMPLING_INTERVAL = "profiler.settings.sampling.interval"; //NOI18N
     public static final String PROP_INSTRUMENTATION_ROOT_METHODS_SIZE = "profiler.settings.instrumentation.root.methods.size"; //NOI18N
@@ -118,7 +118,7 @@ public class ProfilingSettings {
     public static final String PROP_RUN_GC_ON_GET_RESULTS_IN_MEMORY_PROFILING = "profiler.settings.run.gc.on.get.results.in.memory.profiling"; //NOI18N
     public static final String PROP_OBJ_ALLOC_STACK_SAMPLING_INTERVAL = "profiler.settings.obj.alloc.stack.sampling.interval"; //NOI18N
     public static final String PROP_OBJ_ALLOC_STACK_SAMPLING_DEPTH = "profiler.settings.obj.alloc.stack.sampling.depth"; //NOI18N
-    public static final String PROP_SELECTED_INSTR_FILTER = "profiler.settings.instrumentation.filter.selected"; //NOI18N
+    public static final String PROP_INSTR_FILTER = "profiler.settings.instrumentation.filter."; //NOI18N
     public static final String PROP_PROFILE_UNDERLYING_FRAMEWORK = "profiler.settings.profile.underlying.framework"; // NOI18N
     public static final String PROP_PROFILING_POINTS_ENABLED = "profiler.settings.profilingpoints.enabled"; //NOI18N
     public static final String PROP_QUICK_FILTER = "profiler.settings.cpu.quick.filter"; //NOI18N
@@ -134,9 +134,8 @@ public class ProfilingSettings {
     private List instrumentationRootMethods = new ArrayList();
 
     // CPU instrumentation filter related settings
-    private Object selectedInstrumentationFilter = SimpleFilter.NO_FILTER; //NOI18N
-                                                                           // QuickFilter: just for persistence
-    private SimpleFilter quickFilter = FilterUtils.QUICK_FILTER;
+    private GenericFilter instrumentationFilter = new GenericFilter();
+    
     private String jvmArgs = ""; //NOI18N
     private String platformName = null; // from project
     private String settingsName = DEFAULT_PROFILING_SETTINGS_NAME;
@@ -157,7 +156,7 @@ public class ProfilingSettings {
     // -- Memory profiling settings
     private boolean runGCOnGetResultsInMemoryProfiling = true;
     private boolean sortResultsByThreadCPUTime = false;
-    private boolean threadCPUTimerOn = false;
+    private boolean threadCPUTimerOn = true;
     private boolean threadsMonitoringEnabled = false;
     private boolean lockContentionMonitoringEnabled = false;
     private boolean threadsSamplingEnabled = true;
@@ -170,10 +169,11 @@ public class ProfilingSettings {
     private int cpuProfilingType = CommonConstants.CPU_INSTR_FULL;
     private int instrScheme = CommonConstants.INSTRSCHEME_LAZY;
     private int nProfiledThreadsLimit = 32;
-    private int profilingType = PROFILE_CPU_SAMPLING;
+    private int stackDepthLimit = Integer.MAX_VALUE;
+    private int profilingType = PROFILE_MONITOR;
 
     // CPU Profiling: Sampled
-    private int samplingInterval = 10; // hybrid
+    private int samplingInterval = -10; // hybrid
     private int samplingFrequency = 10; // pure sampling
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
@@ -201,6 +201,18 @@ public class ProfilingSettings {
         return (type == ProfilingSettings.PROFILE_CPU_ENTIRE) || (type == ProfilingSettings.PROFILE_CPU_PART)
                || (type == ProfilingSettings.PROFILE_CPU_STOPWATCH || type == PROFILE_CPU_SAMPLING);
     }
+    
+    public static boolean isJDBCSettings(ProfilingSettings settings) {
+        if (settings == null) {
+            return false;
+        }
+
+        return isJDBCSettings(settings.getProfilingType());
+    }
+    
+    public static boolean isJDBCSettings(int type) {
+        return type == ProfilingSettings.PROFILE_CPU_JDBC;
+    }
 
     public static boolean isMemorySettings(ProfilingSettings settings) {
         if (settings == null) {
@@ -346,8 +358,7 @@ public class ProfilingSettings {
     }
 
     public ClientUtils.SourceCodeSelection[] getInstrumentationMarkerMethods() {
-        return (ClientUtils.SourceCodeSelection[]) instrumentationMarkerMethods.toArray(new ClientUtils.SourceCodeSelection[instrumentationMarkerMethods
-                                                                                                                            .size()]);
+        return (ClientUtils.SourceCodeSelection[]) instrumentationMarkerMethods.toArray(new ClientUtils.SourceCodeSelection[0]);
     }
 
     public ClientUtils.SourceCodeSelection[] getInstrumentationMethods() {
@@ -357,7 +368,7 @@ public class ProfilingSettings {
         methods.addAll(instrumentationRootMethods);
         methods.addAll(instrumentationMarkerMethods);
 
-        return (ClientUtils.SourceCodeSelection[]) methods.toArray(new ClientUtils.SourceCodeSelection[methods.size()]);
+        return (ClientUtils.SourceCodeSelection[]) methods.toArray(new ClientUtils.SourceCodeSelection[0]);
     }
 
     public void setInstrumentationRootMethods(final ClientUtils.SourceCodeSelection[] roots) {
@@ -373,8 +384,7 @@ public class ProfilingSettings {
     }
 
     public ClientUtils.SourceCodeSelection[] getInstrumentationRootMethods() {
-        return (ClientUtils.SourceCodeSelection[]) instrumentationRootMethods.toArray(new ClientUtils.SourceCodeSelection[instrumentationRootMethods
-                                                                                                                          .size()]);
+        return (ClientUtils.SourceCodeSelection[]) instrumentationRootMethods.toArray(new ClientUtils.SourceCodeSelection[0]);
     }
     
     public void setSamplingFrequency(int samplingFrequency) {
@@ -413,6 +423,14 @@ public class ProfilingSettings {
         return nProfiledThreadsLimit;
     }
 
+    public void setStackDepthLimit(int num) {
+        stackDepthLimit = num;
+    }
+
+    public int getStackDepthLimit() {
+        return stackDepthLimit;
+    }
+
     public void setOverrideGlobalSettings(final boolean override) {
         overrideGlobalSettings = override;
     }
@@ -442,14 +460,6 @@ public class ProfilingSettings {
         return profilingType;
     }
 
-    public void setQuickFilter(SimpleFilter quickFilter) {
-        this.quickFilter = quickFilter;
-    }
-
-    public SimpleFilter getQuickFilter() {
-        return quickFilter;
-    }
-
     public void setRunGCOnGetResultsInMemoryProfiling(final boolean runGCOnGetResultsInMemoryProfiling) {
         this.runGCOnGetResultsInMemoryProfiling = runGCOnGetResultsInMemoryProfiling;
     }
@@ -467,12 +477,12 @@ public class ProfilingSettings {
         return samplingInterval;
     }
 
-    public void setSelectedInstrumentationFilter(final Object sif) {
-        selectedInstrumentationFilter = sif != null ? sif : SimpleFilter.NO_FILTER;
+    public void setInstrumentationFilter(final GenericFilter filter) {
+        instrumentationFilter = filter;
     }
 
-    public Object getSelectedInstrumentationFilter() {
-        return selectedInstrumentationFilter;
+    public GenericFilter getInstrumentationFilter() {
+        return instrumentationFilter;
     }
 
     public void setSettingsName(final String name) {
@@ -583,6 +593,7 @@ public class ProfilingSettings {
             settings.setNProfiledThreadsLimit(Integer.MAX_VALUE); // zero or negative value means we do not limit it, just remember value for the UI
         }
 
+        settings.setStackDepthLimit(getStackDepthLimit());
         settings.setSortResultsByThreadCPUTime(getSortResultsByThreadCPUTime());
 
         settings.setSamplingInterval(getSamplingInterval());
@@ -602,80 +613,12 @@ public class ProfilingSettings {
         //    for(Iterator iter=rootMethods.iterator();iter.hasNext();) {
         //      ((ClientUtils.SourceCodeSelection)iter.next()).setMarkerMethod(true);
         //    }
-        //    settings.setInstrumentationRootMethods((ClientUtils.SourceCodeSelection[])rootMethods.toArray(new ClientUtils.SourceCodeSelection[rootMethods.size()]));
+        //    settings.setInstrumentationRootMethods((ClientUtils.SourceCodeSelection[])rootMethods.toArray(new ClientUtils.SourceCodeSelection[0]));
         settings.setInstrumentationRootMethods(getInstrumentationMethods());
 
-        // Now applySettings the filters to the Engine's instrumentation filter
-        final InstrumentationFilter instrumentationFilter = settings.getInstrumentationFilter();
-        instrumentationFilter.clearFilter(); // lets start from scratch
+        // Now apply the filters to the Engine's instrumentation filter
+        settings.setInstrumentationFilter(instrumentationFilter);
 
-        // No filter
-        if (getSelectedInstrumentationFilter().equals(FilterUtils.NONE_FILTER)) {
-            instrumentationFilter.setFilterType(InstrumentationFilter.INSTR_FILTER_NONE);
-            instrumentationFilter.setFilterStrings(""); //NOI18N
-
-            return;
-        }
-
-        // Quick Filter
-        if (getSelectedInstrumentationFilter().equals(quickFilter)) {
-            if (quickFilter.getFilterValue().length() > 0) {
-                // Quick Filter defined
-                instrumentationFilter.setFilterType((quickFilter.getFilterType() == SimpleFilter.SIMPLE_FILTER_EXCLUSIVE)
-                                                    ? InstrumentationFilter.INSTR_FILTER_EXCLUSIVE
-                                                    : InstrumentationFilter.INSTR_FILTER_INCLUSIVE);
-                instrumentationFilter.setFilterStrings(quickFilter.getFilterValue());
-            } else {
-                // Quick Filter cancelled and no previous filter defined => filterType=INSTR_FILTER_NONE
-                instrumentationFilter.setFilterType(InstrumentationFilter.INSTR_FILTER_NONE);
-                instrumentationFilter.setFilterStrings(""); //NOI18N
-            }
-
-            return;
-        }
-
-        // Filter defined by ProjectTypeProfiler
-        if (getSelectedInstrumentationFilter() instanceof SimpleFilter) {
-            SimpleFilter ptpFilter = (SimpleFilter) getSelectedInstrumentationFilter();
-            instrumentationFilter.setFilterType((ptpFilter.getFilterType() == SimpleFilter.SIMPLE_FILTER_EXCLUSIVE)
-                                                ? InstrumentationFilter.INSTR_FILTER_EXCLUSIVE
-                                                : InstrumentationFilter.INSTR_FILTER_INCLUSIVE);
-            instrumentationFilter.setFilterStrings(ptpFilter.getFilterValue());
-
-            return;
-        }
-
-        // Filter Set
-        if (getSelectedInstrumentationFilter() instanceof FilterSet) {
-            FilterSet filterSet = (FilterSet) getSelectedInstrumentationFilter();
-            GlobalFilters globalFilters = Profiler.getDefault().getGlobalFilters();
-
-            // set filter type
-            instrumentationFilter.setFilterType((filterSet.getFilterSetType() == FilterSet.FILTER_SET_EXCLUSIVE)
-                                                ? InstrumentationFilter.INSTR_FILTER_EXCLUSIVE
-                                                : InstrumentationFilter.INSTR_FILTER_INCLUSIVE);
-
-            // set filter value
-            final StringBuffer flatFilterStringsBuffer = new StringBuffer();
-            final String[] activeGlobalFilters = filterSet.getActiveGlobalFilters();
-
-            for (int i = 0; i < activeGlobalFilters.length; i++) {
-                final String activeGlobalFilterValue = globalFilters.getFilterValue(activeGlobalFilters[i]);
-
-                if (activeGlobalFilterValue != null) {
-                    flatFilterStringsBuffer.append(activeGlobalFilterValue);
-                    flatFilterStringsBuffer.append(" "); //NOI18N
-                }
-            }
-
-            instrumentationFilter.setFilterStrings(flatFilterStringsBuffer.toString());
-
-            return;
-        }
-
-        // Unknown or no filter
-        instrumentationFilter.setFilterType(InstrumentationFilter.INSTR_FILTER_NONE);
-        instrumentationFilter.setFilterStrings(""); //NOI18N
     }
 
     // -- Settings duplication -------------------------------------------------------------------------------------------
@@ -707,6 +650,7 @@ public class ProfilingSettings {
         settings.setInstrumentMethodInvoke(getInstrumentMethodInvoke());
         settings.setInstrumentSpawnedThreads(getInstrumentSpawnedThreads());
         settings.setNProfiledThreadsLimit(getNProfiledThreadsLimit());
+        settings.setStackDepthLimit(getStackDepthLimit());
         settings.setSortResultsByThreadCPUTime(getSortResultsByThreadCPUTime());
 
         settings.setSamplingInterval(getSamplingInterval());
@@ -720,8 +664,7 @@ public class ProfilingSettings {
         settings.setAllocTrackEvery(getAllocTrackEvery());
         settings.setAllocStackTraceLimit(getAllocStackTraceLimit());
 
-        settings.setSelectedInstrumentationFilter(getSelectedInstrumentationFilter());
-        settings.setQuickFilter(getQuickFilter());
+        settings.setInstrumentationFilter(getInstrumentationFilter());
 
         settings.setProfileUnderlyingFramework(getProfileUnderlyingFramework());
     }
@@ -768,6 +711,8 @@ public class ProfilingSettings {
         sb.append('\n'); //NOI18N
         sb.append("nProfiledThreadsLimit: ").append(getNProfiledThreadsLimit()); //NOI18N
         sb.append('\n'); //NOI18N
+        sb.append("stackDepthLimit: ").append(getStackDepthLimit()); //NOI18N
+        sb.append('\n'); //NOI18N
         sb.append("sortResultsByThreadCPUTime: ").append(getSortResultsByThreadCPUTime()); //NOI18N
         sb.append('\n'); //NOI18N
         sb.append("samplingInterval: ").append(getSamplingInterval()); //NOI18N
@@ -786,7 +731,7 @@ public class ProfilingSettings {
         sb.append('\n'); //NOI18N
         sb.append("allocStackTraceLimit: ").append(getAllocStackTraceLimit()); //NOI18N
         sb.append('\n'); //NOI18N
-        sb.append("selectedInstrFilter: ").append(getSelectedInstrumentationFilter()); //NOI18N
+        sb.append("selectedInstrFilter: ").append(getInstrumentationFilter()); //NOI18N
         sb.append('\n'); //NOI18N
         sb.append("profileUnderlyingFramework: ").append(getProfileUnderlyingFramework()); //NOI18N
         sb.append('\n'); //NOI18N
@@ -837,30 +782,30 @@ public class ProfilingSettings {
         setInstrumentSpawnedThreads(Boolean.valueOf(getProperty(props, prefix + PROP_INSTRUMENT_SPAWNED_THREADS, "false"))
                                            .booleanValue()); //NOI18N
         setNProfiledThreadsLimit(Integer.parseInt(getProperty(props, prefix + PROP_N_PROFILED_THREADS_LIMIT, "32"))); //NOI18N
+        setStackDepthLimit(Integer.parseInt(getProperty(props, prefix + PROP_STACK_DEPTH_LIMIT, String.valueOf(Integer.MAX_VALUE))));
         setSortResultsByThreadCPUTime(Boolean.valueOf(getProperty(props, prefix + PROP_SORT_RESULTS_BY_THREAD_CPU_TIME, "false"))
                                              .booleanValue()); //NOI18N
         setProfileUnderlyingFramework(Boolean.valueOf(getProperty(props, prefix + PROP_PROFILE_UNDERLYING_FRAMEWORK, "false"))
                                              .booleanValue()); //NOI18N
         setSamplingFrequency(Integer.parseInt(getProperty(props, prefix + PROP_SAMPLING_FREQUENCY, "10"))); // NOI18N
 
-        Object iFilter = FilterUtils.loadFilter(props, prefix + PROP_SELECTED_INSTR_FILTER);
-
-        if (iFilter == null) {
-            iFilter = SimpleFilter.NO_FILTER; // if loading fails
-        }
-
-        setSelectedInstrumentationFilter(iFilter);
-
-        SimpleFilter qFilter = (SimpleFilter) FilterUtils.loadFilter(props, prefix + PROP_QUICK_FILTER);
-
-        if (qFilter == null) {
-            qFilter = FilterUtils.QUICK_FILTER; // if loading fails
-        }
-
-        setQuickFilter(qFilter);
-
-        if (getSelectedInstrumentationFilter() == null) {
-            setSelectedInstrumentationFilter(SimpleFilter.NO_FILTER);
+        Properties pr = new Properties();
+        pr.putAll(props);
+        try {
+            // Try to load JavaTypeFilter, covers the most typical scenario for saved snapshots
+            setInstrumentationFilter(new JavaTypeFilter(pr, prefix + PROP_INSTR_FILTER));
+        } catch (GenericFilter.InvalidFilterIdException e) {
+            if ("profiler.simple.filter".equals(getProperty(props, prefix + "profiler.settings.instrumentation.filter.selectedprofiler.filter.type", null))) { // NOI18N
+                // Import previously used SimpleFilter
+                String filterValue = getProperty(props, prefix + "profiler.settings.instrumentation.filter.selectedprofiler.simple.filter.value", ""); // NOI18N
+                int filterType = Integer.parseInt(getProperty(props, prefix + "profiler.settings.instrumentation.filter.selectedprofiler.simple.filter.type", "0")); // NOI18N
+                if (filterType == 1 || filterType == 3) setInstrumentationFilter(new JavaTypeFilter(filterValue, JavaTypeFilter.TYPE_EXCLUSIVE));
+                else if (filterType == 2 || filterType == 4) setInstrumentationFilter(new JavaTypeFilter(filterValue, JavaTypeFilter.TYPE_INCLUSIVE));
+                else setInstrumentationFilter(new JavaTypeFilter(filterValue, JavaTypeFilter.TYPE_NONE));
+            } else {
+                // Fallback to GenericFilter if no filter is stored for this instance
+               setInstrumentationFilter(new GenericFilter("#fallback#", "", GenericFilter.TYPE_NONE)); // NOI18N
+            }
         }
 
         // CPU Profiling: Sampled
@@ -955,11 +900,17 @@ public class ProfilingSettings {
         props.put(prefix + PROP_INSTRUMENT_METHOD_INVOKE, Boolean.toString(getInstrumentMethodInvoke()));
         props.put(prefix + PROP_INSTRUMENT_SPAWNED_THREADS, Boolean.toString(getInstrumentSpawnedThreads()));
         props.put(prefix + PROP_N_PROFILED_THREADS_LIMIT, Integer.toString(getNProfiledThreadsLimit()));
+        props.put(prefix + PROP_STACK_DEPTH_LIMIT, Integer.toString(getStackDepthLimit()));
         props.put(prefix + PROP_SORT_RESULTS_BY_THREAD_CPU_TIME, Boolean.toString(getSortResultsByThreadCPUTime()));
         props.put(prefix + PROP_SAMPLING_FREQUENCY, Integer.toString(getSamplingFrequency()));
 
-        FilterUtils.storeFilter(props, getSelectedInstrumentationFilter(), prefix + PROP_SELECTED_INSTR_FILTER);
-        FilterUtils.storeFilter(props, getQuickFilter(), prefix + PROP_QUICK_FILTER);
+        if (instrumentationFilter != null) {
+            Properties pr = new Properties();
+            instrumentationFilter.store(pr, prefix + PROP_INSTR_FILTER);
+            props.putAll(pr);
+        } else {
+            props.remove(prefix + PROP_INSTR_FILTER);
+        }
 
         props.put(prefix + PROP_PROFILE_UNDERLYING_FRAMEWORK, Boolean.toString(getProfileUnderlyingFramework()));
 
@@ -1012,4 +963,5 @@ public class ProfilingSettings {
 
         return (ret != null) ? (String) ret : defaultValue;
     }
+    
 }
