@@ -74,6 +74,7 @@ public class IntegrationUtils {
     public static final String PLATFORM_JAVA_90 = messages.getString("IntegrationUtils_PlatformJava90"); // NOI18N
     public static final String PLATFORM_JAVA_100 = messages.getString("IntegrationUtils_PlatformJava100"); // NOI18N
     public static final String PLATFORM_JAVA_110 = messages.getString("IntegrationUtils_PlatformJava110"); // NOI18N
+    public static final String PLATFORM_JAVA_120 = messages.getString("IntegrationUtils_PlatformJava120"); // NOI18N
     public static final String PLATFORM_JAVA_CVM = messages.getString("IntegrationUtils_PlatformJavaCvm"); // NOI18N
     public static final String PLATFORM_WINDOWS_OS = messages.getString("IntegrationUtils_PlatformWindowsOs"); // NOI18N
     public static final String PLATFORM_WINDOWS_AMD64_OS = messages.getString("IntegrationUtils_PlatformWindowsAmd64Os"); // NOI18N
@@ -102,6 +103,7 @@ public class IntegrationUtils {
     private static final String JDK_90_NAME = messages.getString("IntegrationUtils_Jdk90Name"); // NOI18N
     private static final String JDK_100_NAME = messages.getString("IntegrationUtils_Jdk100Name"); // NOI18N
     private static final String JDK_110_NAME = messages.getString("IntegrationUtils_Jdk110Name"); // NOI18N
+    private static final String JDK_120_NAME = messages.getString("IntegrationUtils_Jdk120Name"); // NOI18N
     private static final String JDK_CVM_NAME = messages.getString("IntegrationUtils_JdkCvmName"); // NOI18N
     private static final String HTML_REMOTE_STRING = "&lt;" + messages.getString("IntegrationUtils_RemoteString") + "&gt;"; // NOI18N
     private static final String EXPORT_SETENV_MESSAGE = messages.getString("IntegrationUtils_ExportSetenvMessage"); // NOI18N
@@ -277,6 +279,8 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_100;
         } else if (javaVersionString.equals(CommonConstants.JDK_110_STRING)) {
             return PLATFORM_JAVA_110;
+        } else if (javaVersionString.equals(CommonConstants.JDK_120_STRING)) {
+            return PLATFORM_JAVA_120;
         } else if (javaVersionString.equals(CommonConstants.JDK_CVM_STRING)) {
             return PLATFORM_JAVA_CVM;
         }
@@ -344,6 +348,8 @@ public class IntegrationUtils {
             return JDK_100_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_110)) {
             return JDK_110_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_120)) {
+            return JDK_120_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return JDK_CVM_NAME;
         }
@@ -365,6 +371,10 @@ public class IntegrationUtils {
             return "jdk16"; //NOI18N // for JDK 9.0 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_100)) {
             return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_110)) {
+            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_120)) {
+            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return "cvm";  // NOI18N
         }
@@ -411,6 +421,8 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_100;
         } else if (jdkVersion == Platform.JDK_110) {
             return PLATFORM_JAVA_110;
+        } else if (jdkVersion == Platform.JDK_120) {
+            return PLATFORM_JAVA_120;
         }
 
         return null;
