@@ -857,7 +857,7 @@ public class CCTDisplay extends SnapshotCPUResultsPanel implements ScreenshotPro
     }
 
     protected void enableDisablePopup(PrestimeCPUCCTNode node) {
-        boolean regularNode = node.getThreadId() != -1 && node.getMethodId() != 0 && !node.isFilteredNode();
+        boolean regularNode = node.getThreadId() != -1 && node.getMethodId() != 0 && !node.isFiltered();
         if (popupShowSource != null) popupShowSource.setEnabled(regularNode && isShowSourceAvailable());
         if (popupShowSubtree != null) popupShowSubtree.setEnabled(regularNode);
         if (popupShowReverse != null) popupShowReverse.setEnabled(regularNode);
