@@ -79,6 +79,7 @@ import org.netbeans.lib.profiler.ui.swing.ProfilerTable;
 import org.netbeans.lib.profiler.ui.swing.ProfilerTreeTable;
 import org.netbeans.lib.profiler.ui.swing.SearchUtils;
 import org.netbeans.lib.profiler.utils.Wildcards;
+import org.netbeans.lib.profiler.ui.swing.renderer.HideableBarRenderer;
 
 /**
  *
@@ -273,6 +274,7 @@ public abstract class LiveCPUView extends JPanel {
             protected void popupShowing() { LiveCPUView.this.popupShowing(); }
             protected void popupHidden()  { LiveCPUView.this.popupHidden(); }
             protected boolean hasBottomFilterFindMargin() { return true; }
+            HideableBarRenderer.BarDiffMode barDiffMode() { return HideableBarRenderer.BarDiffMode.MODE_BAR_NORMAL; }
         };
         forwardCallsView.notifyOnFocus(new Runnable() {
             public void run() { lastFocused = forwardCallsView; }
@@ -288,6 +290,7 @@ public abstract class LiveCPUView extends JPanel {
             protected void popupShowing() { LiveCPUView.this.popupShowing(); }
             protected void popupHidden()  { LiveCPUView.this.popupHidden(); }
             protected boolean hasBottomFilterFindMargin() { return true; }
+            HideableBarRenderer.BarDiffMode barDiffMode() { return HideableBarRenderer.BarDiffMode.MODE_BAR_NORMAL; }
         };
         hotSpotsView.notifyOnFocus(new Runnable() {
             public void run() { lastFocused = hotSpotsView; }
