@@ -51,6 +51,8 @@ import java.awt.event.MouseEvent;
 import java.awt.event.MouseWheelEvent;
 import java.awt.event.MouseWheelListener;
 import java.awt.image.BufferedImage;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.util.Set;
 import javax.swing.BorderFactory;
 import javax.swing.JPanel;
@@ -130,7 +132,7 @@ public class ProfilerTableContainer extends JPanel {
                 }
             };
             scrollersPanel.setOpaque(true);
-            scrollersPanel.setBackground(getBackground());
+            scrollersPanel.setBackground(UIUtils.getProfilerResultsBackground());
 
             for (final Integer column : scrollableColumns) {
                 final JScrollBar scroller = new JScrollBar(JScrollBar.HORIZONTAL) {
@@ -261,8 +263,9 @@ public class ProfilerTableContainer extends JPanel {
         if (event.getScrollType() == MouseWheelEvent.WHEEL_UNIT_SCROLL) {
             int direction = event.getUnitsToScroll() < 0 ? -1 : 1;
             int increment = scroller.getUnitIncrement(direction);
+            int amount = event.getScrollAmount();
             int oldValue = scroller.getValue();
-            int newValue = oldValue + increment * direction;
+            int newValue = oldValue + increment * amount * direction;
             if (oldValue != newValue) scroller.setValue(newValue);
             event.consume();
         }
@@ -298,6 +301,9 @@ public class ProfilerTableContainer extends JPanel {
         return new JViewport() {
             {
                 setBackground(table.getBackground());
+                table.addPropertyChangeListener("enabled", new PropertyChangeListener() { // NOI18N
+                    public void propertyChange(PropertyChangeEvent evt) { setBackground(table.getBackground()); }
+                });
             }
             public void paint(Graphics g) {
                 super.paint(g);
@@ -311,10 +317,18 @@ public class ProfilerTableContainer extends JPanel {
                     if (height > viewHeight) {
                         g.setColor(table.getGridColor());
                         JTableHeader header = table.getTableHeader();
-                        for (int i = 0; i < table.getColumnCount(); i++) {
-                            Rectangle rect = header.getHeaderRect(i);
-                            if (rect.width > 0) g.drawLine(rect.x + rect.width - 1, viewHeight,
-                                                           rect.x + rect.width - 1, height - 1);
+                        if (header != null) {
+                            for (int i = 0; i < table.getColumnCount(); i++) {
+                                Rectangle rect = header.getHeaderRect(i);
+                                if (rect.width > 0) g.drawLine(rect.x + rect.width - 1, viewHeight,
+                                                               rect.x + rect.width - 1, height - 1);
+                            }
+                        } else if (table.getRowCount() > 0) {
+                            for (int i = 0; i < table.getColumnCount(); i++) {
+                                Rectangle rect = table.getCellRect(0, i, true);
+                                if (rect.width > 0) g.drawLine(rect.x + rect.width - 1, viewHeight,
+                                                               rect.x + rect.width - 1, height - 1);
+                            }
                         }
                     }
                 }
