@@ -44,78 +44,79 @@
 package org.netbeans.lib.profiler.ui.threads;
 
 import java.awt.BorderLayout;
-import java.awt.CardLayout;
-import java.awt.Color;
 import java.awt.Component;
-import java.awt.Dimension;
 import java.awt.FlowLayout;
-import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.image.BufferedImage;
+import java.util.HashSet;
 import java.util.ResourceBundle;
+import java.util.Set;
+import javax.swing.AbstractAction;
 import javax.swing.Action;
+import javax.swing.ActionMap;
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
-import javax.swing.JComboBox;
+import javax.swing.JComponent;
 import javax.swing.JLabel;
+import javax.swing.JMenuItem;
 import javax.swing.JPanel;
+import javax.swing.JPopupMenu;
 import javax.swing.JToggleButton;
 import javax.swing.RowFilter;
 import javax.swing.SortOrder;
 import javax.swing.SwingConstants;
-import javax.swing.SwingUtilities;
-import javax.swing.border.Border;
-import javax.swing.border.CompoundBorder;
 import javax.swing.table.AbstractTableModel;
 import javax.swing.table.JTableHeader;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumn;
-import javax.swing.table.TableRowSorter;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.results.DataManagerListener;
 import org.netbeans.lib.profiler.results.threads.ThreadData;
 import org.netbeans.lib.profiler.results.threads.ThreadsDataManager;
 import org.netbeans.lib.profiler.ui.Formatters;
 import org.netbeans.lib.profiler.ui.UIUtils;
+import org.netbeans.lib.profiler.ui.results.DataView;
+import org.netbeans.lib.profiler.ui.swing.FilterUtils;
 import org.netbeans.lib.profiler.ui.components.FlatToolBar;
 import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
 import org.netbeans.lib.profiler.ui.components.ProfilerToolbar;
 import org.netbeans.lib.profiler.ui.swing.ProfilerTable;
 import org.netbeans.lib.profiler.ui.swing.ProfilerTableContainer;
+import org.netbeans.lib.profiler.ui.swing.SearchUtils;
+import org.netbeans.lib.profiler.ui.swing.renderer.CheckBoxRenderer;
 import org.netbeans.lib.profiler.ui.swing.renderer.NumberRenderer;
-import org.netbeans.modules.profiler.api.icons.Icons;
-import org.netbeans.modules.profiler.api.icons.ProfilerIcons;
 
 /**
  *
  * @author Jiri Sedlacek
  */
-public class ThreadsPanel extends JPanel {
+public class ThreadsPanel extends DataView {
     
     private static ResourceBundle BUNDLE() {
         return ResourceBundle.getBundle("org.netbeans.lib.profiler.ui.threads.Bundle"); // NOI18N
     }
     
-    private static final String LAYOUT_ENABLED = "ENABLED"; // NOI18N
-    private static final String LAYOUT_DISABLED = "DISABLED"; // NOI18N
+    public static enum Filter { ALL, LIVE, FINISHED, SELECTED }
     
     private final ThreadsDataManager dataManager;
     private final ViewManager viewManager;
     
-    private ProfilerToolbar threadsToolbar;
+    private DataManagerListener listener;
+    
     private ProfilerTable threadsTable;
     private ProfilerTableContainer threadsTableContainer;
-    private JComboBox threadStateFilter;
+    private JPanel bottomPanel;
     private JPanel legendPanel;
     
-    private Component fitAct;
+    private Filter filter = Filter.ALL;
     
-    private JPanel contentPanel;
-    private JPanel notificationPanel;
-    private JButton enableThreadsMonitoringButton;
-    private JLabel enableThreadsMonitoringLabel1;
-    private JLabel enableThreadsMonitoringLabel2;
+    private final Set<Integer> selected = new HashSet();
+    private final Set<Integer> selectedApplied = new HashSet();
+    
+    private Component zoomInAction;
+    private Component zoomOutAction;
+    private Component fitAction;
     
     private ThreadTimeRelRenderer timeRelRenderer;
     
@@ -125,14 +126,14 @@ public class ThreadsPanel extends JPanel {
     public ThreadsPanel(ThreadsDataManager dataManager, Action saveView) {
         this.dataManager = dataManager;
         lastTimestamp = dataManager.getEndTime();
-        viewManager = new ViewManager(1, dataManager) {
+        viewManager = new ViewManager(2, dataManager) {
             public void columnWidthChanged(int column, int oldW, int newW) {
-                if (column == 1 && isFit()) threadsTable.updateColumnPreferredWidth(1);
+                if (column == 2 && isFit()) threadsTable.updateColumnPreferredWidth(2);
                 super.columnWidthChanged(column, oldW, newW);
             }
             public void columnOffsetChanged(int column, int oldO, int newO) {
                 super.columnOffsetChanged(column, oldO, newO);
-                if (column == 1) repaintTimeline();
+                if (column == 2) repaintTimeline();
             }
             public void zoomChanged(double oldZoom, double newZoom) {
                 super.zoomChanged(oldZoom, newZoom);
@@ -144,6 +145,36 @@ public class ThreadsPanel extends JPanel {
     }
     
     
+    public void setFilter(Filter filter) {
+        selectedApplied.clear();
+        if (Filter.SELECTED.equals(filter)) selectedApplied.addAll(selected);
+        
+        this.filter = filter;
+        threadsTable.addRowFilter(new ThreadsFilter());
+        
+        filterSelected(filter);
+    }
+    
+    public Filter getFilter() {
+        return filter;
+    }
+    
+    protected void filterSelected(Filter filter) {}
+    
+    public boolean hasSelectedThreads() {
+        return !selected.isEmpty();
+    }
+    
+    public void showSelectedColumn() {
+        threadsTable.setColumnVisibility(0, true);
+    }
+    
+    
+    public void cleanup() {
+        dataManager.removeDataListener(listener);
+    }
+    
+    
     private void initUI(Action saveView) {
         setOpaque(true);
         setBackground(new HTMLTextArea().getBackground());
@@ -151,20 +182,22 @@ public class ThreadsPanel extends JPanel {
         final AbstractTableModel threadsTableModel = new AbstractTableModel() {
             public String getColumnName(int columnIndex) {
                 if (columnIndex == 0) {
-                    return BUNDLE().getString("COL_Name"); // NOI18N
+                    return BUNDLE().getString("COL_Selected"); // NOI18N
                 } else if (columnIndex == 1) {
-                    return BUNDLE().getString("COL_Timeline"); // NOI18N
+                    return BUNDLE().getString("COL_Name"); // NOI18N
                 } else if (columnIndex == 2) {
-                    return CommonConstants.THREAD_STATUS_RUNNING_STRING;
+                    return BUNDLE().getString("COL_Timeline"); // NOI18N
                 } else if (columnIndex == 3) {
-                    return CommonConstants.THREAD_STATUS_SLEEPING_STRING;
+                    return CommonConstants.THREAD_STATUS_RUNNING_STRING;
                 } else if (columnIndex == 4) {
-                    return CommonConstants.THREAD_STATUS_WAIT_STRING;
+                    return CommonConstants.THREAD_STATUS_SLEEPING_STRING;
                 } else if (columnIndex == 5) {
-                    return CommonConstants.THREAD_STATUS_PARK_STRING;
+                    return CommonConstants.THREAD_STATUS_WAIT_STRING;
                 } else if (columnIndex == 6) {
-                    return CommonConstants.THREAD_STATUS_MONITOR_STRING;
+                    return CommonConstants.THREAD_STATUS_PARK_STRING;
                 } else if (columnIndex == 7) {
+                    return CommonConstants.THREAD_STATUS_MONITOR_STRING;
+                } else if (columnIndex == 8) {
                     return BUNDLE().getString("COL_Total"); // NOI18N
                 }
                 return null;
@@ -172,8 +205,10 @@ public class ThreadsPanel extends JPanel {
             
             public Class<?> getColumnClass(int columnIndex) {
                 if (columnIndex == 0) {
-                    return ThreadData.class;
+                    return Boolean.class;
                 } else if (columnIndex == 1) {
+                    return ThreadData.class;
+                } else if (columnIndex == 2) {
                     return ViewManager.RowView.class;
                 } else {
                     return Long.class;
@@ -185,33 +220,42 @@ public class ThreadsPanel extends JPanel {
             }
 
             public int getColumnCount() {
-                return 8;
+                return 9;
             }
 
             public Object getValueAt(int rowIndex, int columnIndex) {
                 if (columnIndex == 0) {
-                    return getData(rowIndex);
+                    return selected.contains(rowIndex);
                 } else if (columnIndex == 1) {
-                    return viewManager.getRowView(rowIndex);
+                    return getData(rowIndex);
                 } else if (columnIndex == 2) {
-                    return getData(rowIndex).getRunningTime(lastTimestamp);
+                    return viewManager.getRowView(rowIndex);
                 } else if (columnIndex == 3) {
-                    return getData(rowIndex).getSleepingTime(lastTimestamp);
+                    return getData(rowIndex).getRunningTime(lastTimestamp);
                 } else if (columnIndex == 4) {
-                    return getData(rowIndex).getWaitTime(lastTimestamp);
+                    return getData(rowIndex).getSleepingTime(lastTimestamp);
                 } else if (columnIndex == 5) {
-                    return getData(rowIndex).getParkTime(lastTimestamp);
+                    return getData(rowIndex).getWaitTime(lastTimestamp);
                 } else if (columnIndex == 6) {
-                    return getData(rowIndex).getMonitorTime(lastTimestamp);
+                    return getData(rowIndex).getParkTime(lastTimestamp);
                 } else if (columnIndex == 7) {
+                    return getData(rowIndex).getMonitorTime(lastTimestamp);
+                } else if (columnIndex == 8) {
                     return getData(rowIndex).getTotalTime(lastTimestamp);
                 }
                 
                 return null;
             }
             
+            public void setValueAt(Object aValue, int rowIndex, int columnIndex) {
+                if (columnIndex == 0) {
+                    if (Boolean.FALSE.equals(aValue)) selected.remove(rowIndex);
+                    else selected.add(rowIndex);
+                }
+            }
+            
             public boolean isCellEditable(int rowIndex, int columnIndex) {
-                return false;
+                return columnIndex == 0;
             }
             
             private ThreadData getData(int rowIndex) {
@@ -220,9 +264,9 @@ public class ThreadsPanel extends JPanel {
         
         };
         
-        threadsTable = new ProfilerTable(threadsTableModel, true, true, new int[] { 1 }) {
+        threadsTable = new ProfilerTable(threadsTableModel, true, true, new int[] { 2 }) {
             protected int computeColumnPreferredWidth(int modelIndex, int viewIndex, int firstRow, int lastRow) {
-                if (modelIndex != 1) return super.computeColumnPreferredWidth(modelIndex, viewIndex, firstRow, lastRow);
+                if (modelIndex != 2) return super.computeColumnPreferredWidth(modelIndex, viewIndex, firstRow, lastRow);
                 
                 viewManager.update();
                 
@@ -232,8 +276,43 @@ public class ThreadsPanel extends JPanel {
                     return viewManager.getViewWidth();
                 }
             }
+            public Object getUserValueForRow(int row) {
+                if (row == -1) return null;
+                if (row >= getModel().getRowCount()) return null; // #239936
+                return Integer.valueOf(convertRowIndexToModel(row));
+            }
+            protected void populatePopup(JPopupMenu popup, Object value, Object userValue) {
+                if (userValue != null) {
+                    final int row = ((Integer)userValue).intValue();
+                    final boolean sel = selected.contains(row);
+                    popup.add(new JMenuItem(sel ? BUNDLE().getString("ACT_UnselectThread") :
+                                                  BUNDLE().getString("ACT_SelectThread")) { // NOI18N
+                        protected void fireActionPerformed(ActionEvent e) {
+                            if (sel) selected.remove(row);
+                            else selected.add(row);
+                            threadsTableModel.fireTableDataChanged();
+                            if (!sel) showSelectedColumn();
+                        }
+                    });
+
+                    popup.addSeparator();
+                }
+                
+                popup.add(createCopyMenuItem());
+                popup.addSeparator();
+                
+                popup.add(new JMenuItem(FilterUtils.ACTION_FILTER) {
+                    protected void fireActionPerformed(ActionEvent e) { activateFilter(); }
+                });
+                popup.add(new JMenuItem(SearchUtils.ACTION_FIND) {
+                    protected void fireActionPerformed(ActionEvent e) { activateSearch(); }
+                });
+            }
         };
-        threadsTable.setColumnToolTips(new String[] { BUNDLE().getString("DESC_Name"), // NOI18N
+        threadsTable.setColumnVisibility(0, false);
+        threadsTable.setMainColumn(1);
+        threadsTable.setColumnToolTips(new String[] { BUNDLE().getString("DESC_Selected"), // NOI18N
+                                                      BUNDLE().getString("DESC_Name"), // NOI18N
                                                       BUNDLE().getString("DESC_Timeline"), // NOI18N
                                                       BUNDLE().getString("DESC_Running"), // NOI18N
                                                       BUNDLE().getString("DESC_Sleeping"), // NOI18N
@@ -242,34 +321,41 @@ public class ThreadsPanel extends JPanel {
                                                       BUNDLE().getString("DESC_Monitor"), // NOI18N
                                                       BUNDLE().getString("DESC_Total") }); // NOI18N
         threadsTable.setDefaultSortOrder(1, SortOrder.ASCENDING);
-        threadsTable.setSortColumn(1);
-        threadsTable.setFitWidthColumn(1);
+        threadsTable.setDefaultSortOrder(2, SortOrder.ASCENDING);
+        threadsTable.setSecondarySortColumn(1); // Simple way for stable sorting, should use threadID
+        threadsTable.setSortColumn(2);
+        threadsTable.setFitWidthColumn(2);
         NameStateRenderer nameStateRenderer = new NameStateRenderer();
         nameStateRenderer.setText("THREADnameTOsetupCOLUMNwidth"); // NOI18N
-        threadsTable.setDefaultColumnWidth(0, nameStateRenderer.getPreferredSize().width);
+        threadsTable.setColumnRenderer(0, new CheckBoxRenderer());
         threadsTable.setDefaultRenderer(ThreadData.class, nameStateRenderer);
         threadsTable.setDefaultRenderer(ViewManager.RowView.class, new TimelineRenderer(viewManager));
+        int w = new JLabel(threadsTable.getColumnName(0)).getPreferredSize().width;
+        threadsTable.setDefaultColumnWidth(0, w + 15);
+        threadsTable.setDefaultColumnWidth(1, nameStateRenderer.getPreferredSize().width);
         
         final JTableHeader header = threadsTable.getTableHeader();
         TableCellRenderer headerRenderer = header.getDefaultRenderer();
-        header.setDefaultRenderer(new TimelineHeaderRenderer(headerRenderer, 1, viewManager));
+        header.setDefaultRenderer(new TimelineHeaderRenderer(headerRenderer, 2, viewManager));
         
-        Number refTime = new Long(123456789);
+        Number refTime = new Long(1234567);
         
         timeRelRenderer = new ThreadTimeRelRenderer(dataManager);
-        timeRelRenderer.setValue(refTime, -1);
-        threadsTable.setDefaultColumnWidth(timeRelRenderer.getPreferredSize().width);
+        timeRelRenderer.setMaxValue(refTime.longValue());
+        threadsTable.setDefaultColumnWidth(timeRelRenderer.getNoBarWidth());
         threadsTable.setDefaultRenderer(Long.class, timeRelRenderer);
         
         NumberRenderer numberRenderer = new NumberRenderer(Formatters.millisecondsFormat());
         numberRenderer.setValue(refTime, -1);
-        threadsTable.setDefaultColumnWidth(7, numberRenderer.getPreferredSize().width);
-        threadsTable.setColumnRenderer(7, numberRenderer);
+        threadsTable.setDefaultColumnWidth(8, numberRenderer.getPreferredSize().width);
+        threadsTable.setColumnRenderer(8, numberRenderer);
         
-        threadsTable.setColumnVisibility(3, false);
         threadsTable.setColumnVisibility(4, false);
         threadsTable.setColumnVisibility(5, false);
         threadsTable.setColumnVisibility(6, false);
+        threadsTable.setColumnVisibility(7, false);
+        
+        threadsTable.providePopupMenu(true);
         
         threadsTableContainer = new ProfilerTableContainer(threadsTable, false, viewManager);
         
@@ -297,119 +383,57 @@ public class ThreadsPanel extends JPanel {
         monitorLegend.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 0));
         legendPanel.add(monitorLegend);
         
-        threadsToolbar = ProfilerToolbar.create(true);
-        if (saveView != null) {
-            threadsToolbar.add(saveView);
-            threadsToolbar.addSeparator();
-        }
-        
-        final Action zoomInAction = viewManager.zoomInAction();
-        threadsToolbar.add(new JButton(zoomInAction) {
+        final Action zoomIn = viewManager.zoomInAction();
+        zoomInAction = new JButton(zoomIn) {
             protected void fireActionPerformed(ActionEvent e) {
                 super.fireActionPerformed(e);
-                Object newOffset = zoomInAction.getValue(ViewManager.PROP_NEW_OFFSET);
+                Object newOffset = zoomIn.getValue(ViewManager.PROP_NEW_OFFSET);
                 if (newOffset != null) {
                     int _newOffset = ((Integer)newOffset).intValue();
-                    threadsTable.setColumnOffset(1, _newOffset);
+                    threadsTable.setColumnOffset(2, _newOffset);
                 }
                 threadsTableModel.fireTableDataChanged();
             }
             public boolean isEnabled() {
                 return threadsTable.isShowing() && super.isEnabled();
             }
-        });
-        
-        final Action zoomOutAction = viewManager.zoomOutAction();
-        threadsToolbar.add(new JButton(zoomOutAction) {
-            protected void fireActionPerformed(ActionEvent e) {
-                super.fireActionPerformed(e);
-                Object newOffset = zoomOutAction.getValue(ViewManager.PROP_NEW_OFFSET);
-                if (newOffset != null) {
-                    int _newOffset = ((Integer)newOffset).intValue();
-                    threadsTable.setColumnOffset(1, _newOffset);
-                }
-                threadsTableModel.fireTableDataChanged();
-            }
-            public boolean isEnabled() {
-                return threadsTable.isShowing() && super.isEnabled();
-            }
-        });
-        
-        fitAct = threadsToolbar.add(new JToggleButton(viewManager.fitAction()) {
-            protected void fireActionPerformed(ActionEvent e) {
-                super.fireActionPerformed(e);
-                threadsTableModel.fireTableDataChanged();
-            }
-        });
-        fitAct.setEnabled(false);
-        
-        threadsToolbar.addSeparator();
-        
-        threadsToolbar.addSpace(3);
-        threadsToolbar.add(new JLabel(BUNDLE().getString("LBL_View")) { // NOI18N
-            public boolean isEnabled() {
-                return threadsTable.isShowing() && super.isEnabled();
-            }
-        });
-        threadsToolbar.addSpace(5);
-        
-        threadStateFilter = new JComboBox(new String[] { BUNDLE().getString("OPT_AllThreads"), // NOI18N
-                                                         BUNDLE().getString("OPT_LiveThreads"), // NOI18N
-                                                         BUNDLE().getString("OPT_FinishedThreads") // NOI18N
-                                                       }) {
-            public Dimension getMaximumSize() {
-                return super.getPreferredSize();
-            }
-            protected void fireActionEvent() {
-                super.fireActionEvent();
-                updateFilter();
-            }
-            public boolean isEnabled() {
-                return threadsTable.isShowing() && super.isEnabled();
-            }
         };
-        threadsToolbar.add(threadStateFilter);
         
-        contentPanel = new JPanel(new BorderLayout());
-        contentPanel.setOpaque(true);
-        contentPanel.setBackground(getBackground());
-        contentPanel.add(threadsTableContainer, BorderLayout.CENTER);
-        contentPanel.add(legendPanel, BorderLayout.SOUTH);
+        final Action zoomOut = viewManager.zoomOutAction();
+        zoomOutAction = new JButton(zoomOut) {
+            protected void fireActionPerformed(ActionEvent e) {
+                super.fireActionPerformed(e);
+                Object newOffset = zoomOut.getValue(ViewManager.PROP_NEW_OFFSET);
+                if (newOffset != null) {
+                    int _newOffset = ((Integer)newOffset).intValue();
+                    threadsTable.setColumnOffset(2, _newOffset);
+                }
+                threadsTableModel.fireTableDataChanged();
+            }
+            public boolean isEnabled() {
+                return threadsTable.isShowing() && super.isEnabled();
+            }
+        };
         
-        Border myRolloverBorder = new CompoundBorder(new FlatToolBar.FlatRolloverButtonBorder(Color.GRAY, Color.LIGHT_GRAY),
-                                                     new FlatToolBar.FlatMarginBorder());
-
-        enableThreadsMonitoringLabel1 = new JLabel(BUNDLE().getString("MSG_ThreadsDisabled")); // NOI18N
-        enableThreadsMonitoringLabel1.setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 3));
-        enableThreadsMonitoringLabel1.setForeground(Color.DARK_GRAY);
-
-        enableThreadsMonitoringButton = new JButton(Icons.getIcon(ProfilerIcons.VIEW_THREADS_32));
-        enableThreadsMonitoringButton.setToolTipText(BUNDLE().getString("DESC_ThreadsDisabled")); // NOI18N
-        enableThreadsMonitoringButton.setContentAreaFilled(false);
-        enableThreadsMonitoringButton.setMargin(new Insets(3, 3, 3, 3));
-        enableThreadsMonitoringButton.setVerticalTextPosition(SwingConstants.BOTTOM);
-        enableThreadsMonitoringButton.setHorizontalTextPosition(SwingConstants.CENTER);
-        enableThreadsMonitoringButton.setRolloverEnabled(true);
-        enableThreadsMonitoringButton.setBorder(myRolloverBorder);
-        enableThreadsMonitoringButton.getAccessibleContext().setAccessibleName(BUNDLE().getString("DESC_ThreadsDisabled")); // NOI18N
-
-        enableThreadsMonitoringLabel2 = new JLabel(BUNDLE().getString("MSG_NoProfiling")); // NOI18N
-        enableThreadsMonitoringLabel2.setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 0));
-        enableThreadsMonitoringLabel2.setForeground(Color.DARK_GRAY);
-        enableThreadsMonitoringLabel2.setVisible(false);
-
-        notificationPanel = new JPanel(new FlowLayout(FlowLayout.LEADING, 0, 15));
-        notificationPanel.setBackground(threadsTable.getBackground());
-        UIUtils.decorateProfilerPanel(notificationPanel);
-        notificationPanel.add(enableThreadsMonitoringLabel1);
-        notificationPanel.add(enableThreadsMonitoringButton);
-        notificationPanel.add(enableThreadsMonitoringLabel2);
+        fitAction = new JToggleButton(viewManager.fitAction()) {
+            protected void fireActionPerformed(ActionEvent e) {
+                super.fireActionPerformed(e);
+                threadsTableModel.fireTableDataChanged();
+            }
+        };
+        fitAction.setEnabled(false);
         
-        setLayout(new CardLayout());
-        add(notificationPanel, LAYOUT_DISABLED);
-        add(contentPanel, LAYOUT_ENABLED);
+        bottomPanel = new JPanel(new BorderLayout());
+        bottomPanel.setOpaque(false);
+        bottomPanel.add(legendPanel, BorderLayout.SOUTH);
         
-        dataManager.addDataListener(new DataManagerListener() {
+        setOpaque(true);
+        setBackground(UIUtils.getProfilerResultsBackground());
+        setLayout(new BorderLayout());
+        add(threadsTableContainer, BorderLayout.CENTER);
+        add(bottomPanel, BorderLayout.SOUTH);
+        
+        listener = new DataManagerListener() {
             private boolean firstChange = true;
             public void dataChanged() {
                 lastTimestamp = dataManager.getEndTime();
@@ -422,51 +446,64 @@ public class ThreadsPanel extends JPanel {
             public void dataReset() {
                 viewManager.reset();
                 firstChange = true;
-                timeRelRenderer.setBasis(0);
+                timeRelRenderer.setMaxValue(0);
                 threadsTableModel.fireTableDataChanged();
             }
+        };
+        dataManager.addDataListener(listener);
+        
+        registerActions();
+    }
+    
+    private void registerActions() {
+        ActionMap map = getActionMap();
+        
+        map.put(FilterUtils.FILTER_ACTION_KEY, new AbstractAction() {
+            public void actionPerformed(ActionEvent e) { activateFilter(); }
         });
         
-        updateFilter();
+        map.put(SearchUtils.FIND_ACTION_KEY, new AbstractAction() {
+            public void actionPerformed(ActionEvent e) { activateSearch(); }
+        });
+    }
+    
+    protected ProfilerTable getResultsComponent() {
+        return threadsTable;
+    }
+    
+    protected boolean hasBottomFilterFindMargin() {
+        return true;
+    }
+    
+    protected void addFilterFindPanel(JComponent comp) {
+        bottomPanel.add(comp, BorderLayout.NORTH);
     }
     
     private void repaintTimeline() {
         JTableHeader header = threadsTable.getTableHeader();
         TableColumn draggedColumn = header.getDraggedColumn();
-        if (draggedColumn != null && draggedColumn.getModelIndex() == 1) {
+        if (draggedColumn != null && draggedColumn.getModelIndex() == 2) {
             header.repaint();
         } else {
-            int _column = threadsTable.convertColumnIndexToView(1);
+            int _column = threadsTable.convertColumnIndexToView(2);
             header.repaint(header.getHeaderRect(_column));
         }
     }
     
-    private void updateFilter() {
-        RowFilter filter = null;
-        switch (threadStateFilter.getSelectedIndex()) {
-            case 1:
-                filter = new RowFilter() {
-                    public boolean include(RowFilter.Entry entry) {
-                        ThreadData data = (ThreadData)entry.getValue(0);
-                        return ThreadData.isAliveState(data.getLastState());
-                    }
-                };
-                break;
-            case 2:
-                filter = new RowFilter() {
-                    public boolean include(RowFilter.Entry entry) {
-                        ThreadData data = (ThreadData)entry.getValue(0);
-                        return !ThreadData.isAliveState(data.getLastState());
-                    }
-                };
-                break;
-        }
-        TableRowSorter sorter = (TableRowSorter)threadsTable.getRowSorter();
-        sorter.setRowFilter(filter);
+    public Component getToolbar() {
+        return null;
     }
     
-    public Component getToolbar() {
-        return threadsToolbar.getComponent();
+    public Component getZoomIn() {
+        return zoomInAction;
+    }
+    
+    public Component getZoomOut() {
+        return zoomOutAction;
+    }
+    
+    public Component getFitWidth() {
+        return fitAction;
     }
     
     public BufferedImage getCurrentViewScreenshot(boolean onlyVisibleArea) {
@@ -482,33 +519,45 @@ public class ThreadsPanel extends JPanel {
     }
     
     public void threadsMonitoringDisabled() {
-        ((CardLayout)getLayout()).show(this, LAYOUT_DISABLED);
-        fitAct.setEnabled(false);
-        threadsToolbar.getComponent().repaint();
+        fitAction.setEnabled(false);
     }
 
     public void threadsMonitoringEnabled() {
-        ((CardLayout)getLayout()).show(this, LAYOUT_ENABLED);
-        fitAct.setEnabled(true);
-        threadsToolbar.getComponent().repaint();
+        fitAction.setEnabled(true);
     }
     
     public void profilingSessionStarted() {
-        enableThreadsMonitoringButton.setEnabled(true);
-        enableThreadsMonitoringButton.setVisible(true);
-        enableThreadsMonitoringLabel1.setVisible(true);
-        enableThreadsMonitoringLabel2.setVisible(false);
+        selected.clear();
+        if (!selectedApplied.isEmpty()) setFilter(Filter.LIVE);
     }
     
     public void profilingSessionFinished() {
-        enableThreadsMonitoringButton.setEnabled(false);
-        enableThreadsMonitoringButton.setVisible(false);
-        enableThreadsMonitoringLabel1.setVisible(false);
-        enableThreadsMonitoringLabel2.setVisible(true);
     }
     
     public void addThreadsMonitoringActionListener(ActionListener listener) {
-        enableThreadsMonitoringButton.addActionListener(listener);
+    }
+    
+    
+    private final class ThreadsFilter extends RowFilter {
+        
+        public boolean include(RowFilter.Entry entry) {
+            ThreadData data = (ThreadData)entry.getValue(1);
+            switch (filter) {
+                case LIVE: return ThreadData.isAliveState(data.getLastState());
+                case FINISHED: return !ThreadData.isAliveState(data.getLastState());
+                case SELECTED: return selectedApplied.contains(entry.getIdentifier());
+                default: return true;
+            }
+        }
+        
+        public boolean equals(Object o) {
+            return o instanceof ThreadsFilter;
+        }
+        
+        public int hashCode() {
+            return Integer.MAX_VALUE - 11;
+        }
+        
     }
     
 }
