@@ -347,7 +347,8 @@ public class TargetAppRunner implements CommonConstants {
            || CommonConstants.JDK_18_STRING.equals(jdkVersion)
            || CommonConstants.JDK_19_STRING.equals(jdkVersion)
            || CommonConstants.JDK_100_STRING.equals(jdkVersion)
-           || CommonConstants.JDK_110_STRING.equals(jdkVersion)) {
+           || CommonConstants.JDK_110_STRING.equals(jdkVersion)
+           || CommonConstants.JDK_120_STRING.equals(jdkVersion)) {
             return true;
         }
 
@@ -707,8 +708,9 @@ public class TargetAppRunner implements CommonConstants {
             || jdkVer.equals(JDK_18_STRING)
             || jdkVer.equals(JDK_19_STRING)
             || jdkVer.equals(JDK_100_STRING)
-            || jdkVer.equals(JDK_110_STRING)) {
-            // for now the 1.6 and 1.7 and 1.8 and 9 and 10 and 11 profiling uses the same agent as 1.5
+            || jdkVer.equals(JDK_110_STRING)
+            || jdkVer.equals(JDK_120_STRING)) {
+            // for now the 1.6 and 1.7 and 1.8 and 9 and 10 and 11 and 12 profiling uses the same agent as 1.5
             jdkVer = JDK_15_STRING;
         }
 
@@ -765,7 +767,8 @@ public class TargetAppRunner implements CommonConstants {
             || jdk.equals(Platform.JDK_18_STRING)
             || jdk.equals(Platform.JDK_19_STRING)
             || jdk.equals(Platform.JDK_100_STRING)
-            || jdk.equals(Platform.JDK_110_STRING)) {
+            || jdk.equals(Platform.JDK_110_STRING)
+            || jdk.equals(Platform.JDK_120_STRING)) {
             String jfNativeLibFullName = Platform.getAgentNativeLibFullName(settings.getJFluidRootDirName(), false,
                                                                             settings.getTargetJDKVersionString(),
                                                                             settings.getSystemArchitecture());
