@@ -45,6 +45,7 @@ package org.netbeans.lib.profiler.classfile;
 
 import org.netbeans.lib.profiler.classfile.ClassInfo.LocalVariableTables;
 import org.netbeans.lib.profiler.classfile.ClassInfo.LocalVariableTypeTables;
+import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.instrumentation.JavaClassConstants;
 import org.netbeans.lib.profiler.utils.StringUtils;
 
@@ -301,6 +302,8 @@ public class ClassFileParser implements JavaClassConstants {
                     classRefsNo++;
                 case CONSTANT_String:
                 case CONSTANT_MethodType:
+                case CONSTANT_Module:
+                case CONSTANT_Package:
                     curBufPos += 2;
 
                     break;
@@ -311,6 +314,7 @@ public class ClassFileParser implements JavaClassConstants {
                 case CONSTANT_NameAndType:
                 case CONSTANT_Integer:
                 case CONSTANT_Float:
+                case CONSTANT_Dynamic:
                 case CONSTANT_InvokeDynamic:
                     curBufPos += 4;
 
@@ -393,8 +397,8 @@ public class ClassFileParser implements JavaClassConstants {
         superClassIdx = nextChar();
 
         if (cpTags[superClassIdx] != CONSTANT_Class) {
-            if ((superClassIdx == 0) && classInfo.name.equals("java/lang/Object")) {  // NOI18N
-                classInfo.superName = "java/lang/Object"; // NOI18N
+            if ((superClassIdx == 0) && classInfo.name.equals(CommonConstants.OBJECT_SLASHED_CLASS_NAME)) {
+                classInfo.superName = CommonConstants.OBJECT_SLASHED_CLASS_NAME;
             } else {
                 throw classFileReadException("Bad reference to super class name"); // NOI18N
             }
