@@ -184,8 +184,8 @@ public class Platform implements CommonConstants {
 
         if (jdkString.equals(JDK_17_STRING) || jdkString.equals(JDK_18_STRING)
             || jdkString.equals(JDK_19_STRING) || jdkString.equals(JDK_100_STRING)
-            || jdkString.equals(JDK_110_STRING)) {
-            // for now, we use the same libs for 1.6 and 1.7 and 1.8 and 1.9 and 10 and 11
+            || jdkString.equals(JDK_110_STRING) || jdkString.equals(JDK_120_STRING)) {
+            // for now, we use the same libs for 1.6 and 1.7 and 1.8 and 1.9 and 10 and 11 and 12
             jdkString = JDK_16_STRING;
         }
 
@@ -313,6 +313,8 @@ public class Platform implements CommonConstants {
             jdkVersion = JDK_100;
         } else if (javaVersion.equals("11") || javaVersion.equals("11-ea") || javaVersion.startsWith("11.")) { // NOI18N
             jdkVersion = JDK_110;
+        } else if (javaVersion.equals("12") || javaVersion.equals("12-ea") || javaVersion.startsWith("12.")) { // NOI18N
+            jdkVersion = JDK_120;
         } else if (javaVersion.equals("CVM")) { // NOI18N
             jdkVersion = JDK_CVM;
         } else {
@@ -349,6 +351,7 @@ public class Platform implements CommonConstants {
             case JDK_19: return JDK_19_STRING;
             case JDK_100: return JDK_100_STRING;
             case JDK_110: return JDK_110_STRING;
+            case JDK_120: return JDK_120_STRING;
             case JDK_CVM: return JDK_CVM_STRING;
             case JDK_UNSUPPORTED: return JDK_UNSUPPORTED_STRING;
         }
@@ -607,7 +610,8 @@ public class Platform implements CommonConstants {
                || CommonConstants.JDK_18_STRING.equals(jdkVersionString)
                || CommonConstants.JDK_19_STRING.equals(jdkVersionString)
                || CommonConstants.JDK_100_STRING.equals(jdkVersionString)
-               || CommonConstants.JDK_110_STRING.equals(jdkVersionString);
+               || CommonConstants.JDK_110_STRING.equals(jdkVersionString)
+               || CommonConstants.JDK_120_STRING.equals(jdkVersionString);
     }
 
     /**
@@ -622,6 +626,7 @@ public class Platform implements CommonConstants {
 		   jdkVersionString.equals(JDK_19_STRING) ||
 		   jdkVersionString.equals(JDK_100_STRING) ||
 		   jdkVersionString.equals(JDK_110_STRING) ||
+		   jdkVersionString.equals(JDK_120_STRING) ||
 		   jdkVersionString.equals(JDK_CVM_STRING)));
     }
 
