@@ -43,6 +43,9 @@
 
 package org.netbeans.lib.profiler.heap;
 
+import java.io.DataInputStream;
+import java.io.DataOutputStream;
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -52,6 +55,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.NoSuchElementException;
 import java.util.Set;
 
 
@@ -121,7 +125,7 @@ class ClassDump extends HprofObject implements JavaClass {
     public List /*<Field>*/ getFields() {
         List filedsList = (List) classDumpSegment.fieldsCache.get(this);
         if (filedsList == null) {
-            filedsList = computeFields();
+            filedsList = Collections.unmodifiableList(computeFields());
             classDumpSegment.fieldsCache.put(this,filedsList);
         }
         return filedsList;
@@ -132,8 +136,11 @@ class ClassDump extends HprofObject implements JavaClass {
             return -1;
         }
 
-        return classDumpSegment.getMinimumInstanceSize()
-               + getHprofBuffer().getInt(fileOffset + classDumpSegment.instanceSizeOffset);
+        int size = getRawInstanceSize();
+        if (!classDumpSegment.newSize) {
+            size += classDumpSegment.getMinimumInstanceSize();
+        }
+        return size;
     }
 
     public long getRetainedSizeByClass() {
@@ -202,6 +209,14 @@ class ClassDump extends HprofObject implements JavaClass {
         return instancesList;
     }
 
+    public Iterator /*<Instance>*/ getInstancesIterator() {
+        int instancesCount = getInstancesCount();
+        if (instancesCount == 0) {
+            return Collections.EMPTY_LIST.iterator();
+        }
+        return new InstancesIterator(instancesCount);
+    }
+
     public int getInstancesCount() {
         if (instances == 0) {
             getHprof().computeInstances();
@@ -223,7 +238,7 @@ class ClassDump extends HprofObject implements JavaClass {
     }
 
     public Collection /*<JavaClass>*/ getSubClasses() {
-        List classes = classDumpSegment.hprofHeap.getAllClasses();
+        List classes = getHprof().getAllClasses();
         List subclasses = new ArrayList(classes.size() / 10);
         Map subclassesMap = new HashMap((classes.size() * 4) / 3);
 
@@ -348,6 +363,10 @@ class ClassDump extends HprofObject implements JavaClass {
         return (int) (cpOffset - (fileOffset + classDumpSegment.constantPoolSizeOffset));
     }
 
+    int getRawInstanceSize() {
+        return getHprofBuffer().getInt(fileOffset + classDumpSegment.instanceSizeOffset);
+    }
+
     HprofHeap getHprof() {
         return classDumpSegment.hprofHeap;
     }
@@ -480,4 +499,59 @@ class ClassDump extends HprofObject implements JavaClass {
 
         return b;
     }
+    
+    private class InstancesIterator implements Iterator {
+        
+        private long instancesCount;
+        private long[] offset;
+        TagBounds allInstanceDumpBounds;
+        HprofHeap heap;
+        long classId;
+        
+        InstancesIterator(long ic) {
+            instancesCount = ic;
+            allInstanceDumpBounds = getHprof().getAllInstanceDumpBounds();
+            offset = new long[] { firstInstanceOffset };
+            heap = getHprof();
+            classId = getJavaClassId();
+
+        }
+
+        
+        public boolean hasNext() {
+            if (instancesCount>0 && offset[0] < allInstanceDumpBounds.endOffset) {
+                return true;
+            }
+            return false;
+        }
+
+        public Object next() {
+            while (hasNext()) {
+                Instance i = heap.getInstanceByOffset(offset, ClassDump.this, classId);
+                if (i != null) {
+                    instancesCount--;
+                    return i;
+                }
+            }
+            throw new NoSuchElementException();
+        } 
+    }
+
+    //---- Serialization support
+    void writeToStream(DataOutputStream out) throws IOException {
+        out.writeLong(fileOffset);
+        out.writeInt(instances);
+        out.writeLong(firstInstanceOffset);
+        out.writeLong(loadClassOffset);
+        out.writeLong(retainedSizeByClass);        
+    }
+
+    ClassDump(ClassDumpSegment segment, long offset, DataInputStream dis) throws IOException {
+        this(segment, offset);
+        instances = dis.readInt();
+        firstInstanceOffset = dis.readLong();
+        loadClassOffset = dis.readLong();
+        retainedSizeByClass = dis.readLong();        
+    }
+
 }
