@@ -43,18 +43,26 @@
 
 package org.netbeans.lib.profiler.instrumentation;
 
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.classfile.BaseClassInfo;
 import org.netbeans.lib.profiler.classfile.ClassLoaderTable;
 import org.netbeans.lib.profiler.classfile.ClassRepository;
 import org.netbeans.lib.profiler.client.ClientUtils.SourceCodeSelection;
 import org.netbeans.lib.profiler.client.RuntimeProfilingPoint;
+import org.netbeans.lib.profiler.filters.InstrumentationFilter;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
-import org.netbeans.lib.profiler.wireprotocol.*;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.List;
+import org.netbeans.lib.profiler.utils.StringUtils;
+import org.netbeans.lib.profiler.wireprotocol.ClassLoadedCommand;
+import org.netbeans.lib.profiler.wireprotocol.Command;
+import org.netbeans.lib.profiler.wireprotocol.InstrumentMethodGroupCommand;
+import org.netbeans.lib.profiler.wireprotocol.InstrumentMethodGroupResponse;
+import org.netbeans.lib.profiler.wireprotocol.MethodInvokedFirstTimeCommand;
+import org.netbeans.lib.profiler.wireprotocol.MethodLoadedCommand;
+import org.netbeans.lib.profiler.wireprotocol.RootClassLoadedCommand;
 
 
 /**
@@ -104,6 +112,7 @@ public class Instrumentor implements CommonConstants {
 
     public int getClassId(String className, int classLoaderId) {
         BaseClassInfo clazz;
+        InstrumentationFilter filter = settings.getInstrumentationFilter();
 
         if (className.charAt(0) == '[') { // array , need special lookup
                                           // strip L and ; from className, see ClassFileParser.classNameAtCPIndex
@@ -112,12 +121,19 @@ public class Instrumentor implements CommonConstants {
                 int elIndex = className.indexOf('L');
                 className = new StringBuffer(className).deleteCharAt(className.length() - 1).deleteCharAt(elIndex).toString();
             }
+            String filterName = StringUtils.userFormClassName(className);
+            if (!filter.passes(filterName.replace('.', '/'))) { // NOI18N
+                return -1;
+            }
 
             clazz = ClassRepository.lookupSpecialClass(className);
             if (clazz.getInstrClassId() == -1) {
                 clazz.setInstrClassId(oms.getNextClassId(className));
             }
         } else {
+            if (!filter.passes(className.replace('.', '/'))) { // NOI18N
+                return -1;
+            }
             clazz = ClassRepository.lookupClassOrCreatePlaceholder(className, classLoaderId);
         }
 
@@ -168,7 +184,7 @@ public class Instrumentor implements CommonConstants {
             return null;
         }
 
-        return (String[]) rootClassNames.toArray(new String[rootClassNames.size()]);
+        return (String[]) rootClassNames.toArray(new String[0]);
     }
 
     public void setSavedSourceCodeSelection(SourceCodeSelection[] s) {
@@ -177,8 +193,6 @@ public class Instrumentor implements CommonConstants {
 
     public void setStatusInfoFromSourceCodeSelection(SourceCodeSelection[] s)
                                               throws ClassNotFoundException, BadLocationException, IOException, ClassFormatError {
-        ClassRepository.CodeRegionBCI location = null;
-
         if (s.length > 0) {
             SourceCodeSelection sel = s[0];
 
@@ -232,7 +246,7 @@ public class Instrumentor implements CommonConstants {
             byte[] classFileBytes = clcmd.getClassFileBytes();
 
             if (classFileBytes != null) {
-                ClassRepository.addVMSuppliedClassFile(clcmd.getClassName(), thisAndParentLoaderData[0], classFileBytes);
+                ClassRepository.addVMSuppliedClassFile(clcmd.getClassName().replace('.','/'), thisAndParentLoaderData[0], classFileBytes);
             }
 
             ClassLoaderTable.addChildAndParent(thisAndParentLoaderData);
@@ -291,23 +305,16 @@ public class Instrumentor implements CommonConstants {
         switch (status.currentInstrType) {
             case INSTR_RECURSIVE_FULL:
             case INSTR_RECURSIVE_SAMPLED:
-                imgr = createInitialInstrumentMethodGroupResponseForCallGraph(cmd.getAllLoadedClassNames(),
-                                                                              cmd.getAllLoadedClassLoaderIds(),
-                                                                              cmd.getCachedClassFileBytes());
+                imgr = createInitialInstrumentMethodGroupResponseForCallGraph(cmd);
 
                 break;
             case INSTR_CODE_REGION:
-                imgr = createInitialInstrumentMethodGroupResponseForCodeRegion(cmd.getAllLoadedClassNames(),
-                                                                               cmd.getAllLoadedClassLoaderIds(),
-                                                                               cmd.getCachedClassFileBytes());
+                imgr = createInitialInstrumentMethodGroupResponseForCodeRegion(cmd);
 
                 break;
             case INSTR_OBJECT_ALLOCATIONS:
             case INSTR_OBJECT_LIVENESS:
-                imgr = createInitialInstrumentMethodGroupResponseForMemoryProfiling(status.currentInstrType,
-                                                                                    cmd.getAllLoadedClassNames(),
-                                                                                    cmd.getAllLoadedClassLoaderIds(),
-                                                                                    cmd.getCachedClassFileBytes());
+                imgr = createInitialInstrumentMethodGroupResponseForMemoryProfiling(status.currentInstrType, cmd);
 
                 break;
             default:
@@ -420,9 +427,7 @@ public class Instrumentor implements CommonConstants {
     }
 
     // ------------------------------------ Transitive method closure instrumentation ------------------------------------
-    private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForCallGraph(String[] loadedClasses,
-                                                                                                 int[] loadedClassLoaderIds,
-                                                                                                 byte[][] cachedClassFileBytes) {
+    private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForCallGraph(RootClassLoadedCommand rootLoaded) {
         //System.err.println("*** Received root class load event for class names: ");
         //for (int i = 0; i < rootClassNames.length; i++) System.err.println("  " + rootClassNames[i] + "." +
         // rootMethodNames[i] + rootMethodSignatures[i]);
@@ -451,7 +456,7 @@ public class Instrumentor implements CommonConstants {
                 break;
         }
 
-        ret = ms.getInitialMethodsToInstrument(loadedClasses, loadedClassLoaderIds, cachedClassFileBytes, rootMethods);
+        ret = ms.getInitialMethodsToInstrument(rootLoaded, rootMethods);
 
         if (ret == null) {
             return new InstrumentMethodGroupResponse(null);
@@ -461,15 +466,15 @@ public class Instrumentor implements CommonConstants {
     }
 
     // ---------------------------------- Code region instrumentation ----------------------------------------------------
-    private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForCodeRegion(String[] loadedClasses,
-                                                                                                  int[] loadedClassLoaderIds,
-                                                                                                  byte[][] loadedClassBytes)
+    private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForCodeRegion(RootClassLoadedCommand rootLoaded)
         throws ClassNotFoundException, BadLocationException {
         CodeRegionMethodInstrumentor.resetLoadedClassData();
-        ClassManager.storeClassFileBytesForCustomLoaderClasses(loadedClasses, loadedClassLoaderIds, loadedClassBytes);
+        ClassManager.storeClassFileBytesForCustomLoaderClasses(rootLoaded);
 
         crms = new CodeRegionMethodInstrumentor(status, savedSourceCodeSelection);
 
+        String[] loadedClasses = rootLoaded.getAllLoadedClassNames();
+        int[] loadedClassLoaderIds = rootLoaded.getAllLoadedClassLoaderIds();
         Object[] ret = crms.getInitialInstrumentCodeRegionResponse(loadedClasses, loadedClassLoaderIds);
 
         if (ret == null) {
@@ -481,15 +486,13 @@ public class Instrumentor implements CommonConstants {
 
     // -------------------------------------- Memory profiling instrumentation -------------------------------------------
     private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForMemoryProfiling(int instrType,
-                                                                                                       String[] loadedClasses,
-                                                                                                       int[] loadedClassLoaderIds,
-                                                                                                       byte[][] cachedClassFileBytes) {
+                                                                         RootClassLoadedCommand rootLoaded) {
         //System.out.println("+++++++++ Received memory profiling instrumentation initialization event of type "
         // + instrType);
         //System.out.println("+++++++++ Number of target VM loaded classes: " + loadedClasses.length);
         oms = new ObjLivenessMethodInstrumentor(status, settings, (instrType == INSTR_OBJECT_LIVENESS));
 
-        Object[] ret = oms.getInitialMethodsToInstrument(loadedClasses, loadedClassLoaderIds, cachedClassFileBytes);
+        Object[] ret = oms.getInitialMethodsToInstrument(rootLoaded);
 
         if (ret == null) {
             return new InstrumentMethodGroupResponse(null);
