@@ -43,6 +43,8 @@
 
 package org.netbeans.lib.profiler.instrumentation;
 
+import java.util.ArrayList;
+import java.util.Collection;
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.classfile.BaseClassInfo;
 import org.netbeans.lib.profiler.classfile.DynamicClassInfo;
@@ -50,11 +52,11 @@ import org.netbeans.lib.profiler.classfile.PlaceholderClassInfo;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
 import org.netbeans.lib.profiler.utils.MiscUtils;
 import org.netbeans.lib.profiler.utils.Wildcards;
-import java.util.ArrayList;
+import org.netbeans.lib.profiler.wireprotocol.RootClassLoadedCommand;
 
 
 /**
- * Recursive method scaner that implements the lazy instrumentation scheme ("Scheme B" in the JFluid paper).
+ * Recursive method scanner that implements the lazy instrumentation scheme ("Scheme B" in the JFluid paper).
  *
  * @author Misha Dmitriev
  * @author Adrian Mos
@@ -77,7 +79,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
 
             for (int i = 0; i < len; i += 2) {
                 locateAndMarkMethodReachable(clazz, (String) methodNamesAndSigs.get(i), (String) methodNamesAndSigs.get(i + 1),
-                                             false, true, false);
+                                             false, true, false, false);
             }
         }
     }
@@ -90,10 +92,8 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
-    Object[] getInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds,
-                                                  byte[][] cachedClassFileBytes, RootMethods roots) {
-        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(loadedClasses, loadedClassLoaderIds,
-                                                                               cachedClassFileBytes);
+    Object[] getInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded, RootMethods roots) {
+        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(rootLoaded);
 
         rootMethods = roots;
 
@@ -125,9 +125,11 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
                 }
 
                 if (isMatch) { // This root class is loaded
-
+                    boolean isMarkerMethod = rootMethods.markerMethods[rIdx];
+                    boolean checkSubClasses = loadedClassInfos[j].isInterface() && isMarkerMethod;
+                    
                     if (Wildcards.isPackageWildcard(rootClassName) || Wildcards.isMethodWildcard(rootMethods.methodNames[rIdx])) {
-                        if (rootMethods.markerMethods[rIdx]) {
+                        if (isMarkerMethod) {
                             markAllMethodsMarker(loadedClassInfos[j]);
                         } else {
                             markAllMethodsRoot(loadedClassInfos[j]);
@@ -138,19 +140,19 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
 
                         for (int methodIdx = 0; methodIdx < methodNames.length; methodIdx++) {
                             locateAndMarkMethodReachable(loadedClassInfos[j], methodNames[methodIdx], signatures[methodIdx],
-                                                         false, false, false);
+                                                         false, false, checkSubClasses, isMarkerMethod);
                         }
                     } else {
                         markMethod(loadedClassInfos[j], rIdx);
                         locateAndMarkMethodReachable(loadedClassInfos[j], rootMethods.methodNames[rIdx],
-                                                     rootMethods.methodSignatures[rIdx], false, false, false);
+                                                     rootMethods.methodSignatures[rIdx], false, false, checkSubClasses, isMarkerMethod);
                     }
                 }
             }
         }
 
         locateAndMarkMethodReachable(javaClassForName("java/lang/ClassLoader", 0), "loadClass",   // NOI18N
-                                     "(Ljava/lang/String;)Ljava/lang/Class;", true, false, true); // NOI18N
+                                     "(Ljava/lang/String;)Ljava/lang/Class;", true, false, true, false); // NOI18N
 
         return createInstrumentedMethodPack();
     }
@@ -184,7 +186,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
             }
         }
 
-        boolean normallyFilteredOut = !instrFilter.passesFilter(className);
+        boolean normallyFilteredOut = !instrFilter.passes(className);
 
         if (!isRootClass) {
             if (normallyFilteredOut) {
@@ -223,6 +225,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
                 }
 
                 if (isMatch) { // it is indeed a root class
+                    boolean checkSubClasses = clazz.isInterface() && rootMethods.markerMethods[rIdx];
 
                     if (Wildcards.isPackageWildcard(rootClassName) || Wildcards.isMethodWildcard(rootMethods.methodNames[rIdx])) {
                         if (rootMethods.markerMethods[rIdx]) {
@@ -235,12 +238,12 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
                         String[] signatures = clazz.getMethodSignatures();
 
                         for (int methodIdx = 0; methodIdx < methodNames.length; methodIdx++) {
-                            locateAndMarkMethodReachable(clazz, methodNames[methodIdx], signatures[methodIdx], false, false, false);
+                            locateAndMarkMethodReachable(clazz, methodNames[methodIdx], signatures[methodIdx], false, false, checkSubClasses, false);
                         }
                     } else {
                         markMethod(clazz, rIdx);
                         locateAndMarkMethodReachable(clazz, rootMethods.methodNames[rIdx], rootMethods.methodSignatures[rIdx],
-                                                     false, false, false);
+                                                     false, false, checkSubClasses, true);
                     }
                 }
             }
@@ -295,26 +298,32 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
         methodName = methodName.intern();
         methodSignature = methodSignature.intern();
 
-        locateAndMarkMethodReachable(clazz, methodName, methodSignature, false, false, false);
+        locateAndMarkMethodReachable(clazz, methodName, methodSignature, false, false, false, false);
 
         //countReachableScannableMethods(clazz);
         return createInstrumentedMethodPack();
     }
 
     protected void findAndMarkOverridingMethodsReachable(DynamicClassInfo superClass, DynamicClassInfo subClass) {
+        if (!superClass.hasMethodReachable()) {
+            return;
+        }
+        
         String[] methodNames = superClass.getMethodNames();
         String[] methodSignatures = superClass.getMethodSignatures();
+        boolean lookupInSuper = superClass.isInterface();
 
         for (int i = 0; i < methodNames.length; i++) {
             if (!(superClass.isMethodVirtual(i) && superClass.isMethodReachable(i))) {
                 continue;
             }
+            boolean isMarker = superClass.isMethodMarker(i);
 
             // int idx = subClass.overridesVirtualMethod(superClass, i); - I once tried this, but with no visible effect. Strict check
             // for whether a method with the same name and signature in subclass really overrrides a method in superclass, given all other
             // conditions that we have already checked (e.g. that the method in superclass is not private), will only detect a pathological
             // case when both method versions are package-private. This is rare, if ever happens at all.
-            locateAndMarkMethodReachable(subClass, methodNames[i], methodSignatures[i], true, false, false);
+            locateAndMarkMethodReachable(subClass, methodNames[i], methodSignatures[i], true, lookupInSuper, false, isMarker);
         }
     }
 
@@ -349,7 +358,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
                 registerPlaceholder(pci);
             }
         } else {
-            locateAndMarkMethodReachable((DynamicClassInfo) refClazz, cms[1], cms[2], virtualCall, true, true);
+            locateAndMarkMethodReachable((DynamicClassInfo) refClazz, cms[1], cms[2], virtualCall, true, true, false);
         }
 
         offset = savedOffset;
@@ -364,7 +373,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
             if (clazz.implementsInterface("java/lang/Runnable") && (clazz.getName() != "java/lang/Thread")) { // NOI18N
 
                 boolean res = markMethodRoot(clazz, "run", "()V"); // NOI18N
-                locateAndMarkMethodReachable(clazz, "run", "()V", false, false, false); // NOI18N
+                locateAndMarkMethodReachable(clazz, "run", "()V", false, false, false, false); // NOI18N
 
                 return res;
             }
@@ -374,7 +383,7 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
     }
 
     private void instrumentClinit(DynamicClassInfo clazz) {
-        locateAndMarkMethodReachable(clazz, "<clinit>", "()V", false, false, false); // NOI18N        
+        locateAndMarkMethodReachable(clazz, "<clinit>", "()V", false, false, false, false); // NOI18N        
     }
 
     private void checkAndScanMethod(String className, int classLoaderId, String methodName, String methodSignature) {
@@ -408,10 +417,12 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
      * - checkSubclasses = true means that if a method is virtual (either because virtualCall == true or because this method is
      * really defined in this class and marked as virtual), methods that override it in subclasses of this class should also
      * be marked reachable.
+     * - setAsMarkerMethod = true means tag reachable method as marker method
      */
     private boolean locateAndMarkMethodReachable(DynamicClassInfo clazz, String methodName, String methodSignature,
                                                  boolean virtualCall, boolean lookupInSuperIfNotFoundInThis,
-                                                 boolean checkSubclasses) {
+                                                 boolean checkSubclasses, boolean setAsMarkerMethod) {
+        boolean constructorNotInstrumented = false;
         if (clazz == null) {
             return false; // Normally shouldn't happen, it's just development-time facilitation (introduced when working on 1.5 support)
         }
@@ -432,9 +443,12 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
             }
 
             if (clazz.isMethodNative(idx) || clazz.isMethodAbstract(idx)
-                    || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passesFilter(className))
-                    || (className == "java/lang/Object")) { // NOI18N  // Actually, just the Object.<init> method?
+                    || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passes(className))
+                    || (className == OBJECT_SLASHED_CLASS_NAME)) {  // Actually, just the Object.<init> method?
                 clazz.setMethodUnscannable(idx);
+            } else if (methodName == "<init>" && !status.canInstrumentConstructor && clazz.getMajorVersion()>50) {
+                clazz.setMethodUnscannable(idx);
+                constructorNotInstrumented = true;
             } else {
                 byte[] bytecode = clazz.getMethodBytecode(idx);
 
@@ -455,20 +469,30 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
             // Class is loaded, method is reachable and not unscannable are sufficient conditions for instrumenting method
             if (!clazz.isMethodUnscannable(idx)) {
                 markClassAndMethodForInstrumentation(clazz, idx);
+                if (setAsMarkerMethod) {
+                    clazz.setMethodMarker(idx);
+                }
+            } else if (constructorNotInstrumented) {
+                scanMethod(clazz, idx);
             }
         }
 
-        if (checkSubclasses && (((idx != -1) && clazz.isMethodVirtual(idx)) || ((idx == -1) && virtualCall))) {
+        if (checkSubclasses && (((idx != -1) && clazz.isMethodVirtual(idx)) || ((idx == -1) && virtualCall)) && className != OBJECT_SLASHED_CLASS_NAME) {
             ArrayList subclasses = clazz.getSubclasses();
 
             if (subclasses != null) {
+                preloadBytecodeForAllSubclasses(subclasses);
                 for (int i = 0; i < subclasses.size(); i++) {
+                    DynamicClassInfo subClass = (DynamicClassInfo) subclasses.get(i);
                     //System.out.println("Gonna scan subclass " + subclassNames.get(i) + " of class " + className + " for method " + methodName);
                     // DynamicClassInfo subClass = javaClassForName((String) subclassNames.get(i));
                     // if ((idx != -1 && subClass.overridesVirtualMethod(clazz, idx) != -1) || idx == -1) - see the comment in findAndMarkOverridingMethods()
                     // on why this seems to be of no use.
-                    locateAndMarkMethodReachable((DynamicClassInfo) subclasses.get(i), methodName, methodSignature, virtualCall,
-                                                 false, false);
+                    if (!subClass.isInterface()) {
+                        boolean searchSuper = clazz.isInterface() && !subclasses.contains(subClass.getSuperClass());
+                        locateAndMarkMethodReachable(subClass, methodName, methodSignature, virtualCall,
+                                                      searchSuper, false, setAsMarkerMethod);
+                    }
                 }
             }
         }
@@ -486,56 +510,50 @@ public class RecursiveMethodInstrumentor1 extends RecursiveMethodInstrumentor {
             DynamicClassInfo superClazz = clazz.getSuperClass();
 
             if ((superClazz != null) && (superClazz.getName() != clazz.getName())) {
-                if (locateAndMarkMethodReachable(superClazz, methodName, methodSignature, virtualCall, true, false)) {
+                if (locateAndMarkMethodReachable(superClazz, methodName, methodSignature, virtualCall, true, false, setAsMarkerMethod)) {
                     return true;
                 }
             }
         }
-
-        DynamicClassInfo[] interfaces = clazz.getSuperInterfaces();
-
-        if (interfaces == null) {
-            return false;
-        }
-
-        for (int i = 0; i < interfaces.length; i++) {
-            DynamicClassInfo intfClazz = interfaces[i];
-
-            if (intfClazz == null) {
-                continue;
-            }
-
-            if (locateAndMarkMethodReachable(intfClazz, methodName, methodSignature, virtualCall, true, false)) {
-                return true;
-            }
-        }
-
         return false;
     }
 
     //----------------------------------- Private implementation ------------------------------------------------
-    private DynamicClassInfo[] preGetInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds,
-                                                                byte[][] cachedClassFileBytes) {
+    private DynamicClassInfo[] preGetInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded) {
         //System.out.println("*** MS1: instr. initial: " + rootClassName);
         resetLoadedClassData();
-        storeClassFileBytesForCustomLoaderClasses(loadedClasses, loadedClassLoaderIds, cachedClassFileBytes);
+        storeClassFileBytesForCustomLoaderClasses(rootLoaded);
         initInstrMethodData();
 
+        String[] loadedClasses = rootLoaded.getAllLoadedClassNames();
+        int[] loadedClassLoaderIds = rootLoaded.getAllLoadedClassLoaderIds();
         DynamicClassInfo[] loadedClassInfos = new DynamicClassInfo[loadedClasses.length];
 
+        // preload all classes
         for (int i = 0; i < loadedClasses.length; i++) {
-            String className = loadedClasses[i].replace('.', '/').intern(); // NOI18N
-            DynamicClassInfo clazz = javaClassForName(className, loadedClassLoaderIds[i]);
+            DynamicClassInfo clazz = javaClassForName(loadedClasses[i], loadedClassLoaderIds[i]);
 
             if (clazz == null) {
                 continue;
             }
 
             clazz.setLoaded(true);
-            addToSubclassList(clazz, clazz);
             loadedClassInfos[i] = clazz;
         }
+        for (int i = 0; i < loadedClasses.length; i++) {
+            DynamicClassInfo clazz = javaClassForName(loadedClasses[i], loadedClassLoaderIds[i]);
+
+            if (clazz != null) {
+                addToSubclassList(clazz, clazz);
+            }
+        }
 
         return loadedClassInfos;
     }
+    
+    void preloadBytecodeForAllSubclasses(Collection classes) {
+        for (Object clazz : classes) {
+            ((DynamicClassInfo)clazz).preloadBytecode();
+        }
+    }
 }
