@@ -43,6 +43,7 @@
 
 package org.netbeans.lib.profiler.instrumentation;
 
+import java.util.ArrayList;
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.classfile.BaseClassInfo;
 import org.netbeans.lib.profiler.classfile.DynamicClassInfo;
@@ -50,11 +51,11 @@ import org.netbeans.lib.profiler.classfile.PlaceholderClassInfo;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
 import org.netbeans.lib.profiler.instrumentation.RecursiveMethodInstrumentor.ReachableMethodPlaceholder;
 import org.netbeans.lib.profiler.utils.Wildcards;
-import java.util.ArrayList;
+import org.netbeans.lib.profiler.wireprotocol.RootClassLoadedCommand;
 
 
 /**
- * Recursive method scaner that implements the eager instrumentation scheme ("Scheme A" in the JFluid paper).
+ * Recursive method scanner that implements the eager instrumentation scheme ("Scheme A" in the JFluid paper).
  *
  * @author Misha Dmitriev
  * @author Adrian Mos
@@ -92,10 +93,8 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
-    Object[] getInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds,
-                                                  byte[][] cachedClassFileBytes, RootMethods roots) {
-        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(loadedClasses, loadedClassLoaderIds,
-                                                                               cachedClassFileBytes);
+    Object[] getInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded, RootMethods roots) {
+        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(rootLoaded);
 
         rootMethods = roots;
 
@@ -184,7 +183,7 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
             }
         }
 
-        boolean normallyFilteredOut = !instrFilter.passesFilter(className);
+        boolean normallyFilteredOut = !instrFilter.passes(className);
 
         if (!isRootClass) {
             if (normallyFilteredOut) {
@@ -371,6 +370,7 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
      */
     private boolean checkAndScanMethod(DynamicClassInfo clazz, String methodName, String methodSignature, boolean virtualCall,
                                        boolean lookupInSuperIfNotFoundInThis, boolean checkSubclasses) {
+        boolean constructorNotInstrumented = false;
         String className = clazz.getName();
         int idx = clazz.getMethodIndex(methodName, methodSignature);
 
@@ -386,9 +386,12 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
                 }
 
                 if (clazz.isMethodNative(idx) || clazz.isMethodAbstract(idx)
-                        || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passesFilter(className))
-                        || (className == "java/lang/Object")) { // NOI18N  // Actually, just the Object.<init> method?
+                        || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passes(className))
+                        || (className == OBJECT_SLASHED_CLASS_NAME)) {  // Actually, just the Object.<init> method?
                     clazz.setMethodUnscannable(idx);
+                } else if (methodName == "<init>" && !status.canInstrumentConstructor && clazz.getMajorVersion()>50) {
+                    clazz.setMethodUnscannable(idx);
+                    constructorNotInstrumented = true;
                 } else {
                     bytecode = clazz.getMethodBytecode(idx);
 
@@ -420,6 +423,8 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
                 clazz.setMethodScanned(idx);
                 //if (!lookupInSuperIfNotFoundInThis && !checkSubclasses) System.out.println("Gonna scan potentially reachable " + className + "." + methodName + methodSignature);
                 scanBytecode(clazz, bytecode);
+            } else if (constructorNotInstrumented) {
+                scanBytecode(clazz, bytecode);
             }
         }
 
@@ -428,12 +433,16 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
 
             if (subclasses != null) {
                 for (int i = 0; i < subclasses.size(); i++) {
+                    DynamicClassInfo subClass = (DynamicClassInfo) subclasses.get(i);
                     //System.out.println("Gonna scan subclass " + subclassNames.get(i) + " of class " + className + " for method " + methodName);
                     // DynamicClassInfo subClass = javaClassForName((String) subclassNames.get(i));
                     // if ((idx != -1 && subClass.overridesVirtualMethod(clazz, idx) != -1) || idx == -1) - see the comment in findAndMarkOverridingMethods()
                     // on why this seems to be of no use.
-                    checkAndScanMethod((DynamicClassInfo) subclasses.get(i), methodName, methodSignature, virtualCall, false,
-                                       false);
+                    if (!subClass.isInterface()) {
+                        boolean searchSuper = clazz.isInterface() && !subclasses.contains(subClass.getSuperClass());
+                        checkAndScanMethod(subClass, methodName, methodSignature, virtualCall, searchSuper,
+                                           false);
+                    }
                 }
             }
         }
@@ -457,42 +466,24 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
             }
         }
 
-        DynamicClassInfo[] interfaces = clazz.getSuperInterfaces();
-
-        if (interfaces == null) {
-            return false;
-        }
-
-        for (int i = 0; i < interfaces.length; i++) {
-            DynamicClassInfo intfClazz = interfaces[i];
-
-            if (intfClazz == null) {
-                continue;
-            }
-
-            if (checkAndScanMethod(intfClazz, methodName, methodSignature, virtualCall, true, false)) {
-                return true;
-            }
-        }
-
         return false;
     }
 
     //----------------------------------- Private implementation ------------------------------------------------
-    private DynamicClassInfo[] preGetInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds,
-                                                                byte[][] cachedClassFileBytes) {
+    private DynamicClassInfo[] preGetInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded) {
         //System.out.println("*** MS2: instr. initial");
         resetLoadedClassData();
-        storeClassFileBytesForCustomLoaderClasses(loadedClasses, loadedClassLoaderIds, cachedClassFileBytes);
+        storeClassFileBytesForCustomLoaderClasses(rootLoaded);
         initInstrMethodData();
 
-        DynamicClassInfo[] loadedClassInfos = null;
+        DynamicClassInfo[] loadedClassInfos;
+        String[] loadedClasses = rootLoaded.getAllLoadedClassNames();
+        int[] loadedClassLoaderIds = rootLoaded.getAllLoadedClassLoaderIds();
         //if (instrumentSpawnedThreads) tmpClassInfos = new DynamicClassInfo[loadedClasses.length];
         loadedClassInfos = new DynamicClassInfo[loadedClasses.length]; //EJB Work: removed the condition in the above line as we need to return the temp array anyway (used to check for multiple roots, see the overloaded getInitialMethodsToInstrument )
 
         for (int i = 0; i < loadedClasses.length; i++) {
-            String className = loadedClasses[i].replace('.', '/').intern(); // NOI18N
-            DynamicClassInfo clazz = javaClassForName(className, loadedClassLoaderIds[i]);
+            DynamicClassInfo clazz = javaClassForName(loadedClasses[i], loadedClassLoaderIds[i]);
 
             if (clazz == null) {
                 continue;
