@@ -46,13 +46,13 @@ package org.netbeans.lib.profiler.instrumentation;
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.classfile.DynamicClassInfo;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
-import org.netbeans.lib.profiler.utils.StringUtils;
 import org.netbeans.lib.profiler.utils.Wildcards;
+import org.netbeans.lib.profiler.wireprotocol.RootClassLoadedCommand;
 
 
 /**
- * Recursive method scaner that implements the total instrumentation scheme.
- * In fact, it's not even a scaner, since it just instruments absolutely everything -
+ * Recursive method scanner that implements the total instrumentation scheme.
+ * In fact, it's not even a scanner, since it just instruments absolutely everything -
  * but it uses the same interface.
  *
  * @author Tomas Hurka
@@ -144,7 +144,7 @@ public class RecursiveMethodInstrumentor3 extends RecursiveMethodInstrumentor {
             }
         }
 
-        boolean normallyFilteredOut = !instrFilter.passesFilter(className);
+        boolean normallyFilteredOut = !instrFilter.passes(className);
 
         if (!isRootClass) {
             if (normallyFilteredOut) {
@@ -241,10 +241,8 @@ public class RecursiveMethodInstrumentor3 extends RecursiveMethodInstrumentor {
         return true;
     }
 
-    Object[] getInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds, byte[][] cachedClassFileBytes,
-                                           RootMethods roots) {
-        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(loadedClasses, loadedClassLoaderIds,
-                                                                               cachedClassFileBytes);
+    Object[] getInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded, RootMethods roots) {
+        DynamicClassInfo[] loadedClassInfos = preGetInitialMethodsToInstrument(rootLoaded);
 
         rootMethods = roots;
         checkForNoRootsSpecified(roots);
@@ -332,10 +330,12 @@ public class RecursiveMethodInstrumentor3 extends RecursiveMethodInstrumentor {
             clazz.setMethodReachable(idx);
 
             if (clazz.isMethodNative(idx) || clazz.isMethodAbstract(idx)
-                    || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passesFilter(className))
-                    || (className == "java/lang/Object") // NOI18N // Actually, just the Object.<init> method?
+                    || (!clazz.isMethodRoot(idx) && !clazz.isMethodMarker(idx) && !instrFilter.passes(className))
+                    || (className == OBJECT_SLASHED_CLASS_NAME) // Actually, just the Object.<init> method?
             ) {
                 clazz.setMethodUnscannable(idx);
+            } else if (clazz.getMethodName(idx) == "<init>" && !status.canInstrumentConstructor && clazz.getMajorVersion()>50) {
+                clazz.setMethodUnscannable(idx);
             } else {
                 byte[] bytecode = clazz.getMethodBytecode(idx);
 
@@ -378,21 +378,21 @@ public class RecursiveMethodInstrumentor3 extends RecursiveMethodInstrumentor {
     }
 
     //----------------------------------- Private implementation ------------------------------------------------
-    private DynamicClassInfo[] preGetInitialMethodsToInstrument(String[] loadedClasses, int[] loadedClassLoaderIds,
-                                                                byte[][] cachedClassFileBytes) {
+    private DynamicClassInfo[] preGetInitialMethodsToInstrument(RootClassLoadedCommand rootLoaded) {
         //System.out.println("*** MS2: instr. initial");
         reflectInvokeInstrumented = true; // We don't need to instrument reflection specially in this mode
 
         resetLoadedClassData();
-        storeClassFileBytesForCustomLoaderClasses(loadedClasses, loadedClassLoaderIds, cachedClassFileBytes);
+        storeClassFileBytesForCustomLoaderClasses(rootLoaded);
         initInstrMethodData();
 
-        DynamicClassInfo[] loadedClassInfos = null;
+        DynamicClassInfo[] loadedClassInfos;
+        String[] loadedClasses = rootLoaded.getAllLoadedClassNames();
+        int[] loadedClassLoaderIds = rootLoaded.getAllLoadedClassLoaderIds();
         loadedClassInfos = new DynamicClassInfo[loadedClasses.length]; //EJB Work: removed the condition in the above line as we need to return the temp array anyway (used to check for multiple roots, see the overloaded getInitialMethodsToInstrument )
 
         for (int i = 0; i < loadedClasses.length; i++) {
-            String className = loadedClasses[i].replace('.', '/').intern(); // NOI18N
-            DynamicClassInfo clazz = javaClassForName(className, loadedClassLoaderIds[i]);
+            DynamicClassInfo clazz = javaClassForName(loadedClasses[i], loadedClassLoaderIds[i]);
 
             if (clazz == null) {
                 // warning already issued in ClassRepository.lookupClass method, no need to do it again
