@@ -49,14 +49,18 @@ import java.io.DataOutputStream;
 import java.io.IOException;
 import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.WeakHashMap;
 import java.util.logging.Level;
+import org.netbeans.lib.profiler.client.ClientUtils;
 import org.netbeans.lib.profiler.results.CCTNode;
 import org.netbeans.lib.profiler.results.FilterSortSupport;
+import org.netbeans.lib.profiler.utils.Wildcards;
 
 
 /**
@@ -217,24 +221,26 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
     }
 
     public CPUCCTContainer getContainerForThread(int threadId, int view) {
-        if (threadCCTContainers[view] == null) {
-            generateDataForView(view);
-        }
-
+        generateDataForView(view);
+        
         return threadCCTContainers[view][getContainerIdForThreadId(threadId)];
     }
 
     public FlatProfileContainer getFlatProfile(int threadId, int view) {
-        if (threadCCTContainers[view] == null) {
-            generateDataForView(view);
-        }
-
+        generateDataForView(view);
+        
         if (threadId != -1) {
             return threadCCTContainers[view][getContainerIdForThreadId(threadId)].getFlatProfile();
         } else {
             return allThreadsMergedCCTContainers[view].getFlatProfile();
         }
     }
+    
+    public FlatProfileContainer getFlatProfile(Collection<Integer> threads, int view) {
+        if (threads == null) return getFlatProfile(-1, view);
+        else if (threads.size() == 1) return getFlatProfile(threads.iterator().next(), view);
+        else return createContainerForThreads(threads, view).getFlatProfile();
+    }
 
     // -- Views-related code
     public String[] getInstrMethodClasses(int view) {
@@ -259,6 +265,19 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
             return new String[] { instrMethodClassesViews[view][methodId], null, null };
         }
     }
+    
+    public ClientUtils.SourceCodeSelection getSourceCodeSelection(int methodId, int view) {
+        String[] sel = getMethodClassNameAndSig(methodId, view);
+        return sel[1] != null ? new ClientUtils.SourceCodeSelection(sel[0], sel[1], sel[2]):
+                         new ClientUtils.SourceCodeSelection(sel[0], Wildcards.ALLWILDCARD, null);
+    }
+    
+    public Map<Integer, ClientUtils.SourceCodeSelection> getMethodIDMap(int view) {
+        Map<Integer, ClientUtils.SourceCodeSelection> map = new HashMap();
+        for (int i = 0; i < instrMethodClassesViews[view].length; i++)
+            map.put(i, getSourceCodeSelection(i, view));
+        return map;
+    }
 
     public int getNInstrMethods() {
         return nInstrMethods;
@@ -269,9 +288,7 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
     }
 
     public PrestimeCPUCCTNode getReverseCCT(int threadId, int methodId, int view) {
-        if (threadCCTContainers[view] == null) {
-            generateDataForView(view);
-        }
+        generateDataForView(view);
 
         if (threadId >= 0) {
             return threadCCTContainers[view][getContainerIdForThreadId(threadId)].getReverseCCT(methodId);
@@ -283,13 +300,140 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
     }
 
     public PrestimeCPUCCTNode getRootNode(int view) {
-        if (threadCCTContainers[view] == null) {
-            generateDataForView(view);
-        }
+        generateDataForView(view);
 
         return rootNode[view];
     }
     
+    public PrestimeCPUCCTNode getRootNode(int view, Collection<Integer> threads, boolean merge) {
+        if (threads == null) {
+            if (merge == false) {
+                return fixNCalls(getRootNode(view));
+            } else {
+                int[] _threads = getThreadIds();
+                threads = new ArrayList(_threads.length);
+                for (int t : _threads) threads.add(t);
+            }
+        }
+        
+        PrestimeCPUCCTNode[] nodes = new PrestimeCPUCCTNode[threads.size()];
+        Iterator<Integer> threadIds = threads.iterator();
+        for (int i = 0; i < nodes.length; i++)
+            nodes[i] = getContainerForThread(threadIds.next(), view).getRootNode();
+        
+        generateDataForView(view);
+        
+        return merge ? new PrestimeCPUCCTNodeBacked(threadCCTContainers[view][0], mergedChildren(nodes)) :
+                       fixNCalls(new PrestimeCPUCCTNodeBacked(threadCCTContainers[view][0], nodes));
+    }
+    
+    // Workaround to display sum of invocations of all children for thread nodes
+    private PrestimeCPUCCTNode fixNCalls(PrestimeCPUCCTNode root) {
+        CCTNode[] children = root == null ? null : root.getChildren();
+        if (children != null) for (CCTNode node : children) {
+            PrestimeCPUCCTNode _root = (PrestimeCPUCCTNode)node;
+            _root.nCalls = 0;
+            CCTNode[] _children = _root.getChildren();
+            if (_children != null) for (CCTNode child : _children)
+                _root.addNCalls(((PrestimeCPUCCTNode)child).getNCalls());
+        }
+        return root;
+    }
+    
+    private PrestimeCPUCCTNode[] mergedChildren(PrestimeCPUCCTNode[] nodes) {
+        List<PrestimeCPUCCTNode> merged = new ArrayList();
+        
+        for (PrestimeCPUCCTNode node : nodes) {
+            CCTNode[] children = node.getChildren();
+            if (children != null) for (CCTNode n : children) {
+                int idx = merged.indexOf(n);
+                if (idx == -1) merged.add(((PrestimeCPUCCTNode)n).createCopy());
+                else merged.get(idx).merge(n);
+            }
+        }
+        
+        return merged.toArray(new PrestimeCPUCCTNode[0]);
+    }
+    
+    public PrestimeCPUCCTNode getReverseRootNode(final int view, Collection<Integer> threads, boolean merge) {
+        int[] threadIds = getThreadIds();
+        List<PrestimeCPUCCTNode> nodes = new ArrayList();
+        for (int i = 0; i < threadIds.length; i++) {
+            final int threadIdF = threadIds[i];
+            if (threads == null || threads.contains(threadIdF)) {
+                final CPUCCTContainer containerF = getContainerForThread(threadIdF, view);
+                final FlatProfileContainer flatF = containerF.getFlatProfile();
+                
+                class ThreadNodeBacked extends PrestimeCPUCCTNodeBacked {
+                    ThreadNodeBacked() {
+                        super(containerF, null);
+                        nCalls = (int)flatF.getNTotalInvocations();
+                        totalTime0 = containerF.getWholeGraphNetTime0();
+                        totalTime1 = containerF.isCollectingTwoTimeStamps() ? containerF.getWholeGraphNetTime1() : 0;
+                        nChildren = flatF.getNRows();
+                    }
+                    PrestimeCPUCCTNode createCopy() {
+                        ThreadNodeBacked copy = new ThreadNodeBacked();
+                        setupCopy(copy);
+                        return copy;
+                    }
+                    public PrestimeCPUCCTNode[] getChildren() {
+                        if (nChildren == 0) return null;
+                        
+                        if (children == null) {
+                            children = new PrestimeCPUCCTNode[flatF.getNRows()];
+                            for (int m = 0; m < children.length; m++) {
+                                final int mF = m;
+                                final int methodIdF = flatF.getMethodIdAtRow(m);
+                                
+                                class ReverseNodeBacked extends PrestimeCPUCCTNodeBacked {
+                                    ReverseNodeBacked() {
+                                        nChildren = 1;
+                                        container = ThreadNodeBacked.this.container;
+                                        methodId = methodIdF;
+                                        nCalls = flatF.getNInvocationsAtRow(mF);
+                                        totalTime0 = flatF.getTotalTimeInMcs0AtRow(mF);
+                                        totalTime1 = flatF.isCollectingTwoTimeStamps() ? flatF.getTotalTimeInMcs1AtRow(mF) : 0;
+                                        parent = ThreadNodeBacked.this;
+                                    }
+                                    PrestimeCPUCCTNode createCopy() {
+                                        ReverseNodeBacked copy = new ReverseNodeBacked();
+                                        setupCopy(copy);
+                                        return copy;
+                                    }
+                                    public PrestimeCPUCCTNode[] getChildren() {
+                                        if (nChildren == 0) return null;
+                                        
+                                        if (children == null) {
+                                            PrestimeCPUCCTNode r = getReverseCCT(threadIdF, methodIdF, view);
+                                            children = r.children;
+                                            nChildren = children == null ? 0 : children.length;
+                                            if (nChildren > 0) for (PrestimeCPUCCTNode ch : children) ch.parent = this;
+                                        }
+
+                                        return children;
+                                    }
+                                }
+                                
+                                children[m] = new ReverseNodeBacked();
+                            }
+                        }
+
+                        return children;
+                    }
+                }
+                
+                nodes.add(new ThreadNodeBacked());
+            }
+        }
+        
+        generateDataForView(view);
+        
+        PrestimeCPUCCTNode[] _nodes = nodes.toArray(new PrestimeCPUCCTNode[0]);
+        PrestimeCPUCCTNode root = new PrestimeCPUCCTNodeBacked(threadCCTContainers[view][0], merge ? mergedChildren(_nodes) : _nodes);
+        return fixNCalls(root);
+    }
+    
     public FilterSortSupport.Configuration getFilterSortInfo(CCTNode node) {
         return sortInfo(node);
     }
@@ -306,76 +450,76 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
     }
     
     public void filterForward(final String filter, final int filterType, final PrestimeCPUCCTNodeBacked root) {
-        FilterSortSupport.Configuration config = sortInfo(root);
-        config.setFilterInfo(filter, filterType);
-        
-        if (!FilterSortSupport.passesFilter(config, root.getNodeName())) {
-            root.setFilteredNode();
-        } else {
-            root.resetFilteredNode();
-        }
-        root.resetChildren();
+//        FilterSortSupport.Configuration config = sortInfo(root);
+//        config.setFilterInfo(filter, filterType);
+//        
+//        if (!FilterSortSupport.passesFilter(config, root.getNodeName())) {
+////            root.setFilteredNode();
+//        } else {
+////            root.resetFilteredNode();
+//        }
+//        root.resetChildren();
     }
     
     public void filterReverse(String filter, int filterType, PrestimeCPUCCTNodeFree root, int view) {
-        PrestimeCPUCCTNodeFree rev = (PrestimeCPUCCTNodeFree)getReverseCCT(
-                root.getContainer().getThreadId(), root.getMethodId(), view);
-        FilterSortSupport.Configuration config = sortInfo(root);
-        config.setFilterInfo(filter, filterType);
-        filter(config, rev);
-        root.children = rev.children;
-        if (root.children != null) {
-            for (PrestimeCPUCCTNode ch : root.children)
-                ch.parent = root;
-            
-            root.sortChildren(config.getSortBy(), config.getSortOrder());
-        }
-        if (!FilterSortSupport.passesFilter(config, root.getNodeName())) {
-            root.setFilteredNode();
-        } else {
-            root.resetFilteredNode();
-        }
+//        PrestimeCPUCCTNodeFree rev = (PrestimeCPUCCTNodeFree)getReverseCCT(
+//                root.getContainer().getThreadId(), root.getMethodId(), view);
+//        FilterSortSupport.Configuration config = sortInfo(root);
+//        config.setFilterInfo(filter, filterType);
+//        filter(config, rev);
+//        root.children = rev.children;
+//        if (root.children != null) {
+//            for (PrestimeCPUCCTNode ch : root.children)
+//                ch.parent = root;
+//            
+//            root.sortChildren(config.getSortBy(), config.getSortOrder());
+//        }
+//        if (!FilterSortSupport.passesFilter(config, root.getNodeName())) {
+////            root.setFilteredNode();
+//        } else {
+////            root.resetFilteredNode();
+//        }
     }
     
-    private void filter(FilterSortSupport.Configuration config, PrestimeCPUCCTNodeFree node) {
-        if (node.children != null) {
-            PrestimeCPUCCTNodeFree filtered = null;
-            List<PrestimeCPUCCTNodeFree> ch = new ArrayList();
-            for (PrestimeCPUCCTNode n : node.children) {
-                PrestimeCPUCCTNodeFree nn = (PrestimeCPUCCTNodeFree)n;
-                if (FilterSortSupport.passesFilter(config, nn.getNodeName())) {
-                    int i = ch.indexOf(nn);
-                    if (i == -1) ch.add(nn);
-                    else ch.get(i).merge(nn);
-                } else {
-                    if (filtered == null) {
-                        nn.setFilteredNode();
-                        filtered = nn;
-                        ch.add(nn);
-                    } else {
-                        filtered.merge(nn);
-                    }
-                }
-            }
-            
-            if (ch.isEmpty()) {
-                node.children = null;
-            } else {
-                if (node.isFilteredNode() && filtered != null && ch.size() == 1) {
-                    // "naive" approach, collapse simple chain of filtered out nodes
-                    PrestimeCPUCCTNodeFree n = ch.get(0);
-                    filter(config, n);
-                    node.children = n.children;
-                } else {
-                    node.children = ch.toArray(new PrestimeCPUCCTNodeFree[ch.size()]);
-                }
-            }
-            
-            if (node.children != null)
-                for (PrestimeCPUCCTNode n : node.children)
-                    filter(config, (PrestimeCPUCCTNodeFree)n);
-        }
-    }
+//    private void filter(FilterSortSupport.Configuration config, PrestimeCPUCCTNodeFree node) {
+//        if (node.children != null) {
+//            PrestimeCPUCCTNodeFree filtered = null;
+//            List<PrestimeCPUCCTNodeFree> ch = new ArrayList();
+//            for (PrestimeCPUCCTNode n : node.children) {
+//                PrestimeCPUCCTNodeFree nn = (PrestimeCPUCCTNodeFree)n;
+//                if (FilterSortSupport.passesFilter(config, nn.getNodeName())) {
+//                    int i = ch.indexOf(nn);
+//                    if (i == -1) ch.add(nn);
+//                    else ch.get(i).merge(nn);
+//                } else {
+//                    if (filtered == null) {
+////                        nn.setFilteredNode();
+//                        filtered = nn;
+//                        ch.add(nn);
+//                    } else {
+//                        filtered.merge(nn);
+//                    }
+//                }
+//            }
+//            
+//            if (ch.isEmpty()) {
+//                node.children = null;
+//            } else {
+//                if (node.isFiltered() && filtered != null && ch.size() == 1) {
+//                    // "naive" approach, collapse simple chain of filtered out nodes
+//                    PrestimeCPUCCTNodeFree n = ch.get(0);
+//                    filter(config, n);
+//                    node.children = n.children;
+//                } else {
+//                    node.children = ch.toArray(new PrestimeCPUCCTNodeFree[0]);
+//                }
+//            }
+//            
+//            if (node.children != null)
+//                for (PrestimeCPUCCTNode n : node.children)
+//                    filter(config, (PrestimeCPUCCTNodeFree)n);
+//        }
+//    }
 
     public int[] getThreadIds() {
         int[] ret = new int[threadCCTContainers[METHOD_LEVEL_VIEW].length];
@@ -401,6 +545,11 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
         return ret;
     }
     
+    public CPUResultsSnapshot createDiff(CPUResultsSnapshot snapshot) {
+        if (!(snapshot instanceof CPUResultsSnapshot)) return null;
+        return new CPUResultsDiff(this, (CPUResultsSnapshot)snapshot);
+    }
+    
     void readFromSnapshot(CPUResultsSnapshot s) {
         beginTime = s.beginTime;
         timeTaken = s.timeTaken;
@@ -541,6 +690,8 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
     }
 
     protected PrestimeCPUCCTNode createRootNodeForAllThreads(int view) {
+        generateDataForView(view);
+        
         CPUCCTContainer[] ccts = threadCCTContainers[view];
         int len = ccts.length;
         PrestimeCPUCCTNode[] threadNodes = new PrestimeCPUCCTNode[len];
@@ -559,7 +710,26 @@ public class CPUResultsSnapshot extends ResultsSnapshot {
 
         return allThreadsMergedCCTContainers[view].getRootNode();
     }
+    
+    protected CPUCCTContainer createContainerForThreads(Collection<Integer> threads, int view) {
+        generateDataForView(view);
+        
+        CPUCCTContainer[] ccts = threadCCTContainers[view];
+        PrestimeCPUCCTNode[] threadNodes = new PrestimeCPUCCTNode[threads.size()];
+        int threadIdx = 0;
 
+        for (int i = 0; i < ccts.length; i++) {
+            if (threads.contains(ccts[i].getThreadId())) {
+                PrestimeCPUCCTNode tRootNode = ccts[i].getRootNode();
+                if (tRootNode.isThreadNode()) threadNodes[threadIdx++] = tRootNode;
+                else threadNodes[threadIdx++] = new PrestimeCPUCCTNodeBacked(ccts[i],
+                                                new PrestimeCPUCCTNode[] { tRootNode });
+            }
+        }
+
+        return new AllThreadsMergedCPUCCTContainer(this, threadNodes, view);
+    }
+    
     private void debugValues() {
         LOGGER.log(Level.FINEST, "collectingTwoTimeStamps: {0}", collectingTwoTimeStamps); // NOI18N
         LOGGER.log(Level.FINEST, "threadCCTContainers.length: {0}", debugLength(threadCCTContainers)); // NOI18N
