@@ -57,6 +57,8 @@ import org.netbeans.lib.profiler.filters.InstrumentationFilter;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
 import org.netbeans.lib.profiler.results.RuntimeCCTNode;
+import org.netbeans.lib.profiler.results.cpu.cct.nodes.MethodCPUCCTNode;
+import org.netbeans.lib.profiler.results.cpu.cct.nodes.TimedCPUCCTNode;
 
 /**
  *
@@ -102,6 +104,8 @@ public class StackTraceSnapshotBuilder {
         new MethodInfo("sun.nio.ch.WindowsSelectorImpl$SubSelector","poll0[native](long, int, int[], int[], int[], long) : int"), // NOI18N
         new MethodInfo("java.net.PlainSocketImpl", "socketConnect[native]"), // NOI18N
         new MethodInfo("java.net.PlainSocketImpl", "socketConnect[native](java.net.InetAddress, int, int) : void"), // NOI18N
+        new MethodInfo("sun.nio.ch.ServerSocketChannelImpl", "accept0[native]"), // NOI18N
+        new MethodInfo("sun.nio.ch.ServerSocketChannelImpl", "accept0[native](java.io.FileDescriptor, java.io.FileDescriptor, java.net.InetSocketAddress[]) : int"), // NOI18N
     });
 
     private InstrumentationFilter filter;
@@ -626,7 +630,6 @@ public class StackTraceSnapshotBuilder {
                 instrMethodSigs[counter] = "";
                 counter++;
             }
-            addStacktrace(new java.lang.management.ThreadInfo[0], currentDumpTimeStamp+1);
             return new CPUResultsSnapshot(since, System.currentTimeMillis(), ccgb, ccgb.isCollectingTwoTimeStamps(), instrMethodClasses, instrMethodNames, instrMethodSigs, miCount);
         }
     }
@@ -690,6 +693,38 @@ public class StackTraceSnapshotBuilder {
             }
         }
 
-    }
+        @Override
+        protected void applyDiffAtGetResultsMoment(ThreadInfo ti) {
+            long time0 = getDumpAbsTimeStamp();
+            long diff = time0 - ti.topMethodEntryTime0;
 
+            if (diff>0) {
+                applyDiffToTopNode(ti, diff);
+                ti.diffAtGetResultsMoment = diff;
+            }
+        }
+
+        @Override
+        protected void undoDiffAtGetResultsMoment(ThreadInfo ti) {
+            if (ti.diffAtGetResultsMoment>0) {
+                applyDiffToTopNode(ti, -ti.diffAtGetResultsMoment);
+                ti.diffAtGetResultsMoment = 0;
+            }
+        }
+
+        private void applyDiffToTopNode(ThreadInfo ti, long diff) {
+            TimedCPUCCTNode top = ti.peek();
+
+            if (top instanceof MethodCPUCCTNode) {
+                top.addNetTime0(diff);
+                if (isCollectingTwoTimeStamps()) {
+                    SampledThreadInfo sti = lastStackTrace.get().get(Long.valueOf(ti.threadId));
+
+                    if (sti!=null && sti.getThreadState() == Thread.State.RUNNABLE) {
+                        top.addNetTime1(diff);
+                    }
+                }
+            }
+        }
+    }
 }
