@@ -69,7 +69,7 @@ public class ProfilerRuntime implements CommonConstants {
 
         public void handleFirstTimeMethodInvoke(char methodId);
 
-        public int handleFirstTimeVMObjectAlloc(String className, int classLoaderId);
+        public int handleFirstTimeVMObjectAlloc(String className, int definingClassLoaderId);
 
         public void handleReflectiveInvoke(Method method);
     }
@@ -772,10 +772,12 @@ public class ProfilerRuntime implements CommonConstants {
     }
 
     private static void initThreadInfo(ThreadInfo ti) {
-        if (ti.evBuf == null) {
-            if (!ti.isInitialized()) ti.initialize();
+        if (!ti.isInitialized()) {
+            ti.initialize();
             ti.useEventBuffer();
             writeThreadCreationEvent(ti);
+        } else if (ti.evBuf == null) {
+            ti.useEventBuffer();
         }
     }
 
@@ -802,6 +804,7 @@ public class ProfilerRuntime implements CommonConstants {
     private static void doResetProfilerCollectors(int instrType) {
         ThreadInfo.resetThreadInfoTable();
         globalEvBufPos = 0;
+        knownMonitors = new HashSet();
 
         if (eventBuffer != null) {
             eventBuffer[globalEvBufPos++] = RESET_COLLECTORS;
