@@ -50,6 +50,7 @@ import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
 import org.netbeans.lib.profiler.server.system.Classes;
 import org.netbeans.lib.profiler.server.system.GC;
 import org.netbeans.lib.profiler.server.system.HeapDump;
+import org.netbeans.lib.profiler.server.system.ThreadDump;
 import org.netbeans.lib.profiler.server.system.Threads;
 import org.netbeans.lib.profiler.server.system.Timers;
 import org.netbeans.lib.profiler.wireprotocol.*;
@@ -118,7 +119,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         private String branding;
 
         /**
-         * current sufix which will be returned in next calling nextElement
+         * current suffix which will be returned in next calling nextElement
          */
         private String current;
 
@@ -128,7 +129,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         private boolean defaultInProgress = false;
 
         /**
-         * this flag means, if empty sufix was exported yet
+         * this flag means, if empty suffix was exported yet
          */
         private boolean empty = false;
 
@@ -161,15 +162,15 @@ public class ProfilerServer extends Thread implements CommonConstants {
         //~ Methods --------------------------------------------------------------------------------------------------------------
 
         /**
-         * Tests if there is any sufix.
+         * Tests if there is any suffix.
          */
         public boolean hasNext() {
             return (current != null);
         }
 
         /**
-         * @return next sufix.
-         * @throws NoSuchElementException if there is no more locale sufix.
+         * @return next suffix.
+         * @throws NoSuchElementException if there is no more locale suffix.
          */
         public Object next() throws NoSuchElementException {
             if (current == null) {
@@ -292,6 +293,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
                     }
 
                     if (stopped) {
+                        ThreadInfo.removeProfilerServerThread(this);
                         return;
                     }
 
@@ -353,12 +355,14 @@ public class ProfilerServer extends Thread implements CommonConstants {
     private static String WAITING_ON_PORT_MSG = "Profiler Agent: Waiting for connection on port {0} (Protocol version: {1})"; // NOI18N
     private static String WAITING_ON_PORT_TIMEOUT_MSG = "Profiler Agent: Waiting for connection on port {0}, timeout {1} seconds (Protocol version: {2})"; // NOI18N
     private static String CONNECTION_EXCEPTION_MSG = "Profiler Agent Error: Exception when trying to establish connection with client:\n{0}"; // NOI18N
+    private static String CONNECTION_EXCEPTION_BIND_MSG = "Profiler Agent Error: Make sure the previously profiled process has been fully terminated"; // NOI18N
     private static String CONNECTION_TIMEOUT_MSG = "Profiler Agent Error: Timed out trying to establish connection with client"; // NOI18N
     private static String AGENT_ERROR_MSG = "Profiler Agent Error: {0}"; // NOI18N
     private static String CONNECTION_INTERRUPTED_MSG = "Profiler Agent Error: Connection with client interrupted"; // NOI18N
     private static String COMMAND_EXCEPTION_MSG = "Profiler Agent Error: Exception when handling command from client:\n{0}"; // NOI18N
     private static String RESPONSE_EXCEPTION_MSG = "Profiler Agent Error: Exception when trying to send response or command to client:\n{0}"; // NOI18N
     private static String CONNECTION_CLOSED_MSG = "Profiler Agent: Connection with agent closed"; // NOI18N
+    private static String CONNECTION_CLOSED_EX_MSG = "Profiler Agent: Connection with agent closed (ProfilingSessionStatus was null)"; // NOI18N
     private static String INCORRECT_AGENT_ID_MSG = "Profiler Agent Warning: Wrong agentId specified: {0}"; // NOI18N
     private static String THREAD_EXCEPTION_MSG = "Profiler Agent Error: Exception in executeInSeparateThread()"; // NOI18N
     private static String THREAD_WAIT_EXCEPTION_MSG = "Profiler Agent Error: Exception in wait in SeparateCmdExecutionThread"; // NOI18N
@@ -500,6 +504,9 @@ public class ProfilerServer extends Thread implements CommonConstants {
      * @see #ATTACH_DYNAMIC
      */
     public static void activate(String fullJFluidPath, int portNo, final int activateCode, int timeOut) {
+        if (connectionOpen) {
+            throw new IllegalStateException("Connection already opened on port "+portNo);   // NOI18N
+        }
         try {
             _fullJFluidPath = fullJFluidPath;
             _portNo = portNo;
@@ -634,7 +641,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             ClassBytesLoader.preloadClasses(remote);
         } else {
             System.out.println(LOCAL_SESSION_MSG);
-            if (Platform.getJDKVersionNumber() == JDK_19) {
+            if (Platform.getJDKVersionNumber() >= JDK_19) {
                 // This is to preload some classes that can otherwise be loaded at inappropriate time and cause class load hook firing.
                 ClassBytesLoader.preloadClasses(remote);
             }
@@ -694,6 +701,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         } else {
             preemptExit = false;
         }
+        ThreadInfo.removeProfilerServerThread(this);
     }
 
     public void sendClassLoaderUnloadingCommand() {
@@ -811,12 +819,14 @@ public class ProfilerServer extends Thread implements CommonConstants {
             WAITING_ON_PORT_MSG = messages.getString("ProfilerServer_WaitingOnPortMsg"); // NOI18N
             WAITING_ON_PORT_TIMEOUT_MSG = messages.getString("ProfilerServer_WaitingOnPortTimeoutMsg"); // NOI18N
             CONNECTION_EXCEPTION_MSG = messages.getString("ProfilerServer_ConnectionExceptionMsg"); // NOI18N
+            CONNECTION_EXCEPTION_BIND_MSG = messages.getString("ProfilerServer_ConnectionExceptionBindMsg"); // NOI18N
             CONNECTION_TIMEOUT_MSG = messages.getString("ProfilerServer_ConnectionTimeoutMsg"); // NOI18N
             AGENT_ERROR_MSG = messages.getString("ProfilerServer_AgentErrorMsg"); // NOI18N
             CONNECTION_INTERRUPTED_MSG = messages.getString("ProfilerServer_ConnectionInterruptedMsg"); // NOI18N
             COMMAND_EXCEPTION_MSG = messages.getString("ProfilerServer_CommandExceptionMsg"); // NOI18N
             RESPONSE_EXCEPTION_MSG = messages.getString("ProfilerServer_ResponseExceptionMsg"); // NOI18N
             CONNECTION_CLOSED_MSG = messages.getString("ProfilerServer_ConnectionClosedMsg"); // NOI18N
+            CONNECTION_CLOSED_EX_MSG = messages.getString("ProfilerServer_ConnectionClosedExMsg"); // NOI18N
             INCORRECT_AGENT_ID_MSG = messages.getString("ProfilerServer_IncorrectAgentIdMsg"); // NOI18N
             THREAD_EXCEPTION_MSG = messages.getString("ProfilerServer_ThreadExceptionMsg"); // NOI18N
             THREAD_WAIT_EXCEPTION_MSG = messages.getString("ProfilerServer_ThreadWaitExceptionMsg"); // NOI18N
@@ -855,7 +865,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
     private static void cleanupOnShutdown() {
         Monitors.shutdown();
         ProfilerInterface.disableProfilerHooks();
-        ProfilerRuntimeCPU.enableProfiling(false); 
+        ProfilerInterface.disableProfiling();
 
         // Bugfix for 65947: Profiler blocks a finishing profiled application
         // The following connectionOpen = false is done just to prevent error message from listenToClient(). When the connection
@@ -1229,7 +1239,9 @@ public class ProfilerServer extends Thread implements CommonConstants {
 
     private synchronized void closeConnection() {
         connectionOpen = false;
-        status.targetAppRunning = false;
+        if (status != null) {
+            status.targetAppRunning = false;
+        }
         removeInfoFile();
 
         try {
@@ -1240,7 +1252,9 @@ public class ProfilerServer extends Thread implements CommonConstants {
         } catch (IOException ex) {
         }
 
-        if (status.runningInAttachedMode) {
+        if (status == null) {
+            System.out.println(CONNECTION_CLOSED_EX_MSG);
+        } else if (status.runningInAttachedMode) {
             System.out.println(CONNECTION_CLOSED_MSG);
         }
 
@@ -1278,6 +1292,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             connectionFailed = true;
         } catch (IOException ex) {
             System.err.println(MessageFormat.format(CONNECTION_EXCEPTION_MSG, new Object[] { ex }));
+            if (ex instanceof BindException) System.err.println(CONNECTION_EXCEPTION_BIND_MSG);
             connectionFailed = true;
         } finally {
             //removeInfoFile ();
@@ -1461,10 +1476,11 @@ public class ProfilerServer extends Thread implements CommonConstants {
                 lockContentionMonitoring = scipCmd.isLockContentionMonitoringEnabled();
                 ProfilerRuntime.setLockContentionMonitoringEnabled(lockContentionMonitoring);
                 ProfilerRuntimeCPU.setNProfiledThreadsLimit(scipCmd.getNProfiledThreadsLimit());
+                ProfilerRuntimeCPU.setStackDepthLimit(scipCmd.getStackDepthLimit());
                 ProfilerRuntimeCPUSampledInstr.setSamplingInterval(scipCmd.getSamplingInterval());
                 ProfilerRuntimeSampler.setSamplngFrequency(scipCmd.getThreadsSamplingFrequency());
                 ProfilerRuntimeMemory.setSamplingInterval((short) scipCmd.getObjAllocStackSamplingInterval());
-                ProfilerRuntimeMemory.setSamplingDepth(scipCmd.getObjAllocStackSamplingDepth());
+                ProfilerRuntimeMemory.setStackSamplingDepth(scipCmd.getObjAllocStackSamplingDepth());
                 ProfilerRuntimeObjLiveness.setRunGCOnGetResults(scipCmd.getRunGCOnGetResultsInMemoryProfiling());
                 threadSampling = scipCmd.isThreadsSamplingEnabled();
                 waitTracking = scipCmd.isWaitTrackingEnabled();
@@ -1590,6 +1606,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
                                                                      System.getProperty("user.dir"), // NOI18N
                                                                      status.jvmArguments, status.javaCommand,
                                                                      System.getProperty("os.name"), // NOI18N
+                                                                     InstrumentConstructorTest.test(),
                                                                      Runtime.getRuntime().maxMemory(),
                                                                      System.currentTimeMillis(), Timers.getCurrentTimeInCounts(),
                                                                      getAgentId()
@@ -1663,15 +1680,28 @@ public class ProfilerServer extends Thread implements CommonConstants {
 
                 break;
             case Command.GET_HEAP_HISTOGRAM:
-                HeapHistogramResponse resp = ProfilerInterface.computeHistogram();
+                Response resp = ProfilerInterface.computeHistogram();
                 sendComplexResponseToClient(resp);
                 
+                break;
+            case Command.TAKE_THREAD_DUMP:
+                Response tdResp = new ThreadDumpResponse(ThreadDump.isJDK15(), new Date(), ThreadDump.takeThreadDump());
+                sendComplexResponseToClient(tdResp);
+                
+                break;
+            case Command.GET_CLASS_FILE_BYTES:
+                //System.out.println(cmd);
+                GetClassFileBytesCommand getCmd = (GetClassFileBytesCommand) cmd;
+                byte[][] bytes = ProfilerInterface.getClassFileBytes(getCmd.getClasses(), getCmd.getClassLoaderIds());
+                sendComplexResponseToClient(new GetClassFileBytesResponse(bytes));
+                
                 break;
         }
     }
 
     private void doExit() {
-        // try to call LifecycleManager in NetBeans first
+
+        // try Lookup.getDefault().lookup(ClassLoader.class)
         try {
             Class lookupClz = Thread.currentThread().getContextClassLoader().loadClass("org.openide.util.Lookup"); // NOI18N
             Method instMethod = lookupClz.getMethod("getDefault", new Class[0]); // NOI18N
@@ -1681,6 +1711,16 @@ public class ProfilerServer extends Thread implements CommonConstants {
             if (instance != null) {
                 ClassLoader clInstance = (ClassLoader)lookupMethod.invoke(instance, new Class[]{ClassLoader.class});
                 if (clInstance != null) {
+                    // try to call Ide.quit in JDeveloper
+                    try {
+                        Class oracleIde = clInstance.loadClass("oracle.ide.Ide"); // NOI18N
+                        Method ideQuitMethod = oracleIde.getMethod("quit", new Class[0]); // NOI18N
+                        ideQuitMethod.invoke(oracleIde, new Object[0]);
+                        return;
+                    } catch (Exception ex) {
+                        // ignore
+                    }
+                    // try to call LifecycleManager in NetBeans
                     Class lcmInstanceClz = clInstance.loadClass("org.openide.LifecycleManager"); // NOI18N
                     Method lcmInstMethod = lcmInstanceClz.getMethod("getDefault", new Class[0]); // NOI18N
                     Method lcmExitMethod = lcmInstanceClz.getMethod("exit", new Class[0]); // NOI18N
@@ -1692,6 +1732,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         } catch (Exception ex) {
             // ignore
         }
+        
         // fall through a general system exit
         System.exit(-1);
     }
