@@ -369,7 +369,7 @@ public class MiscUtils implements CommonConstants {
     }
 
     private static void getClassPathFromManifest(String jarPath,List pathList) throws IOException, URISyntaxException {
-        if (jarPath.toLowerCase().endsWith(".jar")) {   // NOI18N
+        if (jarPath.toLowerCase(Locale.ENGLISH).endsWith(".jar")) {   // NOI18N
             File pathFile = new File(jarPath);
             JarFile jarFile = new JarFile(pathFile);
             Manifest manifest = jarFile.getManifest();
@@ -487,8 +487,8 @@ public class MiscUtils implements CommonConstants {
 
     /** Checks if given directory is already listed on path */
     public static boolean containsDirectoryOnPath(String directory, String path) {
-        String normalizedDirectory = new File(directory).getAbsolutePath().toLowerCase();
-        String normalizedPath = new File(path).getAbsolutePath().toLowerCase();
+        String normalizedDirectory = new File(directory).getAbsolutePath().toLowerCase(Locale.ENGLISH);
+        String normalizedPath = new File(path).getAbsolutePath().toLowerCase(Locale.ENGLISH);
         List pathComponents = getPathComponents(normalizedPath, false, null);
 
         for (int i = 0; i < pathComponents.size(); i++) {
@@ -623,7 +623,9 @@ public class MiscUtils implements CommonConstants {
     }
 
     private static boolean isSupportedJDK(String jdkVersionString) {
-        if (jdkVersionString.startsWith("11")) { // NOI18N
+        if (jdkVersionString.startsWith("12")) { // NOI18N
+            return true;
+        } else if (jdkVersionString.startsWith("11")) { // NOI18N
             return true;
         } else if (jdkVersionString.startsWith("10")) { // NOI18N
             return true;
