@@ -1,20 +1,43 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
  *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
+ * The contents of this file are subject to the terms of either the GNU
+ * General Public License Version 2 only ("GPL") or the Common
+ * Development and Distribution License("CDDL") (collectively, the
+ * "License"). You may not use this file except in compliance with the
+ * License. You can obtain a copy of the License at
+ * http://www.netbeans.org/cddl-gplv2.html
+ * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
+ * specific language governing permissions and limitations under the
+ * License.  When distributing the software, include this License Header
+ * Notice in each file and include the License file at
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * particular file as subject to the "Classpath" exception as provided
+ * by Oracle in the GPL Version 2 section of the License file that
+ * accompanied this code. If applicable, add the following below the
+ * License Header, with the fields enclosed by brackets [] replaced by
+ * your own identifying information:
+ * "Portions Copyrighted [year] [name of copyright owner]"
+ *
+ * If you wish your version of this file to be governed by only the CDDL
+ * or only the GPL Version 2, indicate your decision by adding
+ * "[Contributor] elects to include this software in this distribution
+ * under the [CDDL or GPL Version 2] license." If you do not indicate a
+ * single choice of license, a recipient has the option to distribute
+ * your version of this file under either the CDDL, the GPL Version 2 or
+ * to extend the choice of license to its licensees as provided above.
+ * However, if you add GPL Version 2 code and therefore, elected the GPL
+ * Version 2 license, then the option applies only if the new code is
+ * made subject to such option by the copyright holder.
+ *
+ * Contributor(s):
+ *
+ * Portions Copyrighted 2013 Sun Microsystems, Inc.
  */
 package org.netbeans.nbbuild;
 
@@ -27,12 +50,16 @@ import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.io.Reader;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import java.nio.charset.Charset;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.apache.tools.ant.BuildException;
@@ -117,7 +144,11 @@ public class JNLPUpdateManifestStartup extends Task {
             if (isSigned(jar) == null) {
                 tmpFile = extendLibraryManifest(getProject(), jar, destJar, codebase, permissions, appName);
             }
-        } catch (IOException | ManifestException ex) {
+        } catch (IOException ex) {
+            getProject().log(
+                    "Failed to extend libraries manifests: " + ex.getMessage(), //NOI18N
+                    Project.MSG_WARN);
+        } catch (ManifestException ex) {
             getProject().log(
                     "Failed to extend libraries manifests: " + ex.getMessage(), //NOI18N
                     Project.MSG_WARN);
@@ -145,7 +176,7 @@ public class JNLPUpdateManifestStartup extends Task {
         cp.execute();
         boolean success = false;
         try {
-            final Map<String, String> extendedAttrs = new HashMap<>();
+            final Map<String, String> extendedAttrs = new HashMap<String, String>();
             final org.apache.tools.zip.ZipFile zf = new org.apache.tools.zip.ZipFile(sourceJar);
             try {
                 final org.apache.tools.zip.ZipEntry manifestEntry = zf.getEntry(MANIFEST);
@@ -267,7 +298,8 @@ public class JNLPUpdateManifestStartup extends Task {
      * return alias if signed, or null if not
      */
     private static String isSigned(File f) throws IOException {
-        try (JarFile jar = new JarFile(f)) {
+        JarFile jar = new JarFile(f);
+        try {
             Enumeration<JarEntry> en = jar.entries();
             while (en.hasMoreElements()) {
                 Matcher m = SF.matcher(en.nextElement().getName());
@@ -276,6 +308,8 @@ public class JNLPUpdateManifestStartup extends Task {
                 }
             }
             return null;
+        } finally {
+            jar.close();
         }
     }
     private static final Pattern SF = Pattern.compile("META-INF/(.+)\\.SF");
@@ -295,7 +329,25 @@ public class JNLPUpdateManifestStartup extends Task {
             to.getParentFile().mkdirs();
         }
         getSignTask().setSignedjar(to);
-        getSignTask().setDigestAlg("SHA1");
+        // use reflection for calling getSignTask().setDigestAlg("SHA1");
+        try {
+            Class sjClass = Class.forName("org.apache.tools.ant.taskdefs.SignJar");
+            Method sdaMethod = sjClass.getDeclaredMethod("setDigestAlg", String.class);
+            sdaMethod.invoke(getSignTask(), "SHA1");
+        } catch (ClassNotFoundException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        } catch (NoSuchMethodException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        } catch (SecurityException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        } catch (IllegalAccessException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        } catch (IllegalArgumentException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        } catch (InvocationTargetException ex) {
+            Logger.getLogger(MakeJNLP.class.getName()).log(Level.SEVERE, null, ex);
+        }
+        // end of getSignTask().setDigestAlg("SHA1");
         getSignTask().execute();
 
     }
