@@ -1,20 +1,45 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
  *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
+ * The contents of this file are subject to the terms of either the GNU
+ * General Public License Version 2 only ("GPL") or the Common
+ * Development and Distribution License("CDDL") (collectively, the
+ * "License"). You may not use this file except in compliance with the
+ * License. You can obtain a copy of the License at
+ * http://www.netbeans.org/cddl-gplv2.html
+ * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
+ * specific language governing permissions and limitations under the
+ * License.  When distributing the software, include this License Header
+ * Notice in each file and include the License file at
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * particular file as subject to the "Classpath" exception as provided
+ * by Oracle in the GPL Version 2 section of the License file that
+ * accompanied this code. If applicable, add the following below the
+ * License Header, with the fields enclosed by brackets [] replaced by
+ * your own identifying information:
+ * "Portions Copyrighted [year] [name of copyright owner]"
+ *
+ * Contributor(s):
+ *
+ * The Original Software is NetBeans. The Initial Developer of the Original
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
+ * Microsystems, Inc. All Rights Reserved.
+ *
+ * If you wish your version of this file to be governed by only the CDDL
+ * or only the GPL Version 2, indicate your decision by adding
+ * "[Contributor] elects to include this software in this distribution
+ * under the [CDDL or GPL Version 2] license." If you do not indicate a
+ * single choice of license, a recipient has the option to distribute
+ * your version of this file under either the CDDL, the GPL Version 2 or
+ * to extend the choice of license to its licensees as provided above.
+ * However, if you add GPL Version 2 code and therefore, elected the GPL
+ * Version 2 license, then the option applies only if the new code is
+ * made subject to such option by the copyright holder.
  */
 
 package org.netbeans.nbbuild;
@@ -353,16 +378,16 @@ class UpdateTracking {
     }
 
     static CRC32 crcForFile(File inFile) throws FileNotFoundException, IOException {
-        try (FileInputStream inFileStream = new FileInputStream(inFile)) {
-            byte[] array = new byte[(int) inFile.length()];
-            CRC32 crc = new CRC32();
-            int len = inFileStream.read(array);
-            if (len != array.length) {
-                throw new BuildException("Cannot fully read " + inFile);
-            }
-            crc.update(array);
-            return crc;
+        FileInputStream inFileStream = new FileInputStream(inFile);
+        byte[] array = new byte[(int) inFile.length()];
+        CRC32 crc = new CRC32();
+        int len = inFileStream.read(array);
+        if (len != array.length) {
+            throw new BuildException("Cannot fully read " + inFile);
         }
+        inFileStream.close();
+        crc.update(array);
+        return crc;
     }
     
     class Module extends Object {        
@@ -371,7 +396,7 @@ class UpdateTracking {
         private String codename;
         
         /** Holds value of property versions. */
-        private List<Version> versions = new ArrayList<>();
+        private List<Version> versions = new ArrayList<Version>();
         
         /** Getter for property codenamebase.
          * @return Value of property codenamebase.
@@ -413,17 +438,19 @@ class UpdateTracking {
         }
         
         void addVersion( Version version ) {
-            versions = new ArrayList<>();
+            versions = new ArrayList<Version>();
             versions.add( version );
         }
 
         void setVersion( Version version ) {
-            versions = new ArrayList<>();
+            versions = new ArrayList<Version>();
             versions.add( version );
         }
         
         void removeLocalized( String locale ) {
-            for(Version ver: versions) {
+            Iterator it = versions.iterator();
+            while (it.hasNext()) {
+                Version ver = (Version) it.next();
                 ver.removeLocalized( locale );
             }
         }
@@ -444,7 +471,7 @@ class UpdateTracking {
         private long install_time = 0;
         
         /** Holds value of property files. */
-        private List<ModuleFile> files = new ArrayList<>();
+        private List<ModuleFile> files = new ArrayList<ModuleFile>();
         
         /** Getter for property version.
          * @return Value of property version.
@@ -528,7 +555,7 @@ class UpdateTracking {
         }
         
         public void removeLocalized( String locale ) {
-            List<ModuleFile> newFiles = new ArrayList<>();
+            List<ModuleFile> newFiles = new ArrayList<ModuleFile>();
             for (ModuleFile file : files) {
                 if (file.getName().indexOf("_" + locale + ".") == -1 // NOI18N
                         && file.getName().indexOf("_" + locale + "/") == -1 // NOI18N
