@@ -43,7 +43,6 @@
 
 package org.netbeans.modules.profiler.api;
 
-import java.util.prefs.BackingStoreException;
 import org.netbeans.lib.profiler.common.GlobalProfilingSettings;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
@@ -51,6 +50,8 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.prefs.Preferences;
+import org.netbeans.lib.profiler.common.ProfilingSettings;
+import org.netbeans.lib.profiler.global.CommonConstants;
 
 
 /**
@@ -67,9 +68,17 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
     public static final int CPU_STARTUP = 2;
     public static final int CPU_PROFILING_POINTS = 3;
     public static final int OOME_DETECTION_NONE = 0;
-    public static final int OOME_DETECTION_TEMPDIR = 1;
-    public static final int OOME_DETECTION_PROJECTDIR = 2;
+    public static final int OOME_DETECTION_PROJECTDIR = 1;
+    public static final int OOME_DETECTION_TEMPDIR = 2;
     public static final int OOME_DETECTION_CUSTOMDIR = 3;
+    public static final int SNAPSHOT_WINDOW_OPEN_NEVER = 0;
+    public static final int SNAPSHOT_WINDOW_OPEN_PROFILER = 1;
+    public static final int SNAPSHOT_WINDOW_SHOW_PROFILER = 2;
+    public static final int SNAPSHOT_WINDOW_OPEN_FIRST = 3;
+    public static final int SNAPSHOT_WINDOW_OPEN_EACH = 4;
+    public static final int SNAPSHOT_WINDOW_CLOSE_NEVER = 0;
+    public static final int SNAPSHOT_WINDOW_CLOSE_PROFILER = 1;
+    public static final int SNAPSHOT_WINDOW_HIDE_PROFILER = 2;
 
     /** The Window automatically opens always when profiling starts */
     public static final int OPEN_ALWAYS = 1;
@@ -81,7 +90,7 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
     public static final int OPEN_NEVER = 3;
 
     // --- Singleton pattern ---
-    private static ProfilerIDESettings defaultInstance = new ProfilerIDESettings();
+    private static final ProfilerIDESettings defaultInstance = new ProfilerIDESettings();
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -127,6 +136,14 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
     private final String TRACK_EVERY_KEY = "TRACK_EVERY"; // NOI18N
     private final String TV_BEHAVIOR_KEY = "TV_BEHAVIOR"; // NOI18N
     private final String LCV_BEHAVIOR_KEY = "LCV_BEHAVIOR"; // NOI18N
+    private final String NO_DATA_HINT_KEY = "NO_DATA_HINT"; // NOI18N
+    private final String SNAPSHOT_WINDOW_OPEN_POLICY_KEY = "SNAPSHOT_WINDOW_OPEN_POLICY"; // NOI18N
+    private final String SNAPSHOT_WINDOW_CLOSE_POLICY_KEY = "SNAPSHOT_WINDOW_CLOSE_POLICY"; // NOI18N
+    private final String ENABLE_EXPERT_SETTINGS_KEY = "ENABLE_EXPERT_SETTINGS"; // NOI18N
+    private final String LOG_PROFILER_STATUS_KEY = "LOG_PROFILER_STATUS"; // NOI18N
+    private final String REOPEN_SNAPSHOTS_KEY = "REOPEN_SNAPSHOTS_KEY"; // NOI18N
+    private final String REOPEN_HDUMPS_KEY = "REOPEN_HDUMPS_KEY"; // NOI18N
+    private final String SOURCES_COLORING_KEY = "SOURCES_COLORING_KEY"; // NOI18N
     
     // Defaults for tracked properties
     private final String CUSTOM_HEAPDUMP_PATH_DEFAULT = ""; // NOI18N
@@ -150,6 +167,14 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
     private final int TRACK_EVERY_DEFAULT = 10;
     private final int TV_BEHAVIOR_DEFAULT = OPEN_ALWAYS;
     private final int LCV_BEHAVIOR_DEFAULT = OPEN_ALWAYS;
+    private final boolean NO_DATA_HINT_DEFAULT = true;
+    private final int SNAPSHOT_WINDOW_OPEN_DEFAULT = SNAPSHOT_WINDOW_OPEN_FIRST;
+    private final int SNAPSHOT_WINDOW_CLOSE_DEFAULT = SNAPSHOT_WINDOW_CLOSE_NEVER;
+    private final boolean ENABLE_EXPERT_SETTINGS_DEFAULT = false;
+    private final boolean LOG_PROFILER_STATUS_DEFAULT = false;
+    private final boolean REOPEN_SNAPSHOTS_DEFAULT = false;
+    private final boolean REOPEN_HDUMPS_DEFAULT = false;
+    private final boolean SOURCES_COLORING_DEFAULT = false;
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
@@ -157,100 +182,71 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
         return defaultInstance;
     }
     
-    private ProfilerIDESettings() {
-        try {
-            if (contains55Settings()) convert55Settings();
-            else if (contains701Settings()) convert701Settings();
-        } catch (BackingStoreException e) {
-            // Silently skip exception in NB55 settings
-        }
+    private ProfilerIDESettings() {}
+    
+    
+    // ProfilingSettings -------------------------------------------------------------------------------------------------
+    
+    private ProfilingSettings pSettings;
+    
+    public ProfilingSettings getDefaultProfilingSettings() {
+        if (pSettings == null) pSettings = loadProfilingSettings();
+        return pSettings;
     }
     
-    //~ Conversion of 7.0 / 7.0.1 settings ---------------------------------------------------------------------------------------
-    
-    private boolean contains701Settings() throws BackingStoreException {
-        return get701Preferences().keys().length > 0;
+    public void saveDefaultProfilingSettings() {
+        if (pSettings != null) storeProfilingSettings(pSettings);
     }
     
-    private void convert701Settings() throws BackingStoreException {
-        Preferences preferences = getPreferences();
-        Preferences pref701 = get701Preferences();
+    public ProfilingSettings createDefaultProfilingSettings() {
+        ProfilingSettings defaultSettings = new ProfilingSettings();
+        getDefaultProfilingSettings().copySettingsInto(defaultSettings);
+        return defaultSettings;
+    }
+    
+    private ProfilingSettings loadProfilingSettings() {
+        Preferences pref = getPreferences();
+        ProfilingSettings settings = new ProfilingSettings();
         
-        for (String key : pref701.keys()) {
-            String oldValue = pref701.get(key, null);
-            
-            assert oldValue != null;
-            preferences.put(key, oldValue);
-        }
-        pref701.clear();
-    }
-    
-    private Preferences get701Preferences() {
-        return NbPreferences.root().node("org/netbeans/modules/profiler");  // NOI18N
-    }
-    
-    //~ Conversion of 5.5 / 5.5.1 settings ---------------------------------------------------------------------------------------
-    
-    private boolean contains55Settings() {
-        return getPreferences().getInt(PORT_NO_KEY_55, Integer.MIN_VALUE) != Integer.MIN_VALUE;
-    }
-    
-    private void convert55Settings() throws BackingStoreException {
-        Preferences preferences = getPreferences();
-        String[] keys = preferences.keys();
+        settings.setSamplingFrequency(pref.getInt(ProfilingSettings.PROP_SAMPLING_FREQUENCY, 10));
+        settings.setCPUProfilingType(pref.getInt(ProfilingSettings.PROP_CPU_PROFILING_TYPE, CommonConstants.CPU_INSTR_FULL));
+        settings.setSamplingInterval(pref.getInt(ProfilingSettings.PROP_SAMPLING_INTERVAL, -10));
+        settings.setExcludeWaitTime(pref.getBoolean(ProfilingSettings.PROP_EXCLUDE_WAIT_TIME, true));
+        settings.setInstrumentSpawnedThreads(pref.getBoolean(ProfilingSettings.PROP_INSTRUMENT_SPAWNED_THREADS, false));
+        settings.setNProfiledThreadsLimit(pref.getInt(ProfilingSettings.PROP_N_PROFILED_THREADS_LIMIT, 128));
+        settings.setInstrScheme(pref.getInt(ProfilingSettings.PROP_INSTR_SCHEME, CommonConstants.INSTRSCHEME_LAZY));
+        settings.setInstrumentMethodInvoke(pref.getBoolean(ProfilingSettings.PROP_INSTRUMENT_METHOD_INVOKE, true));
+        settings.setInstrumentGetterSetterMethods(pref.getBoolean(ProfilingSettings.PROP_INSTRUMENT_GETTER_SETTER_METHODS, false));
+        settings.setInstrumentEmptyMethods(pref.getBoolean(ProfilingSettings.PROP_INSTRUMENT_EMPTY_METHODS, false));
         
-        for (String key : keys) {
-            if (AUTO_OPEN_SNAPSHOT_KEY_55.equals(key))
-                convertBoolean(AUTO_OPEN_SNAPSHOT_KEY_55, AUTO_OPEN_SNAPSHOT_KEY, AUTO_OPEN_SNAPSHOT_DEFAULT, preferences);
-            else if (AUTO_SAVE_SNAPSHOT_KEY_55.equals(key))
-                convertBoolean(AUTO_SAVE_SNAPSHOT_KEY_55, AUTO_SAVE_SNAPSHOT_KEY, AUTO_SAVE_SNAPSHOT_DEFAULT, preferences);
-            else if (CALIBRATION_PORT_NO_KEY_55.equals(key))
-                convertInteger(CALIBRATION_PORT_NO_KEY_55, CALIBRATION_PORT_NO_KEY, CALIBRATION_PORT_NO_DEFAULT, preferences);
-            else if (CPU_TASK_KEY_55.equals(key))
-                convertInteger(CPU_TASK_KEY_55, CPU_TASK_KEY, CPU_TASK_DEFAULT, preferences);
-            else if (LIVE_CPU_KEY_55.equals(key))
-                convertBoolean(LIVE_CPU_KEY_55, LIVE_CPU_KEY, LIVE_CPU_DEFAULT, preferences);
-            else if (LIVE_FRAGMENT_KEY_55.equals(key))
-                convertBoolean(LIVE_FRAGMENT_KEY_55, LIVE_FRAGMENT_KEY, LIVE_FRAGMENT_DEFAULT, preferences);
-            else if (LIVE_MEMORY_KEY_55.equals(key))
-                convertBoolean(LIVE_MEMORY_KEY_55, LIVE_MEMORY_KEY, LIVE_MEMORY_DEFAULT, preferences);
-            else if (MEMORY_TASK_ALLOCATIONS_KEY_55.equals(key))
-                convertBoolean(MEMORY_TASK_ALLOCATIONS_KEY_55, MEMORY_TASK_ALLOCATIONS_KEY, MEMORY_TASK_ALLOCATIONS_DEFAULT, preferences);
-            else if (PLATFORM_NAME_KEY_55.equals(key))
-                convertString(PLATFORM_NAME_KEY_55, PLATFORM_NAME_KEY, PLATFORM_NAME_DEFAULT, preferences);
-            else if (PORT_NO_KEY_55.equals(key))
-                convertInteger(PORT_NO_KEY_55, PORT_NO_KEY, PORT_NO_DEFAULT, preferences);
-            else if (RECORD_STACK_TRACES_KEY_55.equals(key))
-                convertBoolean(RECORD_STACK_TRACES_KEY_55, RECORD_STACK_TRACES_KEY, RECORD_STACK_TRACES_DEFAULT, preferences);
-            else if (THREADS_MONITORING_KEY_55.equals(key))
-                convertBoolean(THREADS_MONITORING_KEY_55, THREADS_MONITORING_KEY, THREADS_MONITORING_DEFAULT, preferences);
-            else if (TO_BEHAVIOR_KEY_55.equals(key))
-                convertInteger(TO_BEHAVIOR_KEY_55, TO_BEHAVIOR_KEY, TO_BEHAVIOR_DEFAULT, preferences);
-            else if (TRACK_EVERY_KEY_55.equals(key))
-                convertInteger(TRACK_EVERY_KEY_55, TRACK_EVERY_KEY, TRACK_EVERY_DEFAULT, preferences);
-            else if (TV_BEHAVIOR_KEY_55.equals(key))
-                convertInteger(TV_BEHAVIOR_KEY_55, TV_BEHAVIOR_KEY, TV_BEHAVIOR_DEFAULT, preferences);
-        }
+        settings.setAllocTrackEvery(pref.getInt(ProfilingSettings.PROP_OBJ_ALLOC_STACK_SAMPLING_INTERVAL, 1));
+        settings.setRunGCOnGetResultsInMemoryProfiling(pref.getBoolean(ProfilingSettings.PROP_RUN_GC_ON_GET_RESULTS_IN_MEMORY_PROFILING, false));
+        
+        settings.setThreadsSamplingEnabled(pref.getBoolean(ProfilingSettings.PROP_THREADS_SAMPLING_ENABLED, false));
+        
+        return settings;
     }
     
-    private static void convertBoolean(String oldKey, String newKey, boolean defaultValue, Preferences preferences) {
-        boolean value = preferences.getBoolean(oldKey, defaultValue);
-        preferences.remove(oldKey);
-        preferences.putBoolean(newKey, value);
+    private void storeProfilingSettings(ProfilingSettings settings) {
+        Preferences pref = getPreferences();
+        
+        pref.putInt(ProfilingSettings.PROP_SAMPLING_FREQUENCY, settings.getSamplingFrequency());
+        pref.putInt(ProfilingSettings.PROP_CPU_PROFILING_TYPE, settings.getCPUProfilingType());
+        pref.putInt(ProfilingSettings.PROP_SAMPLING_INTERVAL, settings.getSamplingInterval());
+        pref.putBoolean(ProfilingSettings.PROP_EXCLUDE_WAIT_TIME, settings.getExcludeWaitTime());
+        pref.putBoolean(ProfilingSettings.PROP_INSTRUMENT_SPAWNED_THREADS, settings.getInstrumentSpawnedThreads());
+        pref.putInt(ProfilingSettings.PROP_N_PROFILED_THREADS_LIMIT, settings.getNProfiledThreadsLimit());
+        pref.putInt(ProfilingSettings.PROP_INSTR_SCHEME, settings.getInstrScheme());
+        pref.putBoolean(ProfilingSettings.PROP_INSTRUMENT_METHOD_INVOKE, settings.getInstrumentMethodInvoke());
+        pref.putBoolean(ProfilingSettings.PROP_INSTRUMENT_GETTER_SETTER_METHODS, settings.getInstrumentGetterSetterMethods());
+        pref.putBoolean(ProfilingSettings.PROP_INSTRUMENT_EMPTY_METHODS, settings.getInstrumentEmptyMethods());
+        
+        pref.putInt(ProfilingSettings.PROP_OBJ_ALLOC_STACK_SAMPLING_INTERVAL, settings.getAllocTrackEvery());
+        pref.putBoolean(ProfilingSettings.PROP_RUN_GC_ON_GET_RESULTS_IN_MEMORY_PROFILING, settings.getRunGCOnGetResultsInMemoryProfiling());
+        
+        pref.putBoolean(ProfilingSettings.PROP_THREADS_SAMPLING_ENABLED, settings.getThreadsSamplingEnabled());
     }
     
-    private static void convertInteger(String oldKey, String newKey, int defaultValue, Preferences preferences) {
-        int value = preferences.getInt(oldKey, defaultValue);
-        preferences.remove(oldKey);
-        preferences.putInt(newKey, value);
-    }
-    
-    private static void convertString(String oldKey, String newKey, String defaultValue, Preferences preferences) {
-        String value = preferences.get(oldKey, defaultValue);
-        preferences.remove(oldKey);
-        preferences.put(newKey, value);
-    }
-
     // Properties --------------------------------------------------------------------------------------------------------
     
     /** Determines whether snapshots are automatically opened.
@@ -341,6 +337,76 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
     public boolean getDisplayLiveResultsMemory() {
         return getPreferences().getBoolean(LIVE_MEMORY_KEY, LIVE_MEMORY_DEFAULT);
     }
+    
+    public void setShowNoDataHint(boolean value) {
+        getPreferences().putBoolean(NO_DATA_HINT_KEY, value);
+    }
+    
+    public boolean getShowNoDataHint() {
+        return getPreferences().getBoolean(NO_DATA_HINT_KEY, NO_DATA_HINT_DEFAULT);
+    }
+    
+    public void setSnapshotWindowOpenPolicy(int policy) {
+        getPreferences().putInt(SNAPSHOT_WINDOW_OPEN_POLICY_KEY, policy);
+    }
+    
+    public int getSnapshotWindowOpenPolicy() {
+        return getPreferences().getInt(SNAPSHOT_WINDOW_OPEN_POLICY_KEY, SNAPSHOT_WINDOW_OPEN_DEFAULT);
+    }
+    
+    public void setSnapshotWindowClosePolicy(int policy) {
+        getPreferences().putInt(SNAPSHOT_WINDOW_CLOSE_POLICY_KEY, policy);
+    }
+    
+    public int getSnapshotWindowClosePolicy() {
+        return getPreferences().getInt(SNAPSHOT_WINDOW_CLOSE_POLICY_KEY, SNAPSHOT_WINDOW_CLOSE_DEFAULT);
+    }
+    
+    public void setEnableExpertSettings(boolean value) {
+        getPreferences().putBoolean(ENABLE_EXPERT_SETTINGS_KEY, true);
+//        getPreferences().putBoolean(ENABLE_EXPERT_SETTINGS_KEY, value);
+    }
+    
+    public boolean getEnableExpertSettings() {
+        return true;
+//        return getPreferences().getBoolean(ENABLE_EXPERT_SETTINGS_KEY, ENABLE_EXPERT_SETTINGS_DEFAULT);
+    }
+    
+    public void setLogProfilerStatus(boolean value) {
+        getPreferences().putBoolean(LOG_PROFILER_STATUS_KEY, value);
+    }
+    
+    public boolean getLogProfilerStatus() {
+        return getPreferences().getBoolean(LOG_PROFILER_STATUS_KEY, LOG_PROFILER_STATUS_DEFAULT);
+    }
+    
+    public void setReopenSnapshots(boolean value) {
+        getPreferences().putBoolean(REOPEN_SNAPSHOTS_KEY, value);
+    }
+    
+    public boolean getReopenSnapshots() {
+        return getPreferences().getBoolean(REOPEN_SNAPSHOTS_KEY, REOPEN_SNAPSHOTS_DEFAULT);
+    }
+    
+    public void setReopenHeapDumps(boolean value) {
+        getPreferences().putBoolean(REOPEN_HDUMPS_KEY, value);
+    }
+    
+    public boolean getReopenHeapDumps() {
+        return getPreferences().getBoolean(REOPEN_HDUMPS_KEY, REOPEN_HDUMPS_DEFAULT);
+    }
+    
+    private Boolean sourcesColoringEnabled; // needs to be as fast as possible for rendering tables
+    public void setSourcesColoringEnabled(boolean value) {
+        getPreferences().putBoolean(SOURCES_COLORING_KEY, value);
+        sourcesColoringEnabled = value;
+    }
+    
+    public boolean isSourcesColoringEnabled() {
+        if (sourcesColoringEnabled == null) sourcesColoringEnabled =
+                getPreferences().getBoolean(SOURCES_COLORING_KEY, SOURCES_COLORING_DEFAULT);
+        return sourcesColoringEnabled;
+    }
 
     /**
      * Used by the DNSAConfirmation.
