@@ -60,7 +60,8 @@ public class TargetPlatformEnum {
                                                  IntegrationUtils.PLATFORM_JAVA_50, IntegrationUtils.PLATFORM_JAVA_60,
                                                  IntegrationUtils.PLATFORM_JAVA_70, IntegrationUtils.PLATFORM_JAVA_80, 
                                                  IntegrationUtils.PLATFORM_JAVA_90, IntegrationUtils.PLATFORM_JAVA_100,
-                                                 IntegrationUtils.PLATFORM_JAVA_110, IntegrationUtils.PLATFORM_JAVA_CVM
+                                                 IntegrationUtils.PLATFORM_JAVA_110, IntegrationUtils.PLATFORM_JAVA_120,
+                                                 IntegrationUtils.PLATFORM_JAVA_CVM
                                              };
     public static final TargetPlatformEnum JDK5 = new TargetPlatformEnum(0);
     public static final TargetPlatformEnum JDK6 = new TargetPlatformEnum(1);
@@ -69,7 +70,8 @@ public class TargetPlatformEnum {
     public static final TargetPlatformEnum JDK9 = new TargetPlatformEnum(4);
     public static final TargetPlatformEnum JDK10 = new TargetPlatformEnum(5);
     public static final TargetPlatformEnum JDK11 = new TargetPlatformEnum(6);
-    public static final TargetPlatformEnum JDK_CVM = new TargetPlatformEnum(7);
+    public static final TargetPlatformEnum JDK12 = new TargetPlatformEnum(7);
+    public static final TargetPlatformEnum JDK_CVM = new TargetPlatformEnum(8);
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -92,7 +94,7 @@ public class TargetPlatformEnum {
     }
 
     public static Iterator iterator() {
-        List jvmList = new ArrayList(8);
+        List jvmList = new ArrayList(9);
         jvmList.add(JDK5);
         jvmList.add(JDK6);
         jvmList.add(JDK7);
@@ -100,6 +102,7 @@ public class TargetPlatformEnum {
         jvmList.add(JDK9);
         jvmList.add(JDK10);
         jvmList.add(JDK11);
+        jvmList.add(JDK12);
         jvmList.add(JDK_CVM);
 
         return jvmList.listIterator();
