@@ -45,7 +45,6 @@ package org.netbeans.modules.profiler.heapwalk;
 
 import org.netbeans.lib.profiler.ProfilerLogger;
 import org.netbeans.lib.profiler.global.Platform;
-import org.netbeans.modules.profiler.ProfilerControlPanel2;
 import org.openide.ErrorManager;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -53,12 +52,17 @@ import org.openide.windows.TopComponent;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.SwingUtilities;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
 import org.netbeans.modules.profiler.heapwalk.model.BrowserUtils;
+import org.netbeans.modules.profiler.v2.SnapshotsWindow;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
 
 
 /**
@@ -67,16 +71,15 @@ import org.netbeans.modules.profiler.heapwalk.model.BrowserUtils;
  * @author Jiri Sedlacek
  */
 @NbBundle.Messages({
-    "HeapWalkerManager_CannotOpenHeapWalkerMsg=<html><b>Failed to open the heap dump.</b><br><br>{0}</html>",
+    "HeapWalkerManager_CannotOpenHeapWalkerMsg=Failed to open the heap dump.",
     "HeapWalkerManager_CannotDeleteHeapDumpMsg=<html><b>Deleting heap dump failed</b><br><br>Please try to delete the file once more. If it fails<br>again, restart the IDE and repeat the action.</html>"
 })
 public class HeapWalkerManager {
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
-    private java.util.Set dumpsBeingDeleted = new java.util.HashSet();
+    private Set dumpsBeingDeleted = new HashSet();
     private List<File> heapDumps = new ArrayList();
     private List<HeapWalker> heapWalkers = new ArrayList();
-    private List<TopComponent> topComponents = new ArrayList();
 
     final private RequestProcessor heapwalkerRp = new RequestProcessor(HeapWalkerManager.class);
 
@@ -99,15 +102,17 @@ public class HeapWalkerManager {
         return getHeapWalker(file) != null;
     }
 
-    public synchronized void closeAllHeapWalkers() {
-        HeapWalker[] heapWalkerArr = heapWalkers.toArray(new HeapWalker[heapWalkers.size()]);
-
+    public void closeAllHeapWalkers() {
+        HeapWalker[] heapWalkerArr;
+        synchronized (this) {
+            heapWalkerArr = heapWalkers.toArray(new HeapWalker[0]);
+        }
         for (HeapWalker hw : heapWalkerArr) {
             closeHeapWalker(hw);
         }
     }
 
-    public synchronized void closeHeapWalker(final HeapWalker hw) {
+    public void closeHeapWalker(final HeapWalker hw) {
         SwingUtilities.invokeLater(new Runnable() {
                 public void run() {
                     final TopComponent tc = getTopComponent(hw);
@@ -119,8 +124,10 @@ public class HeapWalkerManager {
                     }
 
                     tc.close();
-                    if (ProfilerControlPanel2.hasDefault())
-                        ProfilerControlPanel2.getDefault().refreshSnapshotsList(); // Refresh to display closed HW using plain font
+                    FileObject folder = FileUtil.toFileObject(hw.getHeapDumpFile().getParentFile());
+                    SnapshotsWindow.instance().refreshFolder(folder, false);
+//                    if (ProfilerControlPanel2.hasDefault())
+//                        ProfilerControlPanel2.getDefault().refreshSnapshotsList(); // Refresh to display closed HW using plain font
                 }
             });
     }
@@ -147,7 +154,6 @@ public class HeapWalkerManager {
         final File file = hw.getHeapDumpFile();
         heapDumps.remove(file);
         heapWalkers.remove(hw);
-        topComponents.remove(tc);
 
         if (dumpsBeingDeleted.remove(file)) {
             BrowserUtils.performTask(new Runnable() {
@@ -159,35 +165,43 @@ public class HeapWalkerManager {
         }
     }
 
-    public synchronized void openHeapWalker(final File heapDump) {
-        HeapWalker hw = getHeapWalker(heapDump);
-
-        if (hw == null) {
-            try {
-                hw = new HeapWalker(heapDump);
-            } catch (IOException e) {
-                ProfilerDialogs.displayError(Bundle.HeapWalkerManager_CannotOpenHeapWalkerMsg(e.getLocalizedMessage()));
-            } catch (Exception e) {
-                Logger.getLogger(HeapWalkerManager.class.getName()).log(Level.SEVERE, null, e);
-            }
+    public void openHeapWalker(final File heapDump) {
+        String heapDumpPath;
+        
+        try {
+            heapDumpPath = heapDump.getCanonicalPath();
+        } catch (IOException ex) {
+            ProfilerDialogs.displayError(Bundle.HeapWalkerManager_CannotOpenHeapWalkerMsg(), null, ex.getLocalizedMessage());
+            return;
         }
+        synchronized (heapDumpPath.intern()) {
+            HeapWalker hw = getHeapWalker(heapDump);
 
-        if (hw != null) {
-            openHeapWalker(hw);
-        } else {
-            ProfilerLogger.severe("Cannot create HeapWalker [" + heapDump + "]"); // NOI18N
+            if (hw == null) {
+                try {
+                    hw = new HeapWalker(heapDump);
+                } catch (IOException e) {
+                    ProfilerDialogs.displayError(Bundle.HeapWalkerManager_CannotOpenHeapWalkerMsg(), null, e.getLocalizedMessage());
+                } catch (Exception e) {
+                    Logger.getLogger(HeapWalkerManager.class.getName()).log(Level.SEVERE, null, e);
+                }
+            }
+
+            if (hw != null) {
+                openHeapWalker(hw);
+            } else {
+                ProfilerLogger.severe("Cannot create HeapWalker [" + heapDump + "]"); // NOI18N
+            }
         }
     }
 
     public synchronized void openHeapWalker(final HeapWalker hw) {
+        if (!heapWalkers.contains(hw)) {
+            heapDumps.add(hw.getHeapDumpFile());
+            heapWalkers.add(hw);
+        }
         SwingUtilities.invokeLater(new Runnable() {
                 public void run() {
-                    if (!heapWalkers.contains(hw)) {
-                        heapDumps.add(hw.getHeapDumpFile());
-                        heapWalkers.add(hw);
-                        topComponents.add(hw.getTopComponent());
-                    }
-
                     final TopComponent tc = getTopComponent(hw);
 
                     if (tc == null) {
@@ -199,8 +213,11 @@ public class HeapWalkerManager {
                     tc.open();
                     //        tc.requestActive(); // For some reason steals focus from Dump Heap button in ProfilerControlPanel2 and causes http://www.netbeans.org/issues/show_bug.cgi?id=92425
                     tc.requestVisible(); // Workaround for the above problem
-                    if (ProfilerControlPanel2.hasDefault())
-                        ProfilerControlPanel2.getDefault().refreshSnapshotsList(); // Refresh to display opened HW using bold font
+                    
+                    FileObject folder = FileUtil.toFileObject(hw.getHeapDumpFile().getParentFile());
+                    SnapshotsWindow.instance().refreshFolder(folder, false);
+//                    if (ProfilerControlPanel2.hasDefault())
+//                        ProfilerControlPanel2.getDefault().refreshSnapshotsList(); // Refresh to display opened HW using bold font
                 }
             });
     }
@@ -211,22 +228,15 @@ public class HeapWalkerManager {
         }
     }
 
-    private HeapWalker getHeapWalker(File heapDump) {
+    private synchronized HeapWalker getHeapWalker(File heapDump) {
         int hdIndex = heapDumps.indexOf(heapDump);
 
         return (hdIndex == -1) ? null : heapWalkers.get(hdIndex);
     }
 
-    private HeapWalker getHeapWalker(TopComponent tc) {
-        int tcIndex = topComponents.indexOf(tc);
-
-        return (tcIndex == -1) ? null : heapWalkers.get(tcIndex);
-    }
-
     private TopComponent getTopComponent(HeapWalker hw) {
-        int hwIndex = heapWalkers.indexOf(hw);
-
-        return (hwIndex == -1) ? null : topComponents.get(hwIndex);
+        assert SwingUtilities.isEventDispatchThread();
+        return hw.getTopComponent();
     }
 
     private void deleteHeapDumpImpl(final File file, final int retries) {
@@ -246,8 +256,10 @@ public class HeapWalkerManager {
                             ProfilerDialogs.displayError(Bundle.HeapWalkerManager_CannotDeleteHeapDumpMsg());
                         }
                     } else {
-                        if (ProfilerControlPanel2.hasDefault())
-                            ProfilerControlPanel2.getDefault().refreshSnapshotsList();
+                        FileObject folder = FileUtil.toFileObject(file.getParentFile());
+                        SnapshotsWindow.instance().refreshFolder(folder, true);
+//                        if (ProfilerControlPanel2.hasDefault())
+//                            ProfilerControlPanel2.getDefault().refreshSnapshotsList();
                     }
                 }
             });
