@@ -217,7 +217,9 @@ public class OQLController extends AbstractTopLevelController
                             });
 
                             if (counter.get() == 0) {
-                                sb.append("<tr><td><h4>Too many results. Please, refine your query.</h4></td></tr>" );
+                                sb.append("<tr><td><h4>");  // NOI18N
+                                sb.append(NbBundle.getMessage(OQLController.class, "OQL_TOO_MANY_RESULTS_MSG"));      // NOI18N
+                                sb.append("</h4></td></tr>");   // NOI18N
                             } else if (counter.get() == RESULTS_LIMIT) {
                                 sb.append("<tr><td><h4>"); // NOI18N
                                 sb.append(NbBundle.getMessage(OQLController.class, "OQL_NO_RESULTS_MSG")); // NOI18N
@@ -288,7 +290,7 @@ public class OQLController extends AbstractTopLevelController
                 }
                 sb.append(entry.getKey().toString().replace("<", "&lt;").replace(">", "&gt;")); // NOI18N
                 sb.append(" = "); // NOI18N
-                dump(entry.getValue(), sb);
+                dump(unwrap(entry.getValue()), sb);
             }
             sb.append("<br/><b>}</b></span>"); // NOI18N
         } else if (o instanceof Object[]) {
@@ -300,12 +302,7 @@ public class OQLController extends AbstractTopLevelController
                 } else {
                     first = false;
                 }
-                Object obj2 = engine.unwrapJavaObject(obj1,true);
-                if (obj2 != null) {
-                    dump(obj2, sb);
-                } else {
-                    dump(obj1, sb);
-                }
+                dump(unwrap(obj1), sb);
             }
             sb.append("&nbsp;<b>]</b></span>"); // NOI18N
         } else {
@@ -313,6 +310,11 @@ public class OQLController extends AbstractTopLevelController
         }
     }
 
+    private Object unwrap(Object obj1) {
+        Object obj2 = engine.unwrapJavaObject(obj1, true);
+        return obj2 != null ? obj2 : obj1;
+    }
+
     private OQLEngine getEngine() {
         return engine;
     }
@@ -403,11 +405,15 @@ public class OQLController extends AbstractTopLevelController
         
 
         return "<a href='file://instance/" + className + "@" + in.getInstanceId() + "'>" + className + '#' + in.getInstanceNumber() + "</a>" + // NOI18N
-                (details != null ? " - " + details : ""); // NOI18N
+                (details != null ? " - " + htmlize(details) : ""); // NOI18N
 //        return "<a href='file://instance/" + className + "/" + in.getInstanceNumber() + "'>" + className + '#' + in.getInstanceNumber() + "</a>"; // NOI18N
 //        return in.getJavaClass().getName() + '@' + Long.toHexString(in.getInstanceId()) + '#' + in.getInstanceNumber();
     }
 
+    private static String htmlize(String value) {
+            return value.replace(">", "&gt;").replace("<", "&lt;");     // NOI18N
+    }
+
 
     // --- Controllers ---------------------------------------------------------
 
