@@ -66,6 +66,7 @@ import javax.management.openmbean.CompositeData;
 import javax.swing.SwingUtilities;
 import org.netbeans.lib.profiler.common.ProfilingSettingsPresets;
 import org.netbeans.lib.profiler.results.cpu.StackTraceSnapshotBuilder;
+import org.netbeans.lib.profiler.results.jdbc.JdbcResultsSnapshot;
 import org.netbeans.lib.profiler.results.memory.SampledMemoryResultsSnapshot;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
 import org.netbeans.modules.profiler.api.ProjectUtilities;
@@ -97,6 +98,7 @@ public class LoadedSnapshot {
     public static final int SNAPSHOT_TYPE_MEMORY_ALLOCATIONS = 4;
     public static final int SNAPSHOT_TYPE_MEMORY_LIVENESS = 8;
     public static final int SNAPSHOT_TYPE_MEMORY_SAMPLED = 16;
+    public static final int SNAPSHOT_TYPE_CPU_JDBC = 32;
     public static final int SNAPSHOT_TYPE_MEMORY = SNAPSHOT_TYPE_MEMORY_ALLOCATIONS | SNAPSHOT_TYPE_MEMORY_LIVENESS | SNAPSHOT_TYPE_MEMORY_SAMPLED;
     public static final String PROFILER_FILE_MAGIC_STRING = "nBpRoFiLeR"; // NOI18N
     private static final byte SNAPSHOT_FILE_VERSION_MAJOR = 1;
@@ -207,6 +209,8 @@ public class LoadedSnapshot {
             return SNAPSHOT_TYPE_MEMORY_ALLOCATIONS;
         } else if (snapshot instanceof SampledMemoryResultsSnapshot) {
             return SNAPSHOT_TYPE_MEMORY_SAMPLED;
+        } else if (snapshot instanceof JdbcResultsSnapshot) {
+            return SNAPSHOT_TYPE_CPU_JDBC;
         } else {
             throw new IllegalStateException(Bundle.LoadedSnapshot_IllegalSnapshotDataMsg());
         }
@@ -380,12 +384,13 @@ public class LoadedSnapshot {
 
             // binary file format:
             // 1. magic number: "nbprofiler"
-            // 2. int type
-            // 3. int length of snapshot data size
-            // 4. snapshot data bytes
-            // 5. int length of settings data size
-            // 6. settings data bytes (.properties plain text file format)
-            // 7. String (UTF) custom comments
+            // 2. byte major, minor version
+            // 3. int type
+            // 4. int length of snapshot data size
+            // 5. snapshot data bytes
+            // 6. int length of settings data size
+            // 7. settings data bytes (.properties plain text file format)
+            // 8. String (UTF) custom comments
 
             // 1. magic number: "nbprofiler"
             byte[] magicArray = new byte[PROFILER_FILE_MAGIC_STRING.length()];
@@ -395,7 +400,7 @@ public class LoadedSnapshot {
                 throw new IOException(Bundle.LoadedSnapshot_InvalidSnapshotFileMsg());
             }
 
-            // 2. int type
+            // 2. byte major, minor version
             byte majorVersion = dis.readByte();
             byte minorVersion = dis.readByte();
 
@@ -437,6 +442,10 @@ public class LoadedSnapshot {
                 case SNAPSHOT_TYPE_MEMORY_SAMPLED:
                     snapshot = new SampledMemoryResultsSnapshot();
                     
+                    break;
+                case SNAPSHOT_TYPE_CPU_JDBC:
+                    snapshot = new JdbcResultsSnapshot();
+                    
                     break;
                 default:
                     throw new IOException(Bundle.LoadedSnapshot_SnapshotFileCorruptedReason(Bundle.LoadedSnapshot_UnrecognizedSnapshotTypeMsg())); // not supported
@@ -462,6 +471,7 @@ public class LoadedSnapshot {
                 throw new IOException(Bundle.LoadedSnapshot_SnapshotFileCorruptedReason(Bundle.LoadedSnapshot_CannotReadSettingsDataMsg()));
             }
             
+            // 8. String (UTF) custom comments
             if (minorVersion >= SNAPSHOT_FILE_VERSION_MINOR) {
                 userComments = dis.readUTF();
             }
@@ -656,7 +666,7 @@ public class LoadedSnapshot {
 
         ThreadsSample(long t, Collection<ThreadInfo> tis) {
             time = t;
-            tinfos = tis.toArray(new ThreadInfo[tis.size()]);
+            tinfos = tis.toArray(new ThreadInfo[0]);
         }
 
         long getTime() {
