@@ -58,14 +58,11 @@ import java.awt.event.HierarchyListener;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-import java.io.OutputStream;
 import java.net.Socket;
 import java.net.SocketTimeoutException;
 import java.util.Collection;
@@ -83,7 +80,6 @@ import javax.swing.JProgressBar;
 import javax.swing.SwingUtilities;
 import javax.swing.border.EmptyBorder;
 import org.netbeans.api.progress.ProgressHandle;
-import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.lib.profiler.ProfilerClient;
 import org.netbeans.lib.profiler.ProfilerEngineSettings;
 import org.netbeans.lib.profiler.ProfilerLogger;
@@ -94,11 +90,9 @@ import org.netbeans.lib.profiler.client.AppStatusHandler;
 import org.netbeans.lib.profiler.client.ClientUtils;
 import org.netbeans.lib.profiler.client.ProfilingPointsProcessor;
 import org.netbeans.lib.profiler.common.*;
-import org.netbeans.lib.profiler.common.filters.DefinedFilterSets;
-import org.netbeans.lib.profiler.common.filters.GlobalFilters;
+import org.netbeans.lib.profiler.filters.GenericFilter;
 import org.netbeans.lib.profiler.global.CalibrationDataFileIO;
 import org.netbeans.lib.profiler.global.CommonConstants;
-import org.netbeans.lib.profiler.global.InstrumentationFilter;
 import org.netbeans.lib.profiler.global.Platform;
 import org.netbeans.lib.profiler.instrumentation.BadLocationException;
 import org.netbeans.lib.profiler.instrumentation.InstrumentationException;
@@ -109,7 +103,6 @@ import org.netbeans.lib.profiler.results.cpu.CPUProfilingResultListener;
 import org.netbeans.lib.profiler.results.cpu.FlatProfileBuilder;
 import org.netbeans.lib.profiler.results.cpu.cct.CCTResultsFilter;
 import org.netbeans.lib.profiler.results.cpu.cct.TimeCollector;
-import org.netbeans.lib.profiler.results.cpu.marking.MarkingEngine;
 import org.netbeans.lib.profiler.results.locks.LockProfilingResultListener;
 import org.netbeans.lib.profiler.results.memory.MemoryCCTProvider;
 import org.netbeans.lib.profiler.results.memory.MemoryProfilingResultsListener;
@@ -120,8 +113,6 @@ import org.netbeans.lib.profiler.ui.monitor.VMTelemetryModels;
 import org.netbeans.lib.profiler.wireprotocol.Command;
 import org.netbeans.lib.profiler.wireprotocol.Response;
 import org.netbeans.lib.profiler.wireprotocol.WireIO;
-import org.netbeans.modules.profiler.api.GestureSubmitter;
-import org.netbeans.modules.profiler.api.GlobalStorage;
 import org.netbeans.modules.profiler.api.JavaPlatform;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
 import org.netbeans.modules.profiler.api.ProfilerIDESettings;
@@ -131,9 +122,7 @@ import org.netbeans.modules.profiler.ui.ProfilerProgressDisplayer;
 import org.netbeans.modules.profiler.utilities.ProfilerUtils;
 import org.openide.awt.Mnemonics;
 import org.openide.awt.StatusDisplayer;
-import org.openide.filesystems.FileLock;
 import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileUtil;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -164,8 +153,8 @@ import org.openide.windows.WindowManager;
     "NetBeansProfiler_ErrorSavingAttachSettingsMessage=Error encountered while saving attach settings: {0}",
     "NetBeansProfiler_CannotFindLibsMsg=Cannot find profiler libs directory",
     "NetBeansProfiler_EngineInitFailedMsg=Failed to initialize the Profiler engine: {0}",
-    "NetBeansProfiler_InitialCalibrationMsg=Profiler will now perform an initial calibration of your machine and target JVM.\n\nThis calibration needs to be performed the first time you run the profiler to\nensure that timing results are accurate when profiling your application. To\nensure the calibration data is accurate, please make sure that other\napplications are not placing a noticeable load on your machine at this time.\n\nYou can run the calibration again by choosing\n\"Profile | Advanced Commands | Manage Calibration Data\"\n\nWarning: If your computer uses dynamic CPU frequency switching, please\ndisable it and do not use it when  profiling.",
-    "NetBeansProfiler_MustCalibrateFirstMsg=Profiling will STOP now because the calibration data is missing or is corrupt.\n\nIf this is the first time you are using the profiler or target JVM on this machine,\nyou first need to run the calibration for your target JVM.\nThe obtained calibration data will be saved and re-used\non subsequent runs, so you will not see this message again.\n\nTo perform calibration, choose\n\"Profile | Advanced Commands | Manage Calibration Data\".\n\n",
+    "NetBeansProfiler_InitialCalibrationMsg=Profiler will now perform an initial calibration of your machine and target JVM.\n\nThis calibration needs to be performed the first time you run the profiler to\nensure that timing results are accurate when profiling your application. To\nensure the calibration data is accurate, please make sure that other\napplications are not placing a noticeable load on your machine at this time.\n\nYou can run the calibration again using\n\"Tools | Options | Java | Profiler | General | Manage calibration data\"\n\nWarning: If your computer uses dynamic CPU frequency switching, please\ndisable it and do not use it when profiling.",
+    "NetBeansProfiler_MustCalibrateFirstMsg=Profiling will STOP now because the calibration data is missing or is corrupt.\n\nIf this is the first time you are using the profiler or target JVM on this machine,\nyou first need to run the calibration for your target JVM.\nThe obtained calibration data will be saved and re-used\non subsequent runs, so you will not see this message again.\n\nTo perform calibration, use\n\"Tools | Options | Java | Profiler | General | Manage calibration data\".\n\n",
     "NetBeansProfiler_MustCalibrateFirstShortMsg=<html><b>Calibration data missing.</b><br><br>Profiling cannot be started on this JDK. Please perform<br>profiler calibration first and start the profiling session again.</html>",
     "NetBeansProfiler_TerminateVMOnExitMsg=<b>The profiled application has finished execution.</b>\n Press OK to terminate the VM.",
     "NetBeansProfiler_TakeSnapshotOnExitMsg=<b>The profiled application has finished execution.</b>\nDo you want to take a snapshot of the collected results?",
@@ -175,6 +164,7 @@ import org.openide.windows.WindowManager;
     "NetBeansProfiler_ModifyingInstrumentationMsg=Modifying instrumentation...",
     "NetBeansProfiler_StartingSession=Starting profiling session...",
     "NetBeansProfiler_CancelBtn=&Cancel",
+    "NetBeansProfiler_AgentFailed=Make sure the process is not already being profiled.",
     "NetBeansProfiler_MemorySamplingJava5=<html><b>Memory sampling is not supported for Java 5.</b><br><br>Please run the profiled application using Java 6+ or use memory instrumentation.</html>"
 })
 public abstract class NetBeansProfiler extends Profiler {
@@ -343,9 +333,9 @@ public abstract class NetBeansProfiler extends Profiler {
             //            public void run() {
 
             // Asynchronously update live results if autorefresh is on
-            if (LiveResultsWindow.hasDefault()) {
-                LiveResultsWindow.getDefault().handleShutdown();
-            }
+//            if (LiveResultsWindow.hasDefault()) {
+//                LiveResultsWindow.getDefault().handleShutdown();
+//            }
 
             if ((getTargetAppRunner().getProfilerClient().getCurrentInstrType() == CommonConstants.INSTR_NONE)
                     || !ResultsManager.getDefault().resultsAvailable()) {
@@ -360,7 +350,7 @@ public abstract class NetBeansProfiler extends Profiler {
         }
 
         public void pauseLiveUpdates() {
-            LiveResultsWindow.setPaused(true);
+//            LiveResultsWindow.setPaused(true);
         }
 
         public void resultsAvailable() {
@@ -372,7 +362,7 @@ public abstract class NetBeansProfiler extends Profiler {
         }
 
         public void resumeLiveUpdates() {
-            LiveResultsWindow.setPaused(false);
+//            LiveResultsWindow.setPaused(false);
         }
 
         public void takeSnapshot() {
@@ -388,9 +378,9 @@ public abstract class NetBeansProfiler extends Profiler {
 
     private static final Logger LOGGER = Logger.getLogger(NetBeansProfiler.class.getName());
 
-    private static final String GLOBAL_FILTERS_FILENAME = "filters"; //NOI18N
-    private static final String DEFINED_FILTERSETS_FILENAME = "filtersets"; //NOI18N
-    private static final String DEFAULT_FILE_SUFFIX = "-default"; //NOI18N
+//    private static final String GLOBAL_FILTERS_FILENAME = "filters"; //NOI18N
+//    private static final String DEFINED_FILTERSETS_FILENAME = "filtersets"; //NOI18N
+//    private static final String DEFAULT_FILE_SUFFIX = "-default"; //NOI18N
     private static boolean initialized = false;
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
@@ -404,11 +394,9 @@ public abstract class NetBeansProfiler extends Profiler {
     
     private ProfilingMonitor monitor = null;
     private TargetAppRunner targetAppRunner;
-    private DefinedFilterSets definedFilterSets;
     private FileObject profiledSingleFile;
     final private ProfilerEngineSettings sharedSettings;
     
-    private GlobalFilters globalFilters;
     private final Object setupLock = new Object();
     private ProfilingSettings lastProfilingSettings;
     private Lookup.Provider profiledProject = null;
@@ -520,22 +508,6 @@ public abstract class NetBeansProfiler extends Profiler {
         return lastSessionSettings;
     }
 
-    public synchronized DefinedFilterSets getDefinedFilterSets() {
-        if (definedFilterSets == null) {
-            loadGlobalFilters();
-        }
-
-        return definedFilterSets;
-    }
-
-    public synchronized GlobalFilters getGlobalFilters() {
-        if (globalFilters == null) {
-            loadGlobalFilters();
-        }
-
-        return globalFilters;
-    }
-
     public GlobalProfilingSettings getGlobalProfilingSettings() {
         return ideSettings;
     }
@@ -742,7 +714,7 @@ public abstract class NetBeansProfiler extends Profiler {
     public boolean attachToApp(final ProfilingSettings profilingSettings, final AttachSettings attachSettings) {
         profilingMode = MODE_ATTACH;
 
-        ProgressHandle ph = ProgressHandleFactory.createHandle(Bundle.NetBeansProfiler_StartingSession());
+        ProgressHandle ph = ProgressHandle.createHandle(Bundle.NetBeansProfiler_StartingSession());
         ph.setInitialDelay(500);
         
         ph.start();
@@ -769,9 +741,6 @@ public abstract class NetBeansProfiler extends Profiler {
             // Platform.supportsThreadSleepingStateMonitoring(sharedSettings.getTargetJDKVersionString()));
             logActionConfig("attachToApp", profilingSettings, null, attachSettings, sSettings.getInstrumentationFilter()); // NOI18N
             
-            GestureSubmitter.logAttach(getProfiledProject(), attachSettings);
-            GestureSubmitter.logConfig(profilingSettings, sSettings.getInstrumentationFilter());
-            
             changeStateTo(PROFILING_STARTED);
             
             cleanupBeforeProfiling(sSettings);
@@ -816,6 +785,9 @@ public abstract class NetBeansProfiler extends Profiler {
                     if (prepareInstrumentation(profilingSettings)) {
                         success = getTargetAppRunner().initiateSession(2, false) && getTargetAppRunner().attachToTargetVM();
                     }
+                } catch (AgentInitializationException ex) {
+                    ProfilerDialogs.displayError(ex.getMessage()+"\n"+Bundle.NetBeansProfiler_AgentFailed());   // NOI18N
+                    ProfilerLogger.log(ex);                    
                 } catch (Exception ex) {
                     ProfilerDialogs.displayError(ex.getMessage());
                     ProfilerLogger.log(ex);
@@ -840,7 +812,21 @@ public abstract class NetBeansProfiler extends Profiler {
     private static void loadAgentIntoTargetJVM(final String jar, final String options, final String pid)
                                             throws AttachNotSupportedException, IOException, AgentLoadException, AgentInitializationException  {
         VirtualMachine virtualMachine = VirtualMachine.attach(pid);
-        virtualMachine.loadAgent(jar,options);
+        try {
+            virtualMachine.loadAgent(jar,options);
+        } catch (AgentLoadException ex) {
+            if ("0".equals(ex.getMessage())) {
+                // JDK 10 -> JDK 9 mismatch
+                return;
+            }
+            throw ex;
+        } catch (IOException ex) {
+           if ("readInt".equals(ex.getStackTrace()[0].getMethodName())) {
+                // JDK 9 -> JDK 10 mismatch
+                return;
+            }
+            throw ex;
+        }
     }
 
     // -- NetBeansProfiler-only public methods -----------------------------------------------------------------------------
@@ -936,7 +922,7 @@ public abstract class NetBeansProfiler extends Profiler {
         lastSessionSettings = sessionSettings;
         lastMode = MODE_PROFILE;
 
-        ProgressHandle ph = ProgressHandleFactory.createHandle(Bundle.NetBeansProfiler_StartingSession());
+        ProgressHandle ph = ProgressHandle.createHandle(Bundle.NetBeansProfiler_StartingSession());
         try {
             ph.setInitialDelay(500);
             ph.start();
@@ -949,15 +935,13 @@ public abstract class NetBeansProfiler extends Profiler {
             
             sessionSettings.applySettings(sSettings);
             profilingSettings.applySettings(sSettings); // can override the session settings
+            sSettings.setInstrumentObjectInit(false); // clear instrument object.<init>
             //sSettings.setRemoteHost(""); // NOI18N // clear remote profiling host
 
             //getThreadsManager().setSupportsSleepingStateMonitoring(
             // Platform.supportsThreadSleepingStateMonitoring(sharedSettings.getTargetJDKVersionString()));
             logActionConfig("connectToStartedApp", profilingSettings, sessionSettings, null, sSettings.getInstrumentationFilter()); // NOI18N
             
-            GestureSubmitter.logProfileApp(getProfiledProject(), sessionSettings);
-            GestureSubmitter.logConfig(profilingSettings, sSettings.getInstrumentationFilter());
-            
             if (prepareProfilingSession(profilingSettings, sessionSettings)) {
                 RequestProcessor.getDefault().post(new Runnable() {
                     
@@ -996,7 +980,7 @@ public abstract class NetBeansProfiler extends Profiler {
         }
         if (sessionSettings.getRemoteHost().isEmpty() && !CalibrationDataFileIO.validateCalibrationInput(
                 sessionSettings.getJavaVersionString(),sessionSettings.getJavaExecutable())) {
-            ProfilerDialogs.displayError(Bundle.NetBeansProfiler_MustCalibrateFirstMsg(), null, Bundle.NetBeansProfiler_MustCalibrateFirstShortMsg());
+            ProfilerDialogs.displayError(Bundle.NetBeansProfiler_MustCalibrateFirstShortMsg(), null, Bundle.NetBeansProfiler_MustCalibrateFirstMsg());
             changeStateTo(PROFILING_INACTIVE);
 
             return false; // failed, cannot proceed
@@ -1038,20 +1022,23 @@ public abstract class NetBeansProfiler extends Profiler {
     }
     
     public void detachFromApp() {
-        setTransitionState();
+        TargetAppRunner runner = getTargetAppRunner();
+        if (runner == null || !runner.targetJVMIsAlive()) return;
+        
+        changeStateTo(PROFILING_IN_TRANSITION);
 
-        getTargetAppRunner().prepareDetachFromTargetJVM();
+        runner.prepareDetachFromTargetJVM();
 
-        if (getTargetAppRunner().getProfilingSessionStatus().currentInstrType != CommonConstants.INSTR_NONE) {
+        if (runner.getProfilingSessionStatus().currentInstrType != CommonConstants.INSTR_NONE) {
             //      if (LiveResultsWindow.hasDefault()) LiveResultsWindow.getDefault().reset(); // see issue http://www.netbeans.org/issues/show_bug.cgi?id=68213
             try {
-                getTargetAppRunner().getProfilerClient().removeAllInstrumentation(false); // remove only the server side instrumentation
+                runner.getProfilerClient().removeAllInstrumentation(false); // remove only the server side instrumentation
             } catch (InstrumentationException e) {
                 ProfilerDialogs.displayError(e.getMessage());
             }
         }
 
-        getTargetAppRunner().detachFromTargetJVM();
+        runner.detachFromTargetJVM();
 
         //    targetAppRunner.getProfilerClient().resetClientData();
         // TODO reset all profilingresultslisteners
@@ -1105,21 +1092,20 @@ public abstract class NetBeansProfiler extends Profiler {
 
         final ProfilerEngineSettings sharedSettings = getTargetAppRunner().getProfilerEngineSettings();
         profilingSettings.applySettings(sharedSettings);
+        sharedSettings.setInstrumentObjectInit(true);
 
         logActionConfig("modifyCurrentProfiling", profilingSettings, null, null, sharedSettings.getInstrumentationFilter()); //NOI18N
-        
-        GestureSubmitter.logConfig(profilingSettings, sharedSettings.getInstrumentationFilter());
 
         setThreadsMonitoringEnabled(profilingSettings.getThreadsMonitoringEnabled());
         setLockContentionMonitoringEnabled(profilingSettings.getLockContentionMonitoringEnabled());
 
-        SwingUtilities.invokeLater(new Runnable() {
-            @Override
-            public void run() {
-                if (LiveResultsWindow.hasDefault())
-                    LiveResultsWindow.getDefault().handleCleanupBeforeProfiling();
-            }
-        });
+//        SwingUtilities.invokeLater(new Runnable() {
+//            @Override
+//            public void run() {
+//                if (LiveResultsWindow.hasDefault())
+//                    LiveResultsWindow.getDefault().handleCleanupBeforeProfiling();
+//            }
+//        });
 
         ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
                 @Override
@@ -1202,14 +1188,12 @@ public abstract class NetBeansProfiler extends Profiler {
         sessionSettings.applySettings(sSettings);
         profilingSettings.applySettings(sSettings); // can override the session settings
         sSettings.setRemoteHost(""); // NOI18N // clear remote profiling host
+        sSettings.setInstrumentObjectInit(false); // clear instrument object.<init>
 
         //getThreadsManager().setSupportsSleepingStateMonitoring(
         // Platform.supportsThreadSleepingStateMonitoring(sharedSettings.getTargetJDKVersionString()));
         logActionConfig("profileClass", profilingSettings, sessionSettings, null, sSettings.getInstrumentationFilter()); //NOI18N
 
-        GestureSubmitter.logProfileClass(getProfiledProject(), sessionSettings);
-        GestureSubmitter.logConfig(profilingSettings, sSettings.getInstrumentationFilter());
-
         changeStateTo(PROFILING_STARTED);
 
         //    System.err.println("--------------------------------------------- 2: "+ (System.currentTimeMillis() - time));
@@ -1305,7 +1289,7 @@ public abstract class NetBeansProfiler extends Profiler {
         ProfilerEngineSettings pes = getTargetAppRunner().getProfilerEngineSettings();
 
         int savedPort = pes.getPortNo();
-        InstrumentationFilter savedInstrFilter = pes.getInstrumentationFilter();
+        GenericFilter savedInstrFilter = pes.getInstrumentationFilter();
         String savedJVMExeFile = pes.getTargetJVMExeFile();
         String savedJDKVersionString = pes.getTargetJDKVersionString();
         int savedArch = pes.getSystemArchitecture();
@@ -1318,7 +1302,7 @@ public abstract class NetBeansProfiler extends Profiler {
         }
 
         pes.setPortNo(ideSettings.getCalibrationPortNo());
-        pes.setInstrumentationFilter(new InstrumentationFilter());
+        pes.setInstrumentationFilter(new GenericFilter());
         pes.setMainClassPath(""); //NOI18N
 
         boolean result = false;
@@ -1370,13 +1354,13 @@ public abstract class NetBeansProfiler extends Profiler {
     public void setProfiledProject(Lookup.Provider project, FileObject singleFile) {
         profiledProject = project;
         profiledSingleFile = singleFile;
-        SwingUtilities.invokeLater(new Runnable() {
-            @Override
-            public void run() {
-                if (ProfilerControlPanel2.hasDefault())
-                    ProfilerControlPanel2.getDefault().setProfiledProject(profiledProject);
-            }
-        });
+//        SwingUtilities.invokeLater(new Runnable() {
+//            @Override
+//            public void run() {
+//                if (ProfilerControlPanel2.hasDefault())
+//                    ProfilerControlPanel2.getDefault().setProfiledProject(profiledProject);
+//            }
+//        });
     }
 
     public Lookup.Provider getProfiledProject() {
@@ -1391,9 +1375,10 @@ public abstract class NetBeansProfiler extends Profiler {
     public boolean prepareInstrumentation(ProfilingSettings profilingSettings) {
         teardownDispatcher();
         setupDispatcher(profilingSettings);
-
-        ClientUtils.SourceCodeSelection[] marks = MarkingEngine.getDefault().getMarkerMethods();
-        profilingSettings.setInstrumentationMarkerMethods(marks);
+        
+//        ClientUtils.SourceCodeSelection[] marks = MarkingEngine.getDefault().getMarkerMethods();
+//        profilingSettings.setInstrumentationMarkerMethods(marks);
+        profilingSettings.setInstrumentationMarkerMethods(new ClientUtils.SourceCodeSelection[0]);
 
         return prepareInstrumentationImpl(profilingSettings);
     }
@@ -1439,68 +1424,42 @@ public abstract class NetBeansProfiler extends Profiler {
         return false;
     }
 
-    // TODO [ian] - perform saving of global settings differently
-    public void saveFilters() {
-        // 1. save global filters
-        FileLock lock = null;
-
-        try {
-            final FileObject folder = GlobalStorage.getSettingsFolder(true);
-            FileObject fo = folder.getFileObject(GLOBAL_FILTERS_FILENAME, "xml"); //NOI18N
-
-            if (fo == null) {
-                fo = folder.createData(GLOBAL_FILTERS_FILENAME, "xml"); //NOI18N
-            }
-
-            lock = fo.lock();
-
-            final OutputStream os = fo.getOutputStream(lock);
-            final BufferedOutputStream bos = new BufferedOutputStream(os);
-            final Properties globalFiltersProps = new Properties();
-            globalFilters.store(globalFiltersProps);
-            globalFiltersProps.storeToXML(bos, ""); //NOI18N
-            bos.close();
-        } catch (Exception e) {
-            ProfilerLogger.log(e);
-            ProfilerDialogs.displayError(
-                Bundle.NetBeansProfiler_ErrorSavingProfilingSettingsMessage(e.getMessage()));
-        } finally {
-            if (lock != null) {
-                lock.releaseLock();
-            }
-        }
-
-        // 2. save defined Filter Sets
-        lock = null;
-
-        try {
-            final FileObject folder = GlobalStorage.getSettingsFolder(true);
-            FileObject fo = folder.getFileObject(DEFINED_FILTERSETS_FILENAME, "xml"); //NOI18N
-
-            if (fo == null) {
-                fo = folder.createData(DEFINED_FILTERSETS_FILENAME, "xml"); //NOI18N
-            }
-
-            lock = fo.lock();
-
-            final OutputStream os = fo.getOutputStream(lock);
-            final BufferedOutputStream bos = new BufferedOutputStream(os);
-            final Properties definedFilterSetsProps = new Properties();
-
-            definedFilterSets.store(definedFilterSetsProps);
-
-            definedFilterSetsProps.storeToXML(bos, ""); //NOI18N
-            bos.close();
-        } catch (Exception e) {
-            ProfilerLogger.log(e);
-            ProfilerDialogs.displayError(
-                Bundle.NetBeansProfiler_ErrorSavingFilterSetsMessage(e.getMessage()));
-        } finally {
-            if (lock != null) {
-                lock.releaseLock();
-            }
-        }
-    }
+//    // TODO [ian] - perform saving of global settings differently
+//    public void saveFilters() {
+//        // 1. save global filters
+//        FileLock lock = null;
+//
+//        try {
+//            Properties globalFiltersProps = new Properties();
+//            globalFilters.store(globalFiltersProps);
+//            ProfilerStorage.saveGlobalProperties(globalFiltersProps, GLOBAL_FILTERS_FILENAME);
+//        } catch (Exception e) {
+//            ProfilerLogger.log(e);
+//            ProfilerDialogs.displayError(
+//                Bundle.NetBeansProfiler_ErrorSavingProfilingSettingsMessage(e.getMessage()));
+//        } finally {
+//            if (lock != null) {
+//                lock.releaseLock();
+//            }
+//        }
+//
+//        // 2. save defined Filter Sets
+//        lock = null;
+//
+//        try {
+//            Properties definedFilterSetsProps = new Properties();
+//            definedFilterSets.store(definedFilterSetsProps);
+//            ProfilerStorage.saveGlobalProperties(definedFilterSetsProps, DEFINED_FILTERSETS_FILENAME);
+//        } catch (Exception e) {
+//            ProfilerLogger.log(e);
+//            ProfilerDialogs.displayError(
+//                Bundle.NetBeansProfiler_ErrorSavingFilterSetsMessage(e.getMessage()));
+//        } finally {
+//            if (lock != null) {
+//                lock.releaseLock();
+//            }
+//        }
+//    }
 
     public void shutdown() {
         getMonitor().stopUpdateThread();
@@ -1558,8 +1517,11 @@ public abstract class NetBeansProfiler extends Profiler {
     }
 
     public void stopApp() {
-        setTransitionState();
-        getTargetAppRunner().terminateTargetJVM();
+        TargetAppRunner runner = getTargetAppRunner();
+        if (runner == null || !runner.targetJVMIsAlive()) return;
+        
+        changeStateTo(PROFILING_IN_TRANSITION);
+        runner.terminateTargetJVM();
     }
 
     private Properties getAgentProperties(int port) {
@@ -1609,10 +1571,6 @@ public abstract class NetBeansProfiler extends Profiler {
         return (profilingState == PROFILING_RUNNING) && (port == getTargetAppRunner().getProfilerEngineSettings().getPortNo());
     }
 
-    private void setTransitionState() {
-        changeStateTo(PROFILING_IN_TRANSITION);
-    }
-
     private void changeStateTo(int newState) {
         if (profilingState == newState) {
             return;
@@ -1639,7 +1597,7 @@ public abstract class NetBeansProfiler extends Profiler {
 
     protected void cleanupAfterProfiling() {
         teardownDispatcher();
-        MarkingEngine.getDefault().deconfigure();
+//        MarkingEngine.getDefault().deconfigure();
         ClassRepository.cleanup();
     }
 
@@ -1648,8 +1606,8 @@ public abstract class NetBeansProfiler extends Profiler {
             public void run() {
                 NetBeansProfiler.this.getThreadsManager().reset();
                 NetBeansProfiler.this.getVMTelemetryManager().reset();
-                if (LiveResultsWindow.hasDefault())
-                    LiveResultsWindow.getDefault().handleCleanupBeforeProfiling();
+//                if (LiveResultsWindow.hasDefault())
+//                    LiveResultsWindow.getDefault().handleCleanupBeforeProfiling();
             }
         });
         ResultsManager.getDefault().reset();
@@ -1658,115 +1616,80 @@ public abstract class NetBeansProfiler extends Profiler {
         ClassRepository.initClassPaths(sharedSettings.getWorkingDir(), sharedSettings.getVMClassPaths());
     }
 
-    private void displayWarningAboutEntireAppProfiling() {
-        ProfilerDialogs.displayWarning(Bundle.NetBeansProfiler_EntireApplicationProfilingWarning());
-    }
-
-    // -- Package-Private stuff --------------------------------------------------------------------------------------------
-    private void loadGlobalFilters() {
-        try {
-            FileObject folder = GlobalStorage.getSettingsFolder(false);
-            FileObject configFolder = FileUtil.getConfigFile("NBProfiler/Config");
-
-            // 1. Deal with global filters
-            FileObject filtersFO = null;
-
-            if ((folder != null) && folder.isValid()) {
-                filtersFO = folder.getFileObject(GLOBAL_FILTERS_FILENAME, "xml"); //NOI18N
-            }
-
-            if ((filtersFO == null) && (configFolder != null) && configFolder.isValid()) {
-                filtersFO = configFolder.getFileObject(GLOBAL_FILTERS_FILENAME + DEFAULT_FILE_SUFFIX, "xml"); //NOI18N
-            }
-
-            if (filtersFO != null) {
-                final InputStream fis = filtersFO.getInputStream();
-                final BufferedInputStream bis = new BufferedInputStream(fis);
-                final Properties globalFiltersProps = new Properties();
-                globalFiltersProps.loadFromXML(bis);
-                globalFilters = new GlobalFilters();
-                globalFilters.load(globalFiltersProps);
-                bis.close();
-            }
-
-            // 2. Deal with defined filter sets
-            FileObject filterSetsFO = null;
-
-            if ((folder != null) && folder.isValid()) {
-                filterSetsFO = folder.getFileObject(DEFINED_FILTERSETS_FILENAME, "xml"); //NOI18N
-            }
-
-            if ((filterSetsFO == null) && (configFolder != null) && configFolder.isValid()) {
-                filterSetsFO = configFolder.getFileObject(DEFINED_FILTERSETS_FILENAME + DEFAULT_FILE_SUFFIX, "xml"); //NOI18N
-            }
-
-            if (filterSetsFO != null) {
-                final InputStream fis = filterSetsFO.getInputStream();
-                final BufferedInputStream bis = new BufferedInputStream(fis);
-                final Properties definedFilterSetsProps = new Properties();
-                definedFilterSetsProps.loadFromXML(bis);
-                definedFilterSets = new DefinedFilterSets();
-                definedFilterSets.load(definedFilterSetsProps);
-                bis.close();
-            }
-        } catch (Exception e) {
-            ProfilerLogger.log(e);
-            ProfilerDialogs.displayError(
-                Bundle.NetBeansProfiler_ErrorLoadingProfilingSettingsMessage(e.getMessage()));
-        }
-    }
+//    private void displayWarningAboutEntireAppProfiling() {
+//        ProfilerDialogs.displayWarning(Bundle.NetBeansProfiler_EntireApplicationProfilingWarning());
+//    }
+//
+//    // -- Package-Private stuff --------------------------------------------------------------------------------------------
+//    private void loadGlobalFilters() {
+//        try {
+//            Properties globalFiltersProps = new Properties();
+//            ProfilerStorage.loadGlobalProperties(globalFiltersProps, GLOBAL_FILTERS_FILENAME);
+//            globalFilters = new GlobalFilters();
+//            globalFilters.load(globalFiltersProps);
+//            
+//            Properties definedFilterSetsProps = new Properties();
+//            ProfilerStorage.loadGlobalProperties(definedFilterSetsProps, DEFINED_FILTERSETS_FILENAME);
+//            definedFilterSets = new DefinedFilterSets();
+//            definedFilterSets.load(definedFilterSetsProps);
+//        } catch (Exception e) {
+//            ProfilerLogger.log(e);
+//            ProfilerDialogs.displayError(
+//                Bundle.NetBeansProfiler_ErrorLoadingProfilingSettingsMessage(e.getMessage()));
+//        }
+//    }
 
     // -- Private implementation -------------------------------------------------------------------------------------------
     private void openWindowsOnProfilingStart() {
-        int telemetryBehavior = ideSettings.getTelemetryOverviewBehavior();
-        int threadsBehavior = ideSettings.getThreadsViewBehavior();
-        int locksBehavior = ideSettings.getLockContentionViewBehavior();
-
-        boolean threadsEnabled = lastProfilingSettings.getThreadsMonitoringEnabled();
-        boolean lockContentionEnabled = lastProfilingSettings.getLockContentionMonitoringEnabled();
-        int type = lastProfilingSettings.getProfilingType();
-
-        // 1. Telemetry Overview
-        if ((telemetryBehavior == ProfilerIDESettings.OPEN_ALWAYS)
-                || ((telemetryBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
-            TelemetryOverviewPanel.getDefault().open();
-            TelemetryOverviewPanel.getDefault().requestVisible();
-        }
-
-        // 2. Threads view
-        if (threadsEnabled) {
-            if ((threadsBehavior == ProfilerIDESettings.OPEN_ALWAYS)
-                    || ((threadsBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
-                ThreadsWindow.getDefault().open();
-                ThreadsWindow.getDefault().requestVisible();
-            }
-        }
-        
-        // 3. Lock Contention view
-        if (lockContentionEnabled) {
-            if ((locksBehavior == ProfilerIDESettings.OPEN_ALWAYS)
-                    || ((locksBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
-                LockContentionWindow.getDefault().showView();
-            }
-        }
-
-        // 4. Live Results
-        if ((ideSettings.getDisplayLiveResultsCPU()
-                && ((type == ProfilingSettings.PROFILE_CPU_ENTIRE) || (type == ProfilingSettings.PROFILE_CPU_PART)
-                    || (type == ProfilingSettings.PROFILE_CPU_SAMPLING)))
-                || (ideSettings.getDisplayLiveResultsFragment() && (type == ProfilingSettings.PROFILE_CPU_STOPWATCH))
-                || (ideSettings.getDisplayLiveResultsMemory()
-                       && ((type == ProfilingSettings.PROFILE_MEMORY_ALLOCATIONS)
-                           || (type == ProfilingSettings.PROFILE_MEMORY_LIVENESS)
-                           || (type == ProfilingSettings.PROFILE_MEMORY_SAMPLING)))) {
-            LiveResultsWindow.getDefault().open();
-            LiveResultsWindow.getDefault().requestVisible();
-        }
-
-        // 5. Control Panel displayed always, and getting focus
-        final ProfilerControlPanel2 controlPanel2 = ProfilerControlPanel2.getDefault();
-        controlPanel2.open();
-        controlPanel2.requestActive();
+//        int telemetryBehavior = ideSettings.getTelemetryOverviewBehavior();
+//        int threadsBehavior = ideSettings.getThreadsViewBehavior();
+//        int locksBehavior = ideSettings.getLockContentionViewBehavior();
+//
+//        boolean threadsEnabled = lastProfilingSettings.getThreadsMonitoringEnabled();
+//        boolean lockContentionEnabled = lastProfilingSettings.getLockContentionMonitoringEnabled();
+//        int type = lastProfilingSettings.getProfilingType();
+//
+//        // 1. Telemetry Overview
+//        if ((telemetryBehavior == ProfilerIDESettings.OPEN_ALWAYS)
+//                || ((telemetryBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
+//            TelemetryOverviewPanel.getDefault().open();
+//            TelemetryOverviewPanel.getDefault().requestVisible();
+//        }
+//
+//        // 2. Threads view
+//        if (threadsEnabled) {
+//            if ((threadsBehavior == ProfilerIDESettings.OPEN_ALWAYS)
+//                    || ((threadsBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
+//                ThreadsWindow.getDefault().open();
+//                ThreadsWindow.getDefault().requestVisible();
+//            }
+//        }
+//        
+//        // 3. Lock Contention view
+//        if (lockContentionEnabled) {
+//            if ((locksBehavior == ProfilerIDESettings.OPEN_ALWAYS)
+//                    || ((locksBehavior == ProfilerIDESettings.OPEN_MONITORING) && (type == ProfilingSettings.PROFILE_MONITOR))) {
+//                LockContentionWindow.getDefault().showView();
+//            }
+//        }
+//
+//        // 4. Live Results
+//        if ((ideSettings.getDisplayLiveResultsCPU()
+//                && ((type == ProfilingSettings.PROFILE_CPU_ENTIRE) || (type == ProfilingSettings.PROFILE_CPU_PART)
+//                    || (type == ProfilingSettings.PROFILE_CPU_SAMPLING)))
+//                || (ideSettings.getDisplayLiveResultsFragment() && (type == ProfilingSettings.PROFILE_CPU_STOPWATCH))
+//                || (ideSettings.getDisplayLiveResultsMemory()
+//                       && ((type == ProfilingSettings.PROFILE_MEMORY_ALLOCATIONS)
+//                           || (type == ProfilingSettings.PROFILE_MEMORY_LIVENESS)
+//                           || (type == ProfilingSettings.PROFILE_MEMORY_SAMPLING)))) {
+//            LiveResultsWindow.getDefault().open();
+//            LiveResultsWindow.getDefault().requestVisible();
+//        }
+//
+//        // 5. Control Panel displayed always, and getting focus
+//        final ProfilerControlPanel2 controlPanel2 = ProfilerControlPanel2.getDefault();
+//        controlPanel2.open();
+//        controlPanel2.requestActive();
     }
 
     @NbBundle.Messages({
@@ -1851,6 +1774,7 @@ public abstract class NetBeansProfiler extends Profiler {
             switch (profilingSettings.getProfilingType()) {
                 case ProfilingSettings.PROFILE_CPU_ENTIRE:
                 case ProfilingSettings.PROFILE_CPU_PART:
+                case ProfilingSettings.PROFILE_CPU_JDBC:
                 case ProfilingSettings.PROFILE_CPU_SAMPLING:
                 case ProfilingSettings.PROFILE_CPU_STOPWATCH: {
                     cctProvider = Lookup.getDefault().lookup(CPUCCTProvider.class);
@@ -1906,6 +1830,7 @@ public abstract class NetBeansProfiler extends Profiler {
             Collection listeners = null;
             switch (profilingSettings.getProfilingType()) {
                 case ProfilingSettings.PROFILE_CPU_PART:
+                case ProfilingSettings.PROFILE_CPU_JDBC:
                 case ProfilingSettings.PROFILE_CPU_ENTIRE:
                 case ProfilingSettings.PROFILE_CPU_SAMPLING: {
                     listeners = Lookup.getDefault().lookupAll(CPUProfilingResultListener.class);
@@ -2022,6 +1947,8 @@ public abstract class NetBeansProfiler extends Profiler {
             for(SessionListener sl : Lookup.getDefault().lookupAll(SessionListener.class)) {
                 sl.onShutdown();
             }
+            FlatProfileBuilder fpb = Lookup.getDefault().lookup(FlatProfileBuilder.class);
+            fpb.setContext(null, null, null);
         }
     }
 
@@ -2048,7 +1975,7 @@ public abstract class NetBeansProfiler extends Profiler {
         return false;
     }
     
-    private static void logActionConfig(String actionTitle, ProfilingSettings ps, SessionSettings ss, AttachSettings as, InstrumentationFilter f) {
+    private static void logActionConfig(String actionTitle, ProfilingSettings ps, SessionSettings ss, AttachSettings as, GenericFilter f) {
         assert actionTitle != null;
         assert ps != null;
         assert f != null;
@@ -2066,7 +1993,7 @@ public abstract class NetBeansProfiler extends Profiler {
                 ps.debug(),
                 (ss != null ? "Session" : (as != null ? "Attach" : null)),  // NOI18N
                 (ss != null ? ss.debug() : (as != null ? as.debug() : null)),                    
-                f.debug()
+                f.toString()
             }
         );
     }
