@@ -70,8 +70,6 @@ import org.netbeans.modules.profiler.api.icons.ProfilerIcons;
 import org.netbeans.modules.profiler.ui.NBSwingWorker;
 import org.openide.DialogDisplayer;
 import org.openide.awt.ActionID;
-import org.openide.awt.ActionReference;
-import org.openide.awt.ActionRegistration;
 import org.openide.util.HelpCtx;
 import org.openide.util.Lookup;
 import org.openide.windows.WindowManager;
@@ -107,8 +105,8 @@ import org.openide.windows.WindowManager;
     "CompareSnapshotsAction_SnapshotsListAccessDescr=List of comparable snapshots in current project"
 })
 @ActionID(id = "org.netbeans.modules.profiler.actions.CompareSnapshotsAction", category = "Profile")
-@ActionRegistration(iconInMenu = true, displayName = "#CompareSnapshotsAction_ActionName", iconBase = "org/netbeans/modules/profiler/impl/icons/compareSnapshots.png")
-@ActionReference(path = "Menu/Profile", position = 1600, separatorAfter=1700)
+//@ActionRegistration(iconInMenu = true, displayName = "#CompareSnapshotsAction_ActionName", iconBase = "org/netbeans/modules/profiler/impl/icons/compareSnapshots.png")
+//@ActionReference(path = "Menu/Profile", position = 1600, separatorAfter=1700)
 public class CompareSnapshotsAction extends AbstractAction {
     //~ Static fields/initializers -------------------------------------------------------------------------------------------
         private static final HelpCtx EXTERNAL_SNAPSHOT_HELP_CTX = new HelpCtx("SelectExternalSnapshotsPanel.HelpCtx"); // NOI18N
@@ -643,6 +641,7 @@ public class CompareSnapshotsAction extends AbstractAction {
 
                             switch (ls.getType()) {
                                 case LoadedSnapshot.SNAPSHOT_TYPE_CPU:
+                                case LoadedSnapshot.SNAPSHOT_TYPE_CPU_JDBC:
                                     c.setIcon(cpuIcon);
 
                                     break;
@@ -667,6 +666,7 @@ public class CompareSnapshotsAction extends AbstractAction {
 
                                 switch (ls.getType()) {
                                     case LoadedSnapshot.SNAPSHOT_TYPE_CPU:
+                                    case LoadedSnapshot.SNAPSHOT_TYPE_CPU_JDBC:
                                         c.setIcon(cpuIcon);
 
                                         break;
@@ -686,6 +686,7 @@ public class CompareSnapshotsAction extends AbstractAction {
                                 c.setText(rm.getSnapshotDisplayName(fo.getName(), type));
                                 switch (type) {
                                     case LoadedSnapshot.SNAPSHOT_TYPE_CPU:
+                                    case LoadedSnapshot.SNAPSHOT_TYPE_CPU_JDBC:
                                         c.setIcon(cpuIcon);
 
                                         break;
@@ -855,25 +856,32 @@ public class CompareSnapshotsAction extends AbstractAction {
     private LoadedSnapshot snapshot;
     private SelectExternalSnapshotsPanel externalSnapshotsSelector;
     private SelectSecondSnapshotPanel secondSnapshotSelector;
+    
+    private Performer performer;
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     public CompareSnapshotsAction() {
-        snapshot = null;
-        putValue(Action.NAME, Bundle.CompareSnapshotsAction_ActionName());
-        putValue(Action.SHORT_DESCRIPTION, Bundle.CompareSnapshotsAction_ActionDescr());
-        putValue(Action.SMALL_ICON, Icons.getIcon(ProfilerIcons.SNAPSHOTS_COMPARE));
+        this(null);
     }
 
     public CompareSnapshotsAction(LoadedSnapshot snapshot) {
-        this();
+        putValue(Action.NAME, Bundle.CompareSnapshotsAction_ActionName());
+        putValue(Action.SHORT_DESCRIPTION, Bundle.CompareSnapshotsAction_ActionDescr());
+        putValue(Action.SMALL_ICON, Icons.getIcon(ProfilerIcons.SNAPSHOTS_COMPARE));
+        
         this.snapshot = snapshot;
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
+    
+    public void setPerformer(Performer _performer) {
+        performer = _performer;
+    }
 
     public void actionPerformed(ActionEvent e) {
         if (snapshot != null) {
+            assert performer != null;
             compareDefinedSnapshot();
         } else {
             compareExternalSnapshots();
@@ -1010,25 +1018,30 @@ public class CompareSnapshotsAction extends AbstractAction {
         DialogDescriptor desc = new DialogDescriptor(getSecondSnapshotSelector(), Bundle.CompareSnapshotsAction_SelectSnapshotDialogCaption(), true,
                                                      new Object[] {
                                                          getSecondSnapshotSelector().getOKButton(), DialogDescriptor.CANCEL_OPTION
-                                                     }, DialogDescriptor.OK_OPTION, 0, null, null);
+                                                     }, DialogDescriptor.OK_OPTION, 0, SECOND_SNAPSHOT_HELP_CTX, null);
         Object res = DialogDisplayer.getDefault().notify(desc);
 
         if (res.equals(getSecondSnapshotSelector().getOKButton())) {
             Object selectedSnapshot = getSecondSnapshotSelector().getSnapshot();
 
             if (selectedSnapshot instanceof LoadedSnapshot) {
-                ResultsManager.getDefault().compareSnapshots(snapshot, (LoadedSnapshot) selectedSnapshot);
+                performer.compare((LoadedSnapshot)selectedSnapshot);
+//                ResultsManager.getDefault().compareSnapshots(snapshot, (LoadedSnapshot) selectedSnapshot);
             } else if (selectedSnapshot instanceof FileObject) {
-                if (snapshot.getFile() == null) {
-                    LoadedSnapshot snapshot2 = ResultsManager.getDefault().getSnapshotFromFileObject((FileObject) selectedSnapshot);
-
-                    if (snapshot2 != null) {
-                        ResultsManager.getDefault().compareSnapshots(snapshot, snapshot2);
-                    }
-                } else {
-                    ResultsManager.getDefault()
-                                  .compareSnapshots(FileUtil.toFileObject(snapshot.getFile()), (FileObject) selectedSnapshot);
-                }
+                // TODO: seems to eventually load the snapshot in EDT
+                LoadedSnapshot snapshot2 = ResultsManager.getDefault().
+                        getSnapshotFromFileObject((FileObject)selectedSnapshot);
+                if (snapshot2 != null) performer.compare(snapshot2);
+//                if (snapshot.getFile() == null) {
+//                    LoadedSnapshot snapshot2 = ResultsManager.getDefault().getSnapshotFromFileObject((FileObject) selectedSnapshot);
+//
+//                    if (snapshot2 != null) {
+//                        ResultsManager.getDefault().compareSnapshots(snapshot, snapshot2);
+//                    }
+//                } else {
+//                    ResultsManager.getDefault()
+//                                  .compareSnapshots(FileUtil.toFileObject(snapshot.getFile()), (FileObject) selectedSnapshot);
+//                }
             }
         }
     }
@@ -1038,7 +1051,7 @@ public class CompareSnapshotsAction extends AbstractAction {
                                                      new Object[] {
                                                          getExternalSnapshotsSelector().getOKButton(),
                                                          DialogDescriptor.CANCEL_OPTION
-                                                     }, DialogDescriptor.OK_OPTION, 0, null, null);
+                                                     }, DialogDescriptor.OK_OPTION, 0, EXTERNAL_SNAPSHOT_HELP_CTX, null);
         Object res = DialogDisplayer.getDefault().notify(desc);
 
         if (res.equals(getExternalSnapshotsSelector().getOKButton())) {
@@ -1047,4 +1060,12 @@ public class CompareSnapshotsAction extends AbstractAction {
                                             FileUtil.toFileObject(new File(getExternalSnapshotsSelector().getSnapshot2Filename())));
         }
     }
+    
+    
+    public static interface Performer {
+        
+        void compare(LoadedSnapshot snapshot);
+        
+    }
+    
 }
