@@ -26,6 +26,7 @@
 package com.sun.tools.visualvm.heapdump;
 
 import com.sun.tools.visualvm.core.datasource.DataSource;
+import com.sun.tools.visualvm.core.datasupport.Utils;
 import com.sun.tools.visualvm.core.snapshot.Snapshot;
 import com.sun.tools.visualvm.core.snapshot.SnapshotsSupport;
 import java.io.File;
@@ -39,6 +40,8 @@ import org.openide.util.NbBundle;
  */
 public abstract class HeapDump extends Snapshot {
     
+    private static final String HWCACHE_EXT = ".hwcache"; // NOI18N
+    
     /**
      * Creates new instance of HeapDump with the data stored in a file.
      * 
@@ -65,5 +68,19 @@ public abstract class HeapDump extends Snapshot {
     public void saveAs() {
         SnapshotsSupport.getInstance().saveAs(this, NbBundle.getMessage(HeapDump.class, "LBL_Save_Heap_Dump_As"));  // NOI18N
     }
+    
+    protected void remove() {
+        final File f = getFile();
+        
+        // #GH-111: delete the corresponding .hwcache directory
+        if (f != null) Utils.FILE_QUEUE.post(new Runnable() {
+            public void run() {
+                File ff = new File(f.getParent(), f.getName() + HWCACHE_EXT);
+                if (ff.isDirectory()) Utils.delete(ff, true);
+            }
+        });
+        
+        super.remove();
+    }
 
 }
