@@ -125,7 +125,7 @@ import org.openide.util.RequestProcessor;
     "OQLConsoleView_ExecutingProgress=Executing...",
     "OQLConsoleView_Results=Results:",
     "OQLConsoleView_ObjectsTooltip=Objects",
-    "OQLConsoleView_HTMLTooltip=Results:",
+    "OQLConsoleView_HTMLTooltip=HTML",
     "OQLConsoleView_Details=Details:",
     "OQLConsoleView_InitializingEngine=<initializing OQL engine...>",
     "OQLConsoleView_EngineNotAvailable=<OQL engine not available>",
