@@ -37,6 +37,7 @@ import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Locale;
 import javax.swing.BorderFactory;
 import javax.swing.Icon;
 import javax.swing.JComponent;
@@ -292,7 +293,7 @@ final class OQLQueries {
         chooser.setFileFilter(new FileFilter() {
             public boolean accept(File f) {
                 if (f.isDirectory()) return true;
-                String fname = f.getName().toLowerCase();
+                String fname = f.getName().toLowerCase(Locale.ENGLISH);
                 if (fname.endsWith(".oql") || fname.endsWith(".txt")) return true; // NOI18N
                 return false;
             }
@@ -367,7 +368,7 @@ final class OQLQueries {
         chooser.setFileFilter(new FileFilter() {
             public boolean accept(File f) {
                 if (f.isDirectory()) return true;
-                String fname = f.getName().toLowerCase();
+                String fname = f.getName().toLowerCase(Locale.ENGLISH);
                 if (fname.endsWith(".oql") || fname.endsWith(".txt")) return true; // NOI18N
                 return false;
             }
@@ -380,7 +381,7 @@ final class OQLQueries {
             File file = chooser.getSelectedFile();
             lastDirectory = file.getParentFile();
             
-            String fname = file.getName().toLowerCase();
+            String fname = file.getName().toLowerCase(Locale.ENGLISH);
             if (!fname.endsWith(".oql") && !fname.endsWith(".txt")) // NOI18N
                 file = new File(file.getParentFile(), file.getName() + ".oql"); // NOI18N
             final File fileF = file;
