@@ -132,6 +132,7 @@ final class ThreadsMemoryView extends JPanel {
         totalBytes = info.getTotalBytes();
         if (currentThreadsInfo != null) {
             allocatedBytesPerSec = currentThreadsInfo.getAllocatedBytesPerSecond(info);
+            renderers[1].setMaxValue(currentThreadsInfo.getTotalAllocatedBytesPerSecond());
         }
         currentThreadsInfo = info;
         
@@ -252,7 +253,9 @@ final class ThreadsMemoryView extends JPanel {
         renderers = new HideableBarRenderer[2];
         
         renderers[0] = new HideableBarRenderer(new NumberPercentRenderer(Formatters.bytesFormat()));
+        renderers[0].setBarDiffMode(HideableBarRenderer.BarDiffMode.MODE_BAR_NORMAL);
         renderers[1] = new HideableBarRenderer(new NumberPercentRenderer(Formatters.bytesFormat()));
+        renderers[1].setBarDiffMode(HideableBarRenderer.BarDiffMode.MODE_BAR_NORMAL);
         
         LabelRenderer threadRenderer = new LabelRenderer();
         threadRenderer.setIcon(Icons.getIcon(ProfilerIcons.THREAD));
